@@ -9,11 +9,11 @@ OC.L10N.register(
     "You made {member} join {circle}" : "Você fez com que {member} se juntasse a {circle}",
     "{author} made {member} join {circle}" : "{author} fez com que {member} se juntasse a {circle}",
     "You added team {member} as member to {circle}" : "Você adicionou a equipe {member} como membro de {circle}",
-    "{author} added team {member} as member to {circle}" : "{autor} Equipe adicionada {membro} como membro da {circle}",
+    "{author} added team {member} as member to {circle}" : "{author} adicionou a equipe {member} como membro de {circle}",
     "You made {member} leave {circle}" : "Você fez {member} sair de {circle}",
-    "{author} made {member} leave {circle}" : "{author} fez com que {membro} saísse de {circle}",
+    "{author} made {member} leave {circle}" : "{author} fez {member} sair de {circle}",
     "You removed {member} from {circle}" : "Você excluiu {member} de {circle}",
-    "{author} removed {member} from {circle}" : "{author} removido {membro} de {circle}",
+    "{author} removed {member} from {circle}" : "{author} excluiu {member} de {circle}",
     "You joined {circle}" : "Você juntou-se a {circle}",
     "{member} joined {circle}" : "{member} juntou-se à {circle}",
     "You accepted the invitation to join {circle}" : "Você aceitou o convite para juntar-se à {circle}",
@@ -30,8 +30,8 @@ OC.L10N.register(
     "{member} left {circle}" : "{member} deixou {circle}",
     "You declined the invitation to join {circle}" : "Você recusou o convite para juntar-se a {circle}",
     "{member} declined an invitation to join {circle}" : "{member} recusou o convite para juntar-se a {circle}",
-    "You cancelled your request to join {circle}" : "Você cancelou o convite para juntar-se a {circle}",
-    "{member} cancelled a request to join {circle}" : "{member} cancelou uma solicitação para ingressar em {circle}",
+    "You cancelled your request to join {circle}" : "Você cancelou sua solicitação para juntar-se a {circle}",
+    "{member} cancelled a request to join {circle}" : "{member} cancelou uma solicitação para juntar-se a {circle}",
     "You have been removed from {circle} by {author}" : "Você foi removido de {circle} por {author}",
     "{member} has been removed from {circle} by {author}" : "{member} foi removido de {circle} por {author}",
     "You removed {external} from {circle}" : "Você removeu {external} de {circle}",
@@ -52,7 +52,7 @@ OC.L10N.register(
     "{member} sent a request to join {circle}" : "{member} solicitou juntar-se à {circle}",
     "You are the new owner of {circle}" : "Você é o novo proprietário de {circle}",
     "{member} is the new owner of {circle}" : "{member} é o novo proprietário de {circle}",
-    "On events happening in a <strong>team</strong> of which you are a member" : "Em eventos que acontecem em um <strong>equipe</strong> do qual você é membro",
+    "On events happening in a <strong>team</strong> of which you are a member" : "Em eventos que acontecem em uma <strong>equipe</strong> da qual você é membro",
     "Any important event in a <strong>team</strong> you are moderating" : "Qualquer evento importante em uma <strong>equipe</strong> que você está moderando",
     "On global events happening in any <strong>team</strong>" : "Em eventos globais que acontecem em qualquer <strong>equipe</strong>",
     "Single" : "Único",
@@ -69,7 +69,7 @@ OC.L10N.register(
     "Backend" : "Processo Interno",
     "Local" : "Local",
     "Root" : "Raiz",
-    "Team invite" : "Convite da equipe",
+    "Team invite" : "Convite de equipe",
     "Federated" : "Federado",
     "Mount point" : "Ponto de montagem",
     "Nextcloud Account" : "Conta Nextcloud",
@@ -100,14 +100,14 @@ OC.L10N.register(
     "%s shared multiple files with \"%s\"." : "%s compartilhou vários arquivos com \"%s\".",
     "%s shared multiple files with you." : "%s compartilhou vários arquivos com você. ",
     "Boot up" : "Inicializar",
-    "Nextcloud Initialization" : "Nextcloud Initialization",
-    "Circles App Initialization" : "Inicialização do aplicativo Círculos",
+    "Nextcloud Initialization" : "Inicialização do Nextcloud",
+    "Circles App Initialization" : "Inicialização do Aplicativo Círculos",
     "Fresh installation status" : "Novo status de instalação",
     "Building Local Database" : "Construindo banco de dados local",
     "Testing Basic Circle Creation" : "Teste básico de criação de círculo",
     "Adding local users and moderators" : "Adicionando usuários locais e moderadores",
     "Show all teams" : "Mostrar todas as equipes",
-    "Create a new team" : "Crie uma nova equipe",
+    "Create a new team" : "Criar uma nova equipe",
     "Files" : "Arquivos",
     "This feature is not available for personal circles" : "Este recurso não está disponível para círculos pessoais",
     "The team is not federated" : "A equipe não é federada",
@@ -121,10 +121,10 @@ OC.L10N.register(
     "You have been blocked from this circle" : "Você foi bloqueado neste círculo",
     "The account is already a member of this circle" : "A conta já é membro deste círculo",
     "The account has already been invited into this circle" : "A conta já foi convidada para este círculo",
-    "%s (Team owned by %s)" : "%s(Equipe de propriedade de %s)",
-    "You are now a member of the Team \"%2$s\"" : "Agora você é um membro da equipe \"%2$s\"",
-    "You have been invited by %1$s into the Team \"%2$s\"" : "Você foi convidado por %1$s para a equipe \"%2$s\"",
-    "%1$s sent a request to be a member of the Team \"%2$s\"" : "%1$s enviou uma solicitação para ser um membro da equipe \"%2$s\"",
+    "%s (Team owned by %s)" : "%s (Equipe de propriedade de %s)",
+    "You are now a member of the Team \"%2$s\"" : "Agora você é um membro da Equipe \"%2$s\"",
+    "You have been invited by %1$s into the Team \"%2$s\"" : "Você foi convidado por %1$s para fazer parte da equipe \"%2$s\"",
+    "%1$s sent a request to be a member of the Team \"%2$s\"" : "%1$s enviou uma solicitação para ser um membro da Equipe \"%2$s\"",
     "Accept" : "Aceitar",
     "Refuse" : "Recusar",
     "Leave the team" : "Deixar a equipe",
@@ -140,19 +140,19 @@ OC.L10N.register(
     "Password to access content" : "Senha para acessar o conteúdo",
     "This item is already shared with this team" : "Este item já está compartilhado com esta equipe",
     "Bring cloud-users closer together." : "Reúna os usuários da nuvem.",
-    "Teams allows people to create their own groups of people/colleagues/friends.\nThose groups of people can then be used by any other app for sharing purpose." : "O Teams permite que as pessoas criem seus próprios grupos de pessoas/colegas/amigos. \nEsses grupos de pessoas podem então ser usados ​​por qualquer outro aplicativo para fins de compartilhamento.",
+    "Teams allows people to create their own groups of people/colleagues/friends.\nThose groups of people can then be used by any other app for sharing purpose." : "O Equipes permite que as pessoas criem seus próprios grupos de pessoas/colegas/amigos. \nEsses grupos de pessoas podem então ser usados ​​por qualquer outro aplicativo para fins de compartilhamento.",
     "No files in here" : "Nenhum arquivo aqui",
     "No entries found in this folder" : "Sem entradas nesta pasta",
     "Name" : "Nome",
     "Size" : "Tamanho",
     "Modified" : "Modificado",
     "Teams' files" : "Arquivos das equipes",
-    "Select team to filter by" : "Selecione a equipe para filtrar",
+    "Select team to filter by" : "Selecione uma equipe para filtrar",
     "No teams found" : "Nenhuma equipe encontrada",
     "Please select teams to filter by" : "Selecione equipes para filtrar",
     "No files found for the selected teams" : "Nenhum arquivo encontrado para as equipes selecionadas",
     "{author} added team {member} has been added as member to {circle}" : "{author} adicionou a equipe {member} como membro de {circle}",
-    "Shared to Circles" : "Compartilhar com Círculos",
+    "Shared to Circles" : "Compartilhado com Círculos",
     "You are now a member of the Circle \"%2$s\"" : "Agora você é membro do Círculo \"%2$s\"",
     "You have been invited by %1$s into the Circle \"%2$s\"" : "Você foi convidado por %1$s para o Círculo \"%2$s\"",
     "%1$s sent a request to be a member of the Circle \"%2$s\"" : "%1$s solicitou ser membro do Círculo \"%2$s\"",
