@@ -306,6 +306,9 @@ OC.L10N.register(
     "Send reminder notifications to calendar sharees as well" : "Envia també notificacions de recordatori als usuaris amb qui s'ha compartit el calendari",
     "Reminders are always sent to organizers and attendees." : "Sempre s'envien recordatoris als organitzadors i als assistents.",
     "Enable notifications for events via push" : "Habilita les notificacions automàtiques per als esdeveniments",
+    "Cancel" : "Cancel·la",
+    "Import" : "Importa",
+    "Error while saving settings" : "S'ha produït un error en desar els paràmetres",
     "There was an error updating your attendance status." : "S'ha produït un error en actualitzar l'estat d'assistència.",
     "Please contact the organizer directly." : "Contacteu amb l'organització directament.",
     "Are you accepting the invitation?" : "Accepteu la invitació?",
