@@ -250,6 +250,9 @@ OC.L10N.register(
     "Completed on %s" : "Fuldført den %s",
     "Due on %s by %s" : "Forfalder på %s til %s",
     "Due on %s" : "Forfalder på %s",
+    "System Address Book" : "System adressebog",
+    "The system address book contains contact information for all users in your instance." : "System adressebogen indeholder kontaktoplysninger for alle brugere i din instans.",
+    "Enable System Address Book" : "Aktiver System adressebog",
     "DAV system address book" : "DAV system adressebog",
     "No outstanding DAV system address book sync." : "Ingen udestående synkronisering af DAV-systemets adressebog.",
     "The DAV system address book sync has not run yet as your instance has more than 1000 users or because an error occurred. Please run it manually by calling \"occ dav:sync-system-addressbook\"." : "DAV-systemets adressebogssynkronisering er ikke kørt endnu, da din instans har mere end 1000 brugere, eller fordi der opstod en fejl. Kør det manuelt ved at kalde \"occ dav:sync-system-addressbook\".",
@@ -303,6 +306,19 @@ OC.L10N.register(
     "Send reminder notifications to calendar sharees as well" : "Send også påmindelsesmeddelelser til kalenderdelinger",
     "Reminders are always sent to organizers and attendees." : "Påmindelser sendes altid til arrangører og deltagere.",
     "Enable notifications for events via push" : "Aktiver notifikationer for begivenheder via push",
+    "Cancel" : "Annuller",
+    "Import" : "Importer",
+    "Error while saving settings" : "Der opstod en fejl under lagring af indstillinger",
+    "Contact reset successfully" : "Kontakten blev nulstillet",
+    "Error while resetting contact" : "Fejl under nulstilling af kontakt",
+    "Contact imported successfully" : "Kontakten blev importeret",
+    "Error while importing contact" : "Fejl under import af kontakt",
+    "Example Content" : "Eksempelindhold",
+    "Set example content to be created on new user first login." : "Indstil eksempel på indhold, der skal oprettes ved ny brugers første login.",
+    "Import contact" : "Importer kontakt",
+    "Reset to default contact" : "Nulstil til standardkontakt",
+    "Import contacts" : "Importer kontakter",
+    "Importing a new .vcf file will delete the existing default contact and replace it with the new one. Do you want to continue?" : "Import af en ny .vcf-fil vil slette den eksisterende standardkontakt og erstatte den med den nye. Vil du fortsætte?",
     "There was an error updating your attendance status." : "Der opstod en fejl under opdatering af din fremmødestatus.",
     "Please contact the organizer directly." : "Kontakt venligst arrangøren direkte.",
     "Are you accepting the invitation?" : "Accepter du invitationen?",
