@@ -186,9 +186,9 @@ OC.L10N.register(
     "November" : "November",
     "December" : "Dezember",
     "First" : "Erste",
-    "Second" : "2.",
-    "Third" : "3.",
-    "Fourth" : "4.",
+    "Second" : "Zweite",
+    "Third" : "Dritte",
+    "Fourth" : "Vierte",
     "Fifth" : "Fünften",
     "Last" : "Letzte",
     "Second Last" : "Vorletztes",
@@ -255,11 +255,11 @@ OC.L10N.register(
     "Enable System Address Book" : "Systemadressbuch aktivieren",
     "DAV system address book" : "DAV-Systemadressbuch",
     "No outstanding DAV system address book sync." : "Keine ausstehende Synchronisierung des DAV-Systemadressbuchs",
-    "The DAV system address book sync has not run yet as your instance has more than 1000 users or because an error occurred. Please run it manually by calling \"occ dav:sync-system-addressbook\"." : "Die Synchronisierung des DAV-Systemadressbuchs wurde noch nicht ausgeführt, da deine Instanz mehr als 1000 Benutzer hat oder weil ein Fehler aufgetreten ist. Bitte führe sie manuell aus, indem du \"occ dav:sync-system-addressbook\" ausführst.",
+    "The DAV system address book sync has not run yet as your instance has more than 1000 users or because an error occurred. Please run it manually by calling \"occ dav:sync-system-addressbook\"." : "Die Synchronisierung des DAV-Systemadressbuchs wurde noch nicht ausgeführt, da diese Instanz mehr als 1000 Benutzer hat oder weil ein Fehler aufgetreten ist. Bitte manuell ausführen, mittels \"occ dav:sync-system-addressbook\".",
     "WebDAV endpoint" : "WebDAV-Endpunkt",
-    "Could not check that your web server is properly set up to allow file synchronization over WebDAV. Please check manually." : "Es konnte nicht überprüft werden, ob dein Webserver ordnungsgemäß eingerichtet ist, um Dateisynchronisation über WebDAV zu ermöglichen. Bitte überprüfe dies manuell.",
-    "Your web server is not yet properly set up to allow file synchronization, because the WebDAV interface seems to be broken." : "Dein Webserver ist noch nicht hinreichend für Datei-Synchronisierung konfiguriert, da die WebDAV-Schnittstelle vermutlich nicht funktioniert.",
-    "Your web server is properly set up to allow file synchronization over WebDAV." : "Dein Webserver ist ordnungsgemäß eingerichtet um Dateisynchronisation über WebDAV zu ermöglichen.",
+    "Could not check that your web server is properly set up to allow file synchronization over WebDAV. Please check manually." : "Es konnte nicht überprüft werden, ob der Webserver ordnungsgemäß eingerichtet ist, um Dateisynchronisation über WebDAV zu ermöglichen. Bitte dies manuell überprüfen.",
+    "Your web server is not yet properly set up to allow file synchronization, because the WebDAV interface seems to be broken." : "Der Webserver ist noch nicht hinreichend für Datei-Synchronisierung konfiguriert, da die WebDAV-Schnittstelle vermutlich nicht funktioniert.",
+    "Your web server is properly set up to allow file synchronization over WebDAV." : "Der Webserver ist ordnungsgemäß eingerichtet um Dateisynchronisation über WebDAV zu ermöglichen.",
     "Migrated calendar (%1$s)" : "Migrierter Kalender (%1$s)",
     "Calendars including events, details and attendees" : "Kalender mit Terminen, Details und Teilnehmern",
     "Contacts and groups" : "Kontakte und Gruppen",
@@ -273,7 +273,7 @@ OC.L10N.register(
     "Out of office replacement (optional)" : "Abwesenheitsvertretung (optional)",
     "Name of the replacement" : "Name der Vertretung",
     "No results." : "Keine Ergebnisse",
-    "Start typing." : "Beginne mit Schreiben",
+    "Start typing." : "Mit dem Schreiben beginnen.",
     "Short absence status" : "Kurze Abwesenheits Meldung",
     "Long absence Message" : "Lange Abwesenheits Meldung",
     "Save" : "Speichern",
@@ -306,6 +306,19 @@ OC.L10N.register(
     "Send reminder notifications to calendar sharees as well" : "Erinnerungsbenachrichtigungen auch an die freigegebenen Kalender senden",
     "Reminders are always sent to organizers and attendees." : "Erinnerungen werden immer an Organisatoren und Teilnehmer gesendet.",
     "Enable notifications for events via push" : "Benachrichtigungen für Termine per Push aktivieren",
+    "Cancel" : "Abbrechen",
+    "Import" : "Importieren",
+    "Error while saving settings" : "Fehler beim Speichern der Einstellungen",
+    "Contact reset successfully" : "Kontakt erfolgreich zurückgesetzt",
+    "Error while resetting contact" : "Fehler beim Zurücksetzen des Kontakts",
+    "Contact imported successfully" : "Kontakt erfolgreich importiert",
+    "Error while importing contact" : "Fehler beim Import des Kontakts",
+    "Example Content" : "Beispielinhalt",
+    "Set example content to be created on new user first login." : "Beispielinhalte festlegen, die bei der ersten Anmeldung eines neuen Benutzers erstellt werden sollen.",
+    "Import contact" : "Kontakt importieren",
+    "Reset to default contact" : "Standardkontakt zurücksetzen",
+    "Import contacts" : "Kontakte importieren",
+    "Importing a new .vcf file will delete the existing default contact and replace it with the new one. Do you want to continue?" : "Durch das Importieren einer neuen VCF-Datei wird der vorhandene Standardkontakt gelöscht und durch den neuen ersetzt. Fortsetzen?",
     "There was an error updating your attendance status." : "Es ist ein Fehler beim Aktualisieren deines Teilnehmerstatus aufgetreten.",
     "Please contact the organizer directly." : "Bitte den Organisator direkt kontaktieren.",
     "Are you accepting the invitation?" : "Die Einladung annehmen?",
