@@ -250,6 +250,9 @@ OC.L10N.register(
     "Completed on %s" : "Dokončené %s",
     "Due on %s by %s" : "Termín od %s do %s",
     "Due on %s" : "Termín do %s",
+    "System Address Book" : "Systémový Adresár",
+    "The system address book contains contact information for all users in your instance." : "Systémový adresár obsahuje kontaktné informácie o všetkých užívateľov vo vašej inštancii.",
+    "Enable System Address Book" : "Povoliť systémový Adresár",
     "DAV system address book" : "Systémový DAV adresár",
     "No outstanding DAV system address book sync." : "Žiadna zostávajúca synchronizácia adresára systému DAV.",
     "The DAV system address book sync has not run yet as your instance has more than 1000 users or because an error occurred. Please run it manually by calling \"occ dav:sync-system-addressbook\"." : "DAV synchronizácia systémového adresára ešte nebola spustená, pretože vaša inštancia má viac ako 1000 užívateľov alebo sa vyskytla chyba. Prosím, spustite ju manuálne volaním \"occ dav:sync-system-addressbook\".",
@@ -303,6 +306,19 @@ OC.L10N.register(
     "Send reminder notifications to calendar sharees as well" : "Posielať upozornenia na pripomienky aj zdieľaným osobám v kalendári",
     "Reminders are always sent to organizers and attendees." : "Upozornenia sa vždy posielajú organizátorom a účastníkom.",
     "Enable notifications for events via push" : "Zapnúť oznámenia o udalostiach prostredníctvom technológie push.",
+    "Cancel" : "Zrušiť",
+    "Import" : "Import",
+    "Error while saving settings" : "Chyba pri ukladaní nastavení",
+    "Contact reset successfully" : "Kontakt bol úspešne resetovaný",
+    "Error while resetting contact" : "Chyba počas resetovania kontaktu ",
+    "Contact imported successfully" : "Kontakt bol úspešne importovaný",
+    "Error while importing contact" : "Chyba pri importovaní kontaktu",
+    "Example Content" : "Príklad Obsahu",
+    "Set example content to be created on new user first login." : "Nastavte vzorový obsah, ktorý sa vytvorí pri prvom prihlásení nového používateľa.",
+    "Import contact" : "Importovať kontakt",
+    "Reset to default contact" : "Resetovať na predvolený kontakt",
+    "Import contacts" : "Importovať kontakty",
+    "Importing a new .vcf file will delete the existing default contact and replace it with the new one. Do you want to continue?" : "Importovaním nového súboru .vcf sa vymaže existujúci predvolený kontakt a nahradí sa novým. Chcete pokračovať?",
     "There was an error updating your attendance status." : "Nastal problém pri aktualizácii Vašej účasti.",
     "Please contact the organizer directly." : "Prosím kontaktujte priamo organizátora.",
     "Are you accepting the invitation?" : "Príjmate pozvánku?",
