@@ -214,6 +214,9 @@ OC.L10N.register(
     "Send reminder notifications to calendar sharees as well" : "Pošiljanje opomnikov tudi naročnikom koledarja.",
     "Reminders are always sent to organizers and attendees." : "Opomniki bodo vedno poslani organizatorjem in udeležencem.",
     "Enable notifications for events via push" : "Omogoči potisna obvestila za dogodke",
+    "Cancel" : "Prekliči",
+    "Import" : "Uvozi",
+    "Error while saving settings" : "Prišlo je do napake med shranjevanjem nastavitev",
     "There was an error updating your attendance status." : "Prišlo je do napake med posodabljanjem vaše udeležbe.",
     "Please contact the organizer directly." : "Z organizatorjem stopite neposredno v stik.",
     "Are you accepting the invitation?" : "Ali želite sprejeti povabilo?",
