@@ -306,6 +306,19 @@ OC.L10N.register(
     "Send reminder notifications to calendar sharees as well" : "Skicka även påminnelser till kalenderdeltagare",
     "Reminders are always sent to organizers and attendees." : "Påminnelser skickas alltid till arrangörer och deltagare.",
     "Enable notifications for events via push" : "Aktivera notiser för händelser via push",
+    "Cancel" : "Avbryt",
+    "Import" : "Importera",
+    "Error while saving settings" : "Fel vid sparande av inställningar",
+    "Contact reset successfully" : "Kontakten har återställts",
+    "Error while resetting contact" : "Fel vid återställning av kontakt",
+    "Contact imported successfully" : "Kontakten har importerats",
+    "Error while importing contact" : "Fel vid import av kontakt",
+    "Example Content" : "Exempelinnehåll",
+    "Set example content to be created on new user first login." : "Ställ in exempelinnehåll som ska skapas vid ny användares första inloggning.",
+    "Import contact" : "Importera kontakt",
+    "Reset to default contact" : "Återställ till standardkontakt",
+    "Import contacts" : "Importera kontakter",
+    "Importing a new .vcf file will delete the existing default contact and replace it with the new one. Do you want to continue?" : "Att importera en ny .vcf-fil kommer att radera den befintliga standardkontakten och ersätta den med den nya. Vill du fortsätta?",
     "There was an error updating your attendance status." : "Ett fel uppstod vid uppdatering av din närvarostatus.",
     "Please contact the organizer directly." : "Vänligen kontakta arrangören direkt.",
     "Are you accepting the invitation?" : "Acceptera inbjudan?",
