@@ -255,6 +255,9 @@ OC.L10N.register(
     "Send reminder notifications to calendar sharees as well" : "كالېندار ھەمبەھىرلىرىگىمۇ ئەسكەرتىش ئۇقتۇرۇشى ئەۋەتىڭ",
     "Reminders are always sent to organizers and attendees." : "ئەسكەرتىش ھەمىشە تەشكىللىگۈچىلەر ۋە قاتناشقۇچىلارغا ئەۋەتىلىدۇ.",
     "Enable notifications for events via push" : "ئىتتىرىش ئارقىلىق ۋەقەلەرگە ئۇقتۇرۇشنى قوزغىتىڭ",
+    "Cancel" : "بىكار قىلىش",
+    "Import" : "ئەكىر",
+    "Error while saving settings" : "تەڭشەكلەرنى ساقلاش جەريانىدا خاتالىق",
     "There was an error updating your attendance status." : "قاتنىشىش ھالىتىڭىزنى يېڭىلاشتا خاتالىق كۆرۈلدى.",
     "Please contact the organizer directly." : "تەشكىللىگۈچى بىلەن بىۋاسىتە ئالاقىلىشىڭ.",
     "Are you accepting the invitation?" : "تەكلىپنى قوبۇل قىلامسىز؟",
