@@ -306,6 +306,19 @@ OC.L10N.register(
     "Send reminder notifications to calendar sharees as well" : "同时向日历共享者发送提醒通知",
     "Reminders are always sent to organizers and attendees." : "始终向组织者和与会者发出提醒。",
     "Enable notifications for events via push" : "启用推送事件通知",
+    "Cancel" : "取消",
+    "Import" : "导入",
+    "Error while saving settings" : "保存设置时出错",
+    "Contact reset successfully" : "联系人重置成功",
+    "Error while resetting contact" : "重置联系人时出错",
+    "Contact imported successfully" : "联系人导入成功",
+    "Error while importing contact" : "导入联系人时出错",
+    "Example Content" : "示例内容",
+    "Set example content to be created on new user first login." : "设置新用户首次登录时要创建的示例内容。",
+    "Import contact" : "导入联系人",
+    "Reset to default contact" : "重置为默认联系人",
+    "Import contacts" : "导入联系人",
+    "Importing a new .vcf file will delete the existing default contact and replace it with the new one. Do you want to continue?" : "导入新的 .vcf 文件将删除现有的默认联系人，并用新联系人替换。是否要继续？",
     "There was an error updating your attendance status." : "更新您的出席状态时出错。",
     "Please contact the organizer directly." : "请直接联系组织者。",
     "Are you accepting the invitation?" : "您是否接受邀请？",
