@@ -331,6 +331,7 @@ OC.L10N.register(
     "_1 file and {folderCount} folder_::_1 file and {folderCount} folders_" : ["1 fil og {folderCount} mapper","1 fil og {folderCount} mapper"],
     "_{fileCount} file and 1 folder_::_{fileCount} files and 1 folder_" : ["{fileCount} fil og 1 mapper","{fileCount} filer og 1 mapper"],
     "{fileCount} files and {folderCount} folders" : "{fileCount} filer og {folderCount} mapper",
+    "_(%n hidden)_::_ (%n hidden)_" : ["(%n skjult)","(%n skjult)"],
     "Filename must not be empty." : "Filnavnet må ikke være tomt.",
     "\"{char}\" is not allowed inside a filename." : "\"{char}\" er ikke tilladt i et filnavn.",
     "\"{segment}\" is a reserved name and not allowed for filenames." : "\"{segment}\" er et reserveret navn og er ikke tilladt til filnavne.",
@@ -364,8 +365,8 @@ OC.L10N.register(
     "Upload cancelled." : "Upload afbrudt.",
     "Processing files …" : "Behandler filer...",
     "…" : "...",
-    "Unable to upload {filename} as it is a directory or has 0 bytes" : "Kan ikke upload {filename} da det er enten en mappe eller indholder 0 bytes.",
-    "Not enough free space, you are uploading {size1} but only {size2} is left" : "Der er ikke tilstrækkeligt friplads. Du uplaoder {size1} men der er kun {size2} tilbage",
+    "Unable to upload {filename} as it is a directory or has 0 bytes" : "Kan ikke uploade {filename} da det er enten en mappe eller indeholder 0 bytes.",
+    "Not enough free space, you are uploading {size1} but only {size2} is left" : "Der er ikke tilstrækkelig fri plads. Du uplaoder {size1} men der er kun {size2} tilbage",
     "Target folder \"{dir}\" does not exist any more" : "Destinationsmappen \"{dir}\" findes ikke længere",
     "An unknown error has occurred" : "En ukendt fejl er opstået",
     "File could not be uploaded" : "Filen kunne ikke uploades",
