@@ -235,6 +235,8 @@ OC.L10N.register(
     "Failed to convert files: {message}" : "Fehler beim Konvertieren der Dateien: {message}",
     "All files failed to be converted" : "Alle Dateien konnten nicht konvertiert werden",
     "One file could not be converted: {message}" : "Eine Datei konnte nicht konvertiert werden: {message}",
+    "_One file could not be converted_::_%n files could not be converted_" : ["Eine Datei konnte nicht konvertiert werden","%n Dateien konnten nicht konvertiert werden"],
+    "_One file successfully converted_::_%n files successfully converted_" : ["Eine Datei erfolgreich konvertiert","%n Dateien erfolgreich konvertiert"],
     "Files successfully converted" : "Dateien erfolgreich konvertiert",
     "Failed to convert files" : "Dateien konnten nicht konvertiert werden",
     "Converting file …" : "Datei wird konvertiert …",
@@ -329,6 +331,7 @@ OC.L10N.register(
     "_1 file and {folderCount} folder_::_1 file and {folderCount} folders_" : ["1 Datei und {folderCount} Ordner","1 Datei und {folderCount} Ordner"],
     "_{fileCount} file and 1 folder_::_{fileCount} files and 1 folder_" : ["{fileCount} Datei und 1 Ordner","{fileCount} Dateien und 1 Ordner"],
     "{fileCount} files and {folderCount} folders" : "{fileCount} Dateien und {folderCount} Ordner",
+    "_(%n hidden)_::_ (%n hidden)_" : ["(%n versteckt)","(%n versteckt)"],
     "Filename must not be empty." : "Dateiname darf nicht leer sein.",
     "\"{char}\" is not allowed inside a filename." : "\"{char}\" ist innerhalb eines Dateinamens nicht zulässig.",
     "\"{segment}\" is a reserved name and not allowed for filenames." : "\"{segment}\" ist ein reservierter Name und für Dateinamen nicht zulässig.",
