@@ -211,7 +211,9 @@ OC.L10N.register(
     "This year ({year})" : "Αυτό το έτος ({year})",
     "Last year ({year})" : "Το περασμένο έτος ({year})",
     "Documents" : "Έγγραφα",
+    "Presentations" : "Παρουσιάσεις",
     "Audio" : "Ήχος",
+    "Photos and images" : "Φωτογραφίες και εικόνες",
     "Videos" : "Βίντεο",
     "Created new folder \"{name}\"" : "Δημιουργήθηκε νέος φάκελος \"{name}\"",
     "Unable to initialize the templates directory" : "Δεν είναι δυνατή η προετοιμασία του καταλόγου προτύπων",
@@ -244,6 +246,7 @@ OC.L10N.register(
     "Files and folders you mark as favorite will show up here" : "Τα αρχεία και οι φάκελοι που σημειώνονται ως αγαπημένα θα εμφανιστούν εδώ",
     "All files" : "Όλα τα αρχεία",
     "List of your files and folders." : "Λίστα των αρχείων και φακέλων σας.",
+    "Personal files" : "Προσωπικά αρχεία",
     "List of your files and folders that are not shared." : "Λίστα αρχείων και φακέλων που δεν είναι κοινόχρηστα.",
     "No personal files found" : "Δε βρέθηκαν προσωπικά αρχεία",
     "Files that are not shared will show up here." : "Τα αρχεία που δεν είναι κοινόχρηστα θα εμφανίζονται εδώ.",
@@ -342,6 +345,7 @@ OC.L10N.register(
     "Go to the previous folder" : "Μετάβαση στον προηγούμενο φάκελο",
     "Open the files app settings" : "Ανοίξτε τις ρυθμίσεις της εφαρμογής αρχείων",
     "Unable to change the favourite state of the file" : "Αδυναμία αλλαγής αγαπημένης κατάστασης αρχείου",
+    "Edit file locally" : "Επεξεργασία αρχείου τοπικά",
     "Create new templates folder" : "Δημιουργία νέου φακέλου προτύπων",
     "List of favorites files and folders." : "Λίστα αγαπημένων αρχείων και φακέλων.",
     "Personal Files" : "Προσωπικά Αρχεία",
