@@ -193,6 +193,8 @@ OC.L10N.register(
     "Use this address to access your Files via WebDAV" : "Используйте этот адрес для подключения WebDAV",
     "If you have enabled 2FA, you must create and use a new app password by clicking here." : "Если вы включили двухфакторную аутентификацию, то нажмите здесь, чтобы создать пароль приложения.",
     "Warnings" : "Предупреждения",
+    "Prevent warning dialogs from open or reenable them." : "Предотвратить открытие диалоговых окон с предупреждениями или включить их повторно.",
+    "Show a warning dialog when changing a file extension." : "Показать диалоговое окно предупреждения при изменении расширения файла.",
     "Keyboard shortcuts" : "Сочетания клавиш",
     "Speed up your Files experience with these quick shortcuts." : "Ускорьте работу с файлами с помощью сочетаний клавиш.",
     "Open the actions menu for a file" : "Открыть меню действий для файла",
@@ -329,6 +331,7 @@ OC.L10N.register(
     "_1 file and {folderCount} folder_::_1 file and {folderCount} folders_" : ["один файл и {folderCount} папка","один файл и {folderCount} папки","один файл и {folderCount} папок","один файл и {folderCount} папки"],
     "_{fileCount} file and 1 folder_::_{fileCount} files and 1 folder_" : ["{fileCount} файл и одна папка","{fileCount} файла и одна папка","{fileCount} файлов и одна папка","{fileCount} файла и одна папка"],
     "{fileCount} files and {folderCount} folders" : "файлов: {fileCount}, папок: {folderCount}",
+    "_(%n hidden)_::_ (%n hidden)_" : ["(%n скрытый)","(%n скрытых)","(%n скрытых)","(%n скрытых)"],
     "Filename must not be empty." : "Имя файла не должно быть пустым.",
     "\"{char}\" is not allowed inside a filename." : "не допускается внутри имени файла.",
     "\"{segment}\" is a reserved name and not allowed for filenames." : "является зарезервированным именем и не допускается для имен файлов.",
