@@ -1,112 +1,11 @@
 OC.L10N.register(
     "files",
     {
-    "Storage is temporarily not available" : "Shramba trenutno ni na voljo",
-    "Storage invalid" : "Mesto shrambe ni veljavno",
-    "Unknown error" : "Neznana napaka",
-    "File could not be found" : "Datoteke ni mogoče najti",
-    "Move or copy" : "Premakni ali kopiraj",
-    "Download" : "Prejmi",
-    "Delete" : "Izbriši",
-    "Show list view" : "Pokaži seznamski pogled",
-    "Show grid view" : "Pokaži mrežni pogled",
-    "Home" : "Začetni pogled",
-    "Close" : "Zapri",
-    "Favorites" : "Priljubljene",
-    "Could not create folder \"{dir}\"" : "Mape »{dir}« ni mogoče ustvariti.",
-    "This will stop your current uploads." : "S tem bodo zaustavljena vsa pošiljanja v oblak.",
-    "Upload cancelled." : "Pošiljanje je preklicano.",
-    "Processing files …" : "Poteka obdelava datotek ...",
-    "…" : "...",
-    "Unable to upload {filename} as it is a directory or has 0 bytes" : "Datoteke {filename} ni mogoče poslati, saj je to mapa, ali pa je velikost datoteke 0 bajtov.",
-    "Not enough free space, you are uploading {size1} but only {size2} is left" : "Ni dovolj prostora. Velikost poslane datoteke je {size1}, na voljo pa je le {size2}.",
-    "Target folder \"{dir}\" does not exist any more" : "Ciljna mapa »{dir}« ne obstaja več.",
-    "Not enough free space" : "Ni dovolj prostora",
-    "An unknown error has occurred" : "Prišlo je do neznane napake!",
-    "Uploading …" : "Poteka pošiljanje ...",
-    "{loadedSize} of {totalSize} ({bitrate})" : "{loadedSize} od {totalSize} ({bitrate})",
-    "Uploading that item is not supported" : "Pošiljate te vrste predmeta ni podprto.",
-    "Target folder does not exist any more" : "Ciljna mapa ne obstaja več",
-    "Operation is blocked by access control" : "Opravilo je zaustavljeno prek nadzora dostopa",
-    "Error when assembling chunks, status code {status}" : "Napaka pri sestavljanju kosov datoteke, koda stanja je {status}",
-    "Actions" : "Dejanja",
-    "Rename" : "Preimenuj",
-    "Move" : "Premakni",
-    "Copy" : "Kopiraj",
-    "Choose target folder" : "Izbor ciljne mape",
-    "Open" : "Odpri",
-    "Delete file" : "Izbriši datoteko",
-    "Delete folder" : "Izbriši mapo",
-    "Disconnect storage" : "Odklopi shrambo",
-    "Leave this share" : "Zapusti to mesto souporabe",
-    "Could not load info for file \"{file}\"" : "Ni mogoče naložiti podatkov za datoteko »{file}«.",
-    "Files" : "Datoteke",
-    "Details" : "Podrobnosti",
-    "Pending" : "Na čakanju ...",
-    "Unable to determine date" : "Ni mogoče določiti datuma",
-    "This operation is forbidden" : "To dejanje ni dovoljeno!",
-    "This directory is unavailable, please check the logs or contact the administrator" : "Mapa ni na voljo. Preverite dnevnik in stopite v stik s skrbnikom sistema.",
-    "Could not move \"{file}\", target exists" : "Datoteke »{file}« ni mogoče premakniti, ker na ciljnem mestu z istim imenom že obstaja.",
-    "Could not move \"{file}\"" : "Datoteke »{file}« ni mogoče premakniti",
-    "copy" : "kopija",
-    "Could not copy \"{file}\", target exists" : "Datoteke »{file}« ni mogoče kopirati, ker ta že obstaja.",
-    "Could not copy \"{file}\"" : "Datoteke »{file}« ni mogoče kopirati.",
-    "Copied {origin} inside {destination}" : "Kopirano {origin} v {destination}",
-    "Copied {origin} and {nbfiles} other files inside {destination}" : "Kopirano {origin} in {nbfiles} ostale datoteke v {destination}",
-    "{newName} already exists" : "Ime {newName} že obstaja",
-    "Could not rename \"{fileName}\", it does not exist any more" : "Datoteke »{fileName}« ni mogoče preimenovati, ker ne obstaja več",
-    "The name \"{targetName}\" is already used in the folder \"{dir}\". Please choose a different name." : "Ime \"{targetName}\" je že v uporabi v mapi \"{dir}\". Izberati je treba drugačno ime.",
-    "Could not rename \"{fileName}\"" : "Datoteke »{fileName}« ni mogoče preimenovati",
-    "Could not create file \"{file}\"" : "Datoteke »{file}« ni mogoče ustvariti.",
-    "Could not create file \"{file}\" because it already exists" : "Datoteke »{file}« ni mogoče ustvariti, ker datoteka z istim imenom že obstaja.",
-    "Could not create folder \"{dir}\" because it already exists" : "Ni mogoče ustvariti mape »{dir}«, ker ta že obstaja",
-    "Could not fetch file details \"{file}\"" : "Ni mogoče pridobiti podrobnosti datoteke »{file}«.",
-    "Error deleting file \"{fileName}\"." : "Prišli je do napake med brisanjem datoteke »{fileName}«.",
-    "No search results in other folders for {tag}{filter}{endtag}" : "Za iskalni niz {tag}{filter}{endtag} ni zadetkov v nobeni mapi",
-    "Enter more than two characters to search in other folders" : "Vpišite več kot dva znaka za iskanje po drugih mapah",
-    "Name" : "Ime",
-    "Size" : "Velikost",
-    "Modified" : "Spremenjeno",
-    "_%n folder_::_%n folders_" : ["%n mapa","%n mapi","%n mape","%n mape"],
-    "_%n file_::_%n files_" : ["%n datoteka","%n datoteki","%n datoteke","%n datotek"],
-    "{dirs} and {files}" : "{dirs} in {files}",
-    "_including %n hidden_::_including %n hidden_" : ["vključujoč %n skrito","vključujoč %n skriti","vključujoč %n skrite","vključujoč %n skritih"],
-    "_Uploading %n file_::_Uploading %n files_" : ["Posodabljanje %n datoteke","Posodabljanje %n datotek","Posodabljanje %n datotek","Poteka posodabljanje %n datotek"],
-    "Select file range" : "Izbor obsega datotek",
-    "{used} of {quota} used" : "v uporabi je {used} od {quota}",
-    "{used} used" : "v uporabi: {used}·",
-    "\"{name}\" is an invalid file name." : "Ime »{name}« ni veljavno ime datoteke.",
-    "File name cannot be empty." : "Ime datoteke ne sme biti prazno polje.",
-    "\"/\" is not allowed inside a file name." : "znak » / « v imenu datoteke ni dovoljen.",
-    "\"{name}\" is not an allowed filetype" : "Ime »{name}« ni dovoljena vrsta datoteke.",
-    "Storage of {owner} is full, files cannot be updated or synced anymore!" : "Shramba uporabnika {owner} je polna, zato datotek ni več mogoče posodabljati in usklajevati!",
-    "Group folder \"{mountPoint}\" is full, files cannot be updated or synced anymore!" : "Skupinska mapa »{mountPoint}« je do konca zasedena, zato datotek ni mogoče več posodobiti in usklajevati!",
-    "External storage \"{mountPoint}\" is full, files cannot be updated or synced anymore!" : "Zunanja shramba »{mountPoint}« je do konca zasedena, zato datotek ni mogoče več posodobiti in usklajevati!",
-    "Your storage is full, files cannot be updated or synced anymore!" : "Shramba je povsem napolnjena. Datotek ni več mogoče posodabljati in usklajevati!",
-    "Storage of {owner} is almost full ({usedSpacePercent}%)." : "Shramba uporabnika {owner} je do konca zasedena ({usedSpacePercent}%).",
-    "Group folder \"{mountPoint}\" is almost full ({usedSpacePercent}%)." : "Skupinska mapa »{mountPoint}« je skoraj do konca zasedena ({usedSpacePercent}%).",
-    "External storage \"{mountPoint}\" is almost full ({usedSpacePercent}%)." : "Zunanja shramba »{mountPoint}« je skoraj do konca zasedena ({usedSpacePercent}%).",
-    "Your storage is almost full ({usedSpacePercent}%)." : "Vaša shramba je skoraj do konca zasedena ({usedSpacePercent}%).",
-    "_matches \"{filter}\"_::_match \"{filter}\"_" : ["se skladajo s filtrom »{filter}«","se skladajo s filtroma »{filter}«","se skladajo s filtri »{filter}«","se skladajo s filtri »{filter}«"],
-    "View in folder" : "Pokaži v mapi",
-    "Copied!" : "Kopirano!",
-    "Copy direct link (only works for users who have access to this file/folder)" : "Kopiraj neposredno povezavo (za uporabnike, ki imajo dostop do datoteke ali mape)",
-    "Path" : "Pot",
-    "_%n byte_::_%n bytes_" : ["%n bajt","%n bajta","%n bajti","%n bajtov"],
-    "Favorited" : "Označeno kot priljubljeno",
-    "Favorite" : "Priljubljene",
-    "You can only favorite a single file or folder at a time" : "Kot priljubljeno je mogoče naenkrat označiti le eno datoteko ali mapo.",
-    "New folder" : "Nova mapa",
-    "Upload file" : "Pošlji datoteko",
-    "Recent" : "Nedavne",
-    "Not favorited" : "Ni priljubljeno",
-    "Remove from favorites" : "Odstrani iz priljubljenih",
-    "Add to favorites" : "Dodaj med priljubljene",
-    "An error occurred while trying to update the tags" : "Prišlo je do napake med posodabljanjem oznak",
     "Added to favorites" : "Dodano med priljubljene",
     "Removed from favorites" : "Odstranjeno iz priljubljenih",
     "You added {file} to your favorites" : "Med priljubljene dodate datoteko {file}",
     "You removed {file} from your favorites" : "Odstranite datoteko {file} od priljubljenih",
+    "Favorites" : "Priljubljene",
     "File changes" : "Spremembe datoteke",
     "Created by {user}" : "{user} ustvari predmet",
     "Changed by {user}" : "{user} spremeni predmet",
@@ -114,7 +13,7 @@ OC.L10N.register(
     "Restored by {user}" : "{user} obnovi predmet",
     "Renamed by {user}" : "{user} preimenuje predmet",
     "Moved by {user}" : "{user} premakne predmet",
-    "\"remote user\"" : "»Oddaljen uporabnik«",
+    "\"remote account\"" : "»oddaljeni račun«",
     "You created {file}" : "Ustvarite datoteko ali mapo {file}",
     "You created an encrypted file in {file}" : "Ustvarite šifrirano datoteko v {file}",
     "{user} created {file}" : "{user} ustvari datoteko {file}",
@@ -141,76 +40,321 @@ OC.L10N.register(
     "You moved {oldfile} to {newfile}" : "Premaknete datoteko {oldfile} v {newfile}",
     "{user} moved {oldfile} to {newfile}" : "{user} premakne datoteko {oldfile} v {newfile}",
     "A file has been added to or removed from your <strong>favorites</strong>" : "Datoteka je bila, ali dodana ali umaknjena iz <strong>priljubljenih</strong>",
+    "Files" : "Datoteke",
     "A file or folder has been <strong>changed</strong>" : "<strong>Spremenjena</strong> je bila datoteka ali mapa",
     "A favorite file or folder has been <strong>changed</strong>" : "<strong>Spremenjena</strong> je bila priljubljena datoteka ali mapa",
-    "All files" : "Vse datoteke",
-    "Unlimited" : "Neomejeno",
+    "Failed to authorize" : "Overitev je spodletela",
+    "Invalid folder path" : "Neveljavna pot mape",
+    "Folder not found" : "Mape ni mogoče najti",
+    "No favorites" : "Ni priljubljenih predmetov",
     "Upload (max. %s)" : "Pošiljanje (omejitev %s)",
     "Accept" : "Sprejmi",
     "Reject" : "Zavrni",
     "Incoming ownership transfer from {user}" : "Vpisana je zahteva za prenos lastništva uporabnika {user}",
     "Do you want to accept {path}?\n\nNote: The transfer process after accepting may take up to 1 hour." : "Ali želite sprejeti pot {path}?\n\nOpomba: po sprejetju lahko prenos traja tudi več kot 1 uro.",
+    "Ownership transfer denied" : "Prenos lastništva je spodletel",
     "Ownership transfer failed" : "Prenos lastništva je spodletel",
-    "Your ownership transfer of {path} to {user} failed." : "Prenos vašega lastništva {path} na {user} je spodletelo",
-    "The ownership transfer of {path} from {user} failed." : "Prenos lastništva {path} na {user} je spodletelo",
+    "Your ownership transfer of {path} to {user} failed." : "Prenos lastništva mesta {path} na uporabnika {user} je spodletel.",
+    "The ownership transfer of {path} from {user} failed." : "Prenos lastništva mesta {path} na uporabnika {user} je spodletel.",
     "Ownership transfer done" : "Prenos lastništva je uspešno končan",
-    "Your ownership transfer of {path} to {user} has completed." : "Prenos vašega lastništva {path} na uporabnika {user} je končan.",
-    "The ownership transfer of {path} from {user} has completed." : "Prenos lastništva {path} z uporabnika {user} je končan.",
+    "Your ownership transfer of {path} to {user} has completed." : "Prenos lastništva poti {path} na uporabnika {user} je končan.",
+    "The ownership transfer of {path} from {user} has completed." : "Prenos lastništva poti {path} z uporabnika {user} je končan.",
     "in %s" : "v %s",
+    "Files compatibility" : "Skladnost datotek",
+    "Enforce Windows compatibility" : "Vsili skladnost s sistemom Windows",
     "File Management" : "Upravljanje datotek",
-    "Transfer ownership of a file or folder" : "Prenos lastništva datoteke ali mape",
-    "Choose file or folder to transfer" : "Izbor datoteke ali mape za prenos",
-    "Change" : "Spremeni",
-    "New owner" : "Nov lastnik",
-    "Search users" : "Iskanje uporabnikov",
+    "Home" : "Začetni pogled",
+    "Target folder does not exist any more" : "Ciljna mapa ne obstaja več",
+    "Reload current directory" : "Ponovno naloži trenutno mapo",
+    "Go to the \"{dir}\" directory" : "Pojdi v mapo »{dir}«",
+    "Current directory path" : "Trenutna pot mape",
+    "Drag and drop files here to upload" : "Za pošiljanje potegnite in spustite datoteke na to mesto",
+    "Favorite" : "Priljubljene",
+    "File is loading" : "Poteka nalaganje datoteke",
+    "Folder is loading" : "mape",
+    "Filename" : "Ime datoteke",
+    "Folder name" : "Ime mape",
+    "This node is unavailable" : "To vozlišče ni na voljo.",
+    "Invalid filename." : "Neveljavno ime datoteke",
+    "Renamed \"{oldName}\" to \"{newName}\"" : "Preimenuj »{oldName}« to »{newName}«",
+    "Rename file" : "Preimenuj datoteke",
+    "Pending" : "Na čakanju ...",
+    "Clear filter" : "Počisti filter",
+    "Modified" : "Spremenjeno",
+    "Type" : "Vrsta",
+    "Active filters" : "Dejavni filtri",
+    "Remove filter" : "Odstrani filter",
+    "Total rows summary" : "Skupni povzetek vrstic",
+    "Name" : "Ime",
+    "Size" : "Velikost",
+    "\"{displayName}\" batch action executed successfully" : "Paketno dejanje »{displayName}« je uspešno izvedeno",
+    "\"{displayName}\" action failed" : "Dejanje »{displayName}« je spodletelo",
+    "Actions" : "Dejanja",
+    "(selected)" : "(izbrano)",
+    "List of files and folders." : "Seznam datotek in map",
+    "This list is not fully rendered for performance reasons. The files will be rendered as you navigate through the list." : "Seznam datotek ni v celoti izpisan zaradi zagotavljanja hitrosti in odzivnosti sistema. Predmeti se bodo dopolnjevali med brskanjem.",
+    "File not found" : "Datoteke ni mogoče najti",
+    "{count} selected" : "{count} izbranih",
+    "{usedQuotaByte} used" : "Zasedeno {usedQuotaByte}",
+    "{used} of {quota} used" : "V uporabi je {used} od {quota}",
+    "{relative}% used" : "Zasedeno {relative} %",
+    "Could not refresh storage stats" : "Ni mogoče osvežiti podatkov shrambe",
+    "Your storage is full, files can not be updated or synced anymore!" : "Shramba je povsem napolnjena. Datotek ni več mogoče posodabljati in usklajevati!",
+    "Storage information" : "Podrobnosti shrambe",
+    "Storage quota" : "Omejitev shrambe",
+    "New folder" : "Nova mapa",
+    "Create new folder" : "Ustvari novo mapo",
+    "This name is already in use." : "Vpisano uporabniško ime je že v uporabi",
+    "Create" : "Ustvari",
+    "Fill template fields" : "Zapolni polja predloge",
+    "Submit" : "Pošlji",
     "Choose a file or folder to transfer" : "Izbor datoteke ali mape za prenos",
     "Transfer" : "Prenos",
     "Transfer {path} to {userid}" : "Prenesi pot {path} k uporabniku {userid}",
     "Invalid path selected" : "Izbrana je neveljavna pot",
+    "Unknown error" : "Neznana napaka",
     "Ownership transfer request sent" : "Zahteva za prenos lastništva je poslana",
-    "Tags" : "Oznake",
-    "Unable to change the favourite state of the file" : "Ni mogoče spremeniti stanja priljubljenosti datoteke",
-    "Error while loading the file data" : "Prišlo je do napake med nalaganjem podatkov računa",
-    "Pick a template for {name}" : "Izbor predloge za {name}",
-    "Cancel" : "Prekliči",
-    "Create" : "Ustvari",
-    "Create a new file with the selected template" : "Ustvari novo datoteko z izbrano predlogo",
-    "Creating file" : "Poteka ustvarjanje datoteke",
-    "Blank" : "Prazno",
-    "Unable to create new file from template" : "Nove datoteke iz predloge ni mogoče ustvariti",
-    "Set up templates folder" : "Nastavitev mape predlog",
-    "Templates" : "Predloge",
-    "Unable to initialize the templates directory" : "Ni mogoče začeti mape predlog",
-    "%s used" : "Uporabljeno %s",
-    "%1$s of %2$s used" : "Uporabljeno %1$s od %2$s",
-    "Show hidden files" : "Pokaži skrite datoteke",
-    "Crop image previews" : "Obreži slike predogleda",
-    "WebDAV" : "WebDAV",
-    "Use this address to access your Files via WebDAV" : "Uporabite ta naslov za dostop do datotek prek WebDAV",
-    "Toggle %1$s sublist" : "Preklopi podseznam %1$s",
-    "Toggle grid view" : "Preklopi mrežni pogled",
+    "Cannot transfer ownership of a file or folder you do not own" : "Ni mogoče prenesti lastništva datotek in map, katerih niste lastnik",
+    "Transfer ownership of a file or folder" : "Prenos lastništva datoteke ali mape",
+    "Choose file or folder to transfer" : "Izbor datoteke ali mape za prenos",
+    "Change" : "Spremeni",
+    "New owner" : "Nov lastnik",
+    "Select file or folder to link to" : "Izbor datoteke ali mape za povezavo",
+    "Choose {file}" : "Izberite datoteko {file}",
+    "Share" : "·Souporaba·",
+    "Shared by link" : "V souporabi sk povezavo",
+    "Shared" : "V souporabi",
+    "Switch to list view" : "Preklopi na seznamski pogled",
+    "Switch to grid view" : "Preklopi na mrežni pogled",
+    "Upload was cancelled by user" : "Uporabnik je pošiljanje preklical",
+    "Not enough free space" : "Ni dovolj prostora",
+    "Operation is blocked by access control" : "Opravilo je zaustavljeno prek nadzora dostopa",
+    "Unknown error during upload" : "Med pošiljanjem je prišlo do neznane napake",
+    "\"{displayName}\" action executed successfully" : "Dejanje »{displayName}« je uspešno izvedeno",
+    "Loading current folder" : "Poteka nalaganje trenutne mape",
+    "Retry" : "Poskusi znova     ",
     "No files in here" : "V mapi ni datotek",
     "Upload some content or sync with your devices!" : "Uvozite vsebino, ali pa omogočite usklajevanje z napravami!",
+    "Go back" : "Skoči nazaj",
+    "Views" : "Pogledi",
+    "Files settings" : "Nastavitve datotek",
+    "Your files" : "Osebne datoteke",
+    "Open in files" : "Odpri datoteko v mapi",
+    "File cannot be accessed" : "Do datoteke dostop ni mogoč",
+    "Clipboard is not available" : "Odložišče ni na voljo",
+    "WebDAV URL copied to clipboard" : "Naslov URL WebDAV je kopiran v odložišče",
+    "Sort favorites first" : "Razvrsti najprej priljubljene",
+    "Sort folders before files" : "Razvrsti mape pred datotekami",
+    "Show hidden files" : "Pokaži skrite datoteke",
+    "Crop image previews" : "Obreži slike predogleda",
+    "Enable the grid view" : "Omogoči mrežni pogled",
+    "Enable folder tree" : "Omogoči drevesno strukturo map",
+    "Additional settings" : "Dodatne nastavitve",
+    "WebDAV" : "WebDAV",
+    "WebDAV URL" : "Naslov URL WebDAV",
+    "Copy to clipboard" : "Kopiraj v odložišče",
+    "Use this address to access your Files via WebDAV" : "Uporabite ta naslov za dostop do datotek z uporabo WebDAV",
+    "If you have enabled 2FA, you must create and use a new app password by clicking here." : "Če je omogočen sistem dvostopenjskega overjanja 2FA, je treba ustvariti in uporabiti novo geslo programa s klikom na to mesto.",
+    "Keyboard shortcuts" : "Tipkovne bližnjice",
+    "Selection" : "Izbor",
+    "Navigation" : "Krmarjenje",
+    "View" : "Pogled",
+    "You" : "Jaz",
+    "Error while loading the file data" : "Prišlo je do napake med nalaganjem podatkov računa",
+    "Remove from favorites" : "Odstrani iz priljubljenih",
+    "Add to favorites" : "Dodaj med priljubljene",
+    "Tags" : "Oznake",
+    "Blank" : "Prazno",
+    "Unable to create new file from template" : "Nove datoteke iz predloge ni mogoče ustvariti",
+    "Pick a template for {name}" : "Izbor predloge za {name}",
+    "Create a new file with the selected template" : "Ustvari novo datoteko z izbrano predlogo",
+    "Creating file" : "Poteka ustvarjanje datoteke",
+    "Deletion cancelled" : "Brisanje je bilo preklicano",
+    "Leave this share" : "Prekini to souporabo",
+    "Leave these shares" : "Prekini to souporabo",
+    "Disconnect storage" : "Odklopi shrambo",
+    "Disconnect storages" : "Odklopi shrambo",
+    "Delete permanently" : "Izbriši trajno",
+    "Delete and unshare" : "Izbriši in prekini souporabo",
+    "Delete file" : "Izbriši datoteko",
+    "Delete files" : "Izbriši datoteki",
+    "Delete folder" : "Izbriši mapo",
+    "Delete folders" : "Izbriši mape",
+    "Delete" : "Izbriši",
+    "Confirm deletion" : "Potrdi brisanje",
+    "Cancel" : "Prekliči",
+    "You cannot move a file/folder onto itself or into a subfolder of itself" : "Mape ali datoteke ni mogoče premakniti samo vase oziroma v podmapo same sebe",
+    "(copy)" : "(kopija)",
+    "(copy %n)" : "(kopija %n)",
+    "Move cancelled" : "Premikanje je bilo preklicano",
+    "A file or folder with that name already exists in this folder" : "Datoteka oziroma mapa s tem imenom v tej mapi že obstaja",
+    "The files are locked" : "Datoteke so zaklenjene",
+    "The file does not exist anymore" : "Datoteka ne obstaja več",
+    "Choose destination" : "Izbor ciljnega mesta",
+    "Copy to {target}" : "Kopiraj na {target}",
+    "Copy" : "Kopiraj",
+    "Move to {target}" : "Premakni na {target}",
+    "Move" : "Premakni",
+    "Move or copy operation failed" : "Opravilo kopiranja oziroma premikanja je spodletelo",
+    "Move or copy" : "Premakni ali kopiraj",
+    "Cancelled move or copy operation" : "Opravilo kopiranje in premikanja je preklicano",
+    "Open folder {displayName}" : "Odpri mapo {displayName}",
+    "Open in Files" : "Open in Files",
+    "Open file locally" : "Odpri datoteko krajevno",
+    "Failed to redirect to client" : "Preusmerjanje odjemalca je spodletelo",
+    "Open locally" : "Odpri krajevno",
+    "Rename" : "Preimenuj",
+    "Open details" : "Odpri podrobnosti",
+    "View in folder" : "Pokaži v mapi",
+    "Today" : "Danes",
+    "Last 7 days" : "Zadnjih 7 dni",
+    "Last 30 days" : "Zadnjih 30 dni",
+    "This year ({year})" : "Letos ({year})",
+    "Last year ({year})" : "Lansko leto ({year})",
+    "Documents" : "Dokumenti",
+    "Spreadsheets" : "Preglednice",
+    "Presentations" : "Predstavitve",
+    "PDFs" : "Dokumenti PDF",
+    "Folders" : "Mape",
+    "Audio" : "Zvočni posnetek",
+    "Photos and images" : "Slike in fotografije",
+    "Videos" : "Video posnetki",
+    "New folder creation cancelled" : "Ustvarjanje nove mape je bilo preklicano",
+    "Created new folder \"{name}\"" : "Ustvarjena je nova mapa »{name}«.",
+    "Unable to initialize the templates directory" : "Ni mogoče začeti mape predlog",
+    "Create templates folder" : "Ustvari mapo predlog",
+    "Templates" : "Predloge",
+    "New template folder" : "Nova mapa predlog",
+    "In folder" : "V mapi",
+    "Search in folder: {folder}" : "Išči v mapi: {folder}",
+    "No files to upload" : "Ni datotek za pošiljanje",
+    "Some files could not be uploaded" : "Nekaterih datotek ni bilo mogoče poslati",
+    "Files uploaded successfully" : "Datoteke so uspešno poslane v oblak",
+    "No files to process" : "Ni datotek za obdelavo",
+    "Some files could not be copied" : "Nekaterih datotek ni bilo mogoče kopirati",
+    "Some files could not be moved" : "Nekaterih datotek ni mogoče premakniti",
+    "Files copied successfully" : "Datoteke so uspešno kopirane",
+    "Files moved successfully" : "Datoteke so uspešno premaknjene",
+    "Conflicts resolution skipped" : "Razreševanje sporov je preklicano",
+    "Upload cancelled" : "Pošiljanje je bilo preklicano",
+    "This operation is forbidden" : "To dejanje ni dovoljeno!",
+    "This directory is unavailable, please check the logs or contact the administrator" : "Mapa ni na voljo. Preverite dnevnik in stopite v stik s skrbnikom sistema.",
+    "Storage is temporarily not available" : "Shramba trenutno ni na voljo",
+    "_{folderCount} folder_::_{folderCount} folders_" : ["{folderCount} mapa","{folderCount} mapi","{folderCount} mape","{folderCount} map"],
+    "_{fileCount} file_::_{fileCount} files_" : ["{fileCount} datoteka","{fileCount} datoteki","{fileCount} datoteke","{fileCount} datotek"],
+    "_1 file and {folderCount} folder_::_1 file and {folderCount} folders_" : ["1 datoteka in {folderCount} mapa","1 datoteka in {folderCount} mapi","1 datoteka in {folderCount} mape","1 datoteka in {folderCount} map"],
+    "_{fileCount} file and 1 folder_::_{fileCount} files and 1 folder_" : ["{fileCount} datoteka in 1 mapa","{fileCount} datoteki in 1 mapa","{fileCount} datoteke in 1 mapa","{fileCount} datotek in 1 mapa"],
+    "{fileCount} files and {folderCount} folders" : "{fileCount} datotek in {folderCount} map",
+    "Filename must not be empty." : "Ime datoteke ne sme biti prazno.",
+    "No favorites yet" : "Ni še dodanih priljubljenih predmetov",
+    "Files and folders you mark as favorite will show up here" : "Datoteke ali mape, ki so označene kot priljubljene, bodo zbrane na tem mestu.",
+    "All files" : "Vse datoteke",
+    "List of your files and folders." : "Seznam datotek in map.",
+    "All folders" : "Vse mape",
+    "No personal files found" : "Ni najdenih zasebnih datotek",
+    "Recent" : "Nedavne",
+    "List of recently modified files and folders." : "Seznam nedavno spremenjenih datotek in map.",
+    "No recently modified files" : "Ni nedavno spremenjenih datotek",
+    "Files and folders you recently modified will show up here." : "Nedavno spremenjene datoteke ali mape, bodo zbrane na tem mestu.",
     "No entries found in this folder" : "V tej mapi ni najdenih predmetov.",
     "Select all" : "izberi vse",
     "Upload too large" : "Prekoračena je omejitev dovoljene velikosti",
     "The files you are trying to upload exceed the maximum size for file uploads on this server." : "Datoteke, ki jih želite poslati, presegajo največjo dovoljeno velikost na strežniku.",
-    "No favorites yet" : "Ni še dodanih priljubljenih predmetov",
-    "Files and folders you mark as favorite will show up here" : "Datoteke ali mape, ki so označene kot priljubljene, bodo zbrane na tem mestu.",
-    "Deleted files" : "Izbrisane datoteke",
-    "Shares" : "Souporaba",
-    "Shared with others" : "V souporabi  z drugimi",
-    "Shared with you" : "V skupni rabi z vami",
-    "Shared by link" : "V souporabi sk povezavo",
-    "Deleted shares" : "Izbrisana mesta souporabe",
-    "Pending shares" : "Predmeti za souporabo na čakanju",
+    "File could not be found" : "Datoteke ni mogoče najti",
+    "Download" : "Prejmi",
+    "Show list view" : "Pokaži seznamski pogled",
+    "Show grid view" : "Pokaži mrežni pogled",
+    "Close" : "Zapri",
+    "Could not create folder \"{dir}\"" : "Mape »{dir}« ni mogoče ustvariti.",
+    "This will stop your current uploads." : "S tem bodo zaustavljena vsa pošiljanja v oblak.",
+    "Upload cancelled." : "Pošiljanje je preklicano.",
+    "Processing files …" : "Poteka obdelava datotek ...",
+    "…" : "...",
+    "Unable to upload {filename} as it is a directory or has 0 bytes" : "Datoteke {filename} ni mogoče poslati, saj je to mapa, ali pa je velikost datoteke 0 bajtov.",
+    "Not enough free space, you are uploading {size1} but only {size2} is left" : "Ni dovolj prostora. Velikost poslane datoteke je {size1}, na voljo pa je le {size2}.",
+    "Target folder \"{dir}\" does not exist any more" : "Ciljna mapa »{dir}« ne obstaja več.",
+    "An unknown error has occurred" : "Prišlo je do neznane napake!",
+    "File could not be uploaded" : "Datoteke ni mogoče poslati",
+    "Uploading …" : "Poteka pošiljanje ...",
+    "{remainingTime} ({currentNumber}/{total})" : "{remainingTime} ({currentNumber}/{total})",
+    "Uploading … ({currentNumber}/{total})" : "Pošiljanje … ({currentNumber}/{total})",
+    "{loadedSize} of {totalSize} ({bitrate})" : "{loadedSize} od {totalSize} ({bitrate})",
+    "Uploading that item is not supported" : "Pošiljate te vrste predmeta ni podprto.",
+    "Error when assembling chunks, status code {status}" : "Napaka pri sestavljanju kosov datoteke, koda stanja je {status}",
+    "Choose target folder" : "Izbor ciljne mape",
+    "Set reminder" : "Nastavi opomnik",
+    "Edit locally" : "Uredi krajevno",
+    "Open" : "Odpri",
+    "Could not load info for file \"{file}\"" : "Ni mogoče naložiti podatkov za datoteko »{file}«.",
+    "Details" : "Podrobnosti",
+    "Please select tag(s) to add to the selection" : "Izbrati je treba oznake za dodajanje k izbiri",
+    "Apply tag(s) to selection" : "Poteka uveljavljanje oznak za izbiro",
+    "Select directory \"{dirName}\"" : "Izberi mapo »{dirName}«",
+    "Select file \"{fileName}\"" : "Izberi datoteko »{fileName}«.",
+    "Unable to determine date" : "Ni mogoče določiti datuma",
+    "Could not move \"{file}\", target exists" : "Datoteke »{file}« ni mogoče premakniti, ker na ciljnem mestu z istim imenom že obstaja.",
+    "Could not move \"{file}\"" : "Datoteke »{file}« ni mogoče premakniti",
+    "copy" : "kopija",
+    "Could not copy \"{file}\", target exists" : "Datoteke »{file}« ni mogoče kopirati, ker ta že obstaja.",
+    "Could not copy \"{file}\"" : "Datoteke »{file}« ni mogoče kopirati.",
+    "Copied {origin} inside {destination}" : "Kopirano {origin} v {destination}",
+    "Copied {origin} and {nbfiles} other files inside {destination}" : "Kopirano {origin} in {nbfiles} ostale datoteke v {destination}",
+    "{newName} already exists" : "Ime {newName} že obstaja",
+    "Could not rename \"{fileName}\", it does not exist any more" : "Datoteke »{fileName}« ni mogoče preimenovati, ker ne obstaja več",
+    "The name \"{targetName}\" is already used in the folder \"{dir}\". Please choose a different name." : "Ime \"{targetName}\" je v mapi »{dir}« že v uporabi. Izbrati je treba drugačno ime.",
+    "Could not rename \"{fileName}\"" : "Datoteke »{fileName}« ni mogoče preimenovati",
+    "Could not create file \"{file}\"" : "Datoteke »{file}« ni mogoče ustvariti.",
+    "Could not create file \"{file}\" because it already exists" : "Datoteke »{file}« ni mogoče ustvariti, ker datoteka z istim imenom že obstaja.",
+    "Could not create folder \"{dir}\" because it already exists" : "Ni mogoče ustvariti mape »{dir}«, ker ta že obstaja",
+    "Could not fetch file details \"{file}\"" : "Ni mogoče pridobiti podrobnosti datoteke »{file}«.",
+    "Error deleting file \"{fileName}\"." : "Prišli je do napake med brisanjem datoteke »{fileName}«.",
+    "No search results in other folders for {tag}{filter}{endtag}" : "Za iskalni niz {tag}{filter}{endtag} ni zadetkov v nobeni mapi",
+    "Enter more than two characters to search in other folders" : "Vpišite več kot dva znaka za iskanje po drugih mapah",
+    "_%n folder_::_%n folders_" : ["%n mapa","%n mapi","%n mape","%n mape"],
+    "_%n file_::_%n files_" : ["%n datoteka","%n datoteki","%n datoteke","%n datotek"],
+    "{dirs} and {files}" : "{dirs} in {files}",
+    "_including %n hidden_::_including %n hidden_" : ["vključujoč %n skrito","vključujoč %n skriti","vključujoč %n skrite","vključujoč %n skritih"],
+    "You do not have permission to upload or create files here" : "Ni ustreznih dovoljenja za pošiljanje ali ustvarjanje novih datotek",
+    "_Uploading %n file_::_Uploading %n files_" : ["Posodabljanje %n datoteke","Posodabljanje %n datotek","Posodabljanje %n datotek","Poteka posodabljanje %n datotek"],
+    "New" : "Novo",
+    "New file/folder menu" : "Nov meni datoteke/mape",
+    "Select file range" : "Izbor obsega datotek",
+    "{used}%" : "{used} %",
+    "{used} used" : "V uporabi je {used}",
+    "\"{name}\" is an invalid file name." : "Ime »{name}« ni veljavno ime datoteke.",
+    "File name cannot be empty." : "Ime datoteke ne sme biti prazno polje.",
+    "\"/\" is not allowed inside a file name." : "znak » / « v imenu datoteke ni dovoljen.",
+    "\"{name}\" is not an allowed filetype" : "Ime »{name}« ni dovoljena vrsta datoteke.",
+    "Storage of {owner} is full, files cannot be updated or synced anymore!" : "Shramba uporabnika {owner} je polna, zato datotek ni več mogoče posodabljati in usklajevati!",
+    "Group folder \"{mountPoint}\" is full, files cannot be updated or synced anymore!" : "Skupinska mapa »{mountPoint}« je do konca zasedena, zato datotek ni mogoče več posodobiti in usklajevati!",
+    "External storage \"{mountPoint}\" is full, files cannot be updated or synced anymore!" : "Zunanja shramba »{mountPoint}« je do konca zasedena, zato datotek ni mogoče več posodobiti in usklajevati!",
+    "Your storage is full, files cannot be updated or synced anymore!" : "Shramba je povsem napolnjena. Datotek ni več mogoče posodabljati in usklajevati!",
+    "Storage of {owner} is almost full ({usedSpacePercent}%)." : "Shramba uporabnika {owner} je do konca zasedena ({usedSpacePercent}%).",
+    "Group folder \"{mountPoint}\" is almost full ({usedSpacePercent}%)." : "Skupinska mapa »{mountPoint}« je skoraj do konca zasedena ({usedSpacePercent}%).",
+    "External storage \"{mountPoint}\" is almost full ({usedSpacePercent}%)." : "Zunanja shramba »{mountPoint}« je skoraj do konca zasedena ({usedSpacePercent}%).",
+    "Your storage is almost full ({usedSpacePercent}%)." : "Vaša shramba je skoraj do konca zasedena ({usedSpacePercent}%).",
+    "_matches \"{filter}\"_::_match \"{filter}\"_" : ["se skladajo s filtrom »{filter}«","se skladajo s filtroma »{filter}«","se skladajo s filtri »{filter}«","se skladajo s filtri »{filter}«"],
+    "Direct link was copied (only works for people who have access to this file/folder)" : "Kopirana je neposredna povezava (za uporabnike, ki imajo dostop do datoteke ali mape)",
+    "Path" : "Pot",
+    "_%n byte_::_%n bytes_" : ["%n bajt","%n bajta","%n bajti","%n bajtov"],
+    "Favorited" : "Označeno kot priljubljeno",
+    "Copy direct link (only works for people who have access to this file/folder)" : "Kopiraj neposredno povezavo (za uporabnike, ki imajo dostop do datoteke ali mape)",
+    "Upload file" : "Pošlji datoteko",
+    "Not favorited" : "Ni priljubljeno",
+    "An error occurred while trying to update the tags" : "Prišlo je do napake med posodabljanjem oznak",
+    "Storage informations" : "Podrobnosti shrambe",
+    "Choose file" : "Izbor datotek",
+    "Go to the previous folder" : "Skoči na predhodno mapo",
+    "Open the files app settings" : "Odpri nastavitve programa Datoteke",
+    "Unable to change the favourite state of the file" : "Ni mogoče spremeniti stanja priljubljenosti datoteke",
+    "Edit file locally" : "Uredi datoteko krajevno",
+    "Edit online" : "Uredi na spletu",
+    "Create new templates folder" : "Ustvari novo začasno mapo",
+    "List of favorites files and folders." : "Seznam priljubljenih datotek in map.",
+    "Personal Files" : "Osebne datoteke",
     "Text file" : "Besedilna datoteka",
     "New text file.txt" : "nova_datoteka.txt",
-    "Select" : "Izbor",
-    "You don’t have permission to upload or create files here" : "Ni ustreznih dovoljenj za pošiljanje in ustvarjanje datotek na tem mestu.",
-    "New" : "Novo",
-    "Cannot transfer ownership of a file or folder you don't own" : "Ni mogoče prenesti lastništva datotek in map, katerih niste lastnik",
-    "%s%% of %s used" : "Uporabljeno %s%% od %s",
-    "Settings" : "Nastavitve"
+    "Submitting fields…" : "Poteka objavljanje vsebine polj ...",
+    "Filter filenames…" : "Filtriraj imena datotek ..."
 },
 "nplurals=4; plural=(n%100==1 ? 0 : n%100==2 ? 1 : n%100==3 || n%100==4 ? 2 : 3);");
