@@ -23,7 +23,7 @@ OC.L10N.register(
     "{actor} removed public link" : "{actor} вилучив(-ла) публічне посилання",
     "Public link of {actor} expired" : "Термін дії публічного посилання {actor} вичерпано",
     "You shared {file} as public link" : "Ви поділилися {file} за допомогою публічного посилання",
-    "You removed public link for {file}" : "Ви вилучили публічне посилання для файла {file}",
+    "You removed public link for {file}" : "Ви вилучили публічне посилання для {file}",
     "Public link expired for {file}" : "Термін дії посилання сплив для файла {file}",
     "{actor} shared {file} as public link" : "{actor} надав(-ла) доступ до файлу {file} через публічне посилання",
     "{actor} removed public link for {file}" : "{actor} вилучив(-ла) публічне посилання для {file}",
@@ -117,7 +117,7 @@ OC.L10N.register(
     "We would like to kindly remind you that you have not yet uploaded any files to the shared folder." : "Нагадування про те, що ви ще не завантажили жодного файлу до спільного каталогу.",
     "Open \"%s\"" : "Відкрити \"%s\"",
     "People" : "Користувачі",
-    "Filter accounts" : "Фільтр користувачів",
+    "Filter accounts" : "Вибрати користувачів",
     "The request will expire on {date} at midnight and will be password protected." : "Термін дії запиту спливе опівночі {date}, запит буде захищено паролем. ",
     "The request will expire on {date} at midnight." : "Термін дії запиту спливе опівночі {date}.",
     "The request will be password protected." : "Запит буде захищено паролем",
@@ -140,7 +140,7 @@ OC.L10N.register(
     "_{count} email address already added_::_{count} email addresses already added_" : ["{count} ел. адресу вже додано","{count} ел. адреси вже додано","{count} ел. адрес вже додано","{count} ел. адрес вже додано"],
     "_{count} email address added_::_{count} email addresses added_" : ["{count} ел. адресу додано","{count} ел. адреси додано","{count} ел. адрес додано","{count} ел. адрес додано"],
     "You can now share the link below to allow people to upload files to your directory." : "Тепер ви можете поділитися посиланням, за яким користувачі матимуть змогу завантажити файли до вашого каталогу. ",
-    "Share link" : "Посилання на спільний доступ",
+    "Share link" : "Передати у публічний доступ",
     "Copy to clipboard" : "Копіювати до буферу обміну",
     "Send link via email" : "Надіслати посилання електронною поштою",
     "Enter an email address or paste a list" : "Зазначте ел. адресу або список адрес",
@@ -218,9 +218,9 @@ OC.L10N.register(
     "Error, please enter proper password and/or expiration date" : "Помилка. Будь ласка, зазначте правильний пароль та/або термін дії",
     "Link share created" : "Створено посилання на спільний ресурс",
     "Error while creating the share" : "Помилка під час створення спільного ресурсу",
-    "Please enter the following required information before creating the share" : "Будь ласка, введіть таку інформацію перед наданням спільного доступу",
+    "Please enter the following required information before creating the share" : "Зазначте такі дані перед наданням у публічний доступ",
     "Password protection (enforced)" : "Захист паролем (обов'язково)",
-    "Password protection" : "Password protection",
+    "Password protection" : "Захист паролем",
     "Enter a password" : "Зазначте пароль",
     "Enable link expiration (enforced)" : "Увімкнути термін дії посилання (примусово)",
     "Enable link expiration" : "Увімкнути термін дії посилання",
@@ -233,7 +233,7 @@ OC.L10N.register(
     "Create a new share link" : "Створити нове посилання спільного доступу",
     "Quick share options, the current selected is \"{selectedOption}\"" : "Швидкі параметри спільного доступу, зараз вибрано \"{selectedOption}\"",
     "View only" : "Лише перегляд",
-    "Can edit" : "Можна редагувати",
+    "Can edit" : "Може редагувати",
     "Custom permissions" : "Спеціальні дозволи",
     "Resharing is not allowed" : "Надання спільного доступу іншим не дозволяється",
     "Name or email …" : "Ім'я або електронна адреса …",
@@ -253,7 +253,7 @@ OC.L10N.register(
     "Search for internal recipients" : "Шукати внутрішніх отримувачів",
     "Note from" : "Примітка від",
     "Note:" : "Примітка:",
-    "File drop" : "Відкинути файл",
+    "File drop" : "Перетягнути файл",
     "Upload files to {foldername}." : "Завантажити файли до {foldername}.",
     "By uploading files, you agree to the terms of service." : "Завантаження файлів означає, що ви погоджуєтеся з умовами користування.",
     "View terms of service" : "Переглянути умови користування.",
@@ -393,10 +393,10 @@ OC.L10N.register(
     "Share note" : "Поділитися нотаткою",
     "Show list view" : "Подання списком",
     "Show grid view" : "Подання сіткою",
-    "Upload files to %s" : "Завантажувати файли до %s",
+    "Upload files to %s" : "Завантажити файли до %s",
     "%s shared a folder with you." : "%s поділив(-ла)ся з вами каталогом.",
     "Note" : "Нотатка",
-    "Select or drop files" : "Виберіть або перетягніть файли",
+    "Select or drop files" : "Вибрати або перетягнути файли",
     "Uploading files" : "Завантаження файлів",
     "Uploaded files:" : "Завантажені файли:",
     "By uploading files, you agree to the %1$sterms of service%2$s." : "Завантажуючи файли, ви погоджуєтеся з %1$sумовами користування%2$s.",
