@@ -122,6 +122,7 @@ OC.L10N.register(
     "Add photos to this place" : "Tilføj fotos til dette sted",
     "Cover photo for place {placeName}" : "Forsidefoto til sted {placeName}",
     "There is no place yet!" : "Der er endnu ikke noget sted!",
+    "Cover photo for shared album {albumName}" : "Forsidebillede til delt album {albumName}",
     "Back to tags overview" : "Tilbage til tags oversigt",
     "No photos with this tag yet" : "Endnu ingen fotos med dette tag",
     "No tags yet" : "Ingen tags endnu",
@@ -137,6 +138,7 @@ OC.L10N.register(
     "Failed to fetch collection." : "Kunne ikke hente samlingen.",
     "Failed to fetch collections list." : "Kunne ikke hente samlingslisten.",
     "Failed to fetch faces list." : "Kunne ikke hente ansigtslisten.",
+    "Error fetching files" : "Fejl ved hentning af filer",
     "All your media" : "Alle dine medier",
     "Album {title}" : "Album {title}",
     "Shared Albums" : "Delte albums",
@@ -147,6 +149,12 @@ OC.L10N.register(
     "{title}'s face" : "{title}'s ansigt",
     "{startDate} to {endDate}" : "{startDate} til {endDate}",
     "Details" : "Detaljer",
+    "Failed to rename {oldName} to {faceName}" : "Kunne ikke omdøbe {oldName} til {faceName}",
+    "Failed to delete {faceName}" : "Kunne ikke slette {faceName}",
+    "Failed to delete {fileId}" : "Kunne ikke slette {fileId}",
+    "Failed to delete {fileName}" : "Kunne ikke slette {fileName}",
+    "Failed to set favorite state for {fileId}" : "Kunne ikke indstille favorittilstand for {fileId}",
+    "Failed to set favorite state for {fileName}" : "Kunne ikke indstille favorittilstand for {fileName}",
     "Could not load photos folder" : "Kunne ikke indlæse fotomappe",
     "One of the source folders does not exists" : "En af kildemapperne eksisterer ikke",
     "Add" : "Tilføj"
