@@ -122,7 +122,6 @@ OC.L10N.register(
     "Add photos to this place" : "Ajouter des photos à ce lieu",
     "Cover photo for place {placeName}" : "Photo de couverture pour le lieu {nom du lieu}",
     "There is no place yet!" : "Il n’y a pas encore de lieu !",
-    "Cover photo for shared album {albumName}." : "Photo de couverture pour l’album partagé {albumName}.",
     "Back to tags overview" : "Retour à l’aperçu des étiquettes",
     "No photos with this tag yet" : "Pas de photo avec cette étiquette pour l’instant",
     "No tags yet" : "Aucune étiquette pour le moment",
@@ -148,12 +147,6 @@ OC.L10N.register(
     "{title}'s face" : "Visage de {title}",
     "{startDate} to {endDate}" : "{startDate} au {endDate}",
     "Details" : "Détails",
-    "Failed to rename {oldName} to {faceName}." : "Échec du renommage de {oldName} en {faceName}.",
-    "Failed to delete {faceName}." : "Échec de la suppression de {faceName}.",
-    "Failed to delete {fileId}." : "Échec de la suppression de {fileId}.",
-    "Failed to delete {fileName}." : "Échec de la suppression de {fileName}.",
-    "Failed to set favorite state for {fileId}." : "Impossible de définir l’état des favoris pour {fileId}.",
-    "Failed to set favorite state for {fileName}." : "Échec de la définition de l’état des favoris pour {fileName}.",
     "Could not load photos folder" : "Impossible de charger le dossier des photos",
     "One of the source folders does not exists" : "L’un des dossiers source n’existe pas",
     "Add" : "Ajouter"
