@@ -3,16 +3,16 @@ OC.L10N.register(
     {
     "Public link" : "Link público",
     "Photos" : "Fotos",
-    "On This Day" : "Neste dia",
+    "On This Day" : "Neste Dia",
     "Your memories under your control" : "Suas memórias sob seu controle",
-    "All media" : "Toda mídia",
+    "All media" : "Todas as mídias",
     "Videos" : "Vídeos",
     "Albums" : "Álbuns",
     "Collaborative albums" : "Álbuns colaborativos",
     "People" : "Pessoas",
     "Folders" : "Pastas",
     "Favorites" : "Favoritos",
-    "On this day" : "Nesse dia",
+    "On this day" : "Neste dia",
     "Shared with you" : "Compartilhado com você",
     "Tags" : "Etiquetas",
     "Places" : "Lugares",
@@ -33,73 +33,74 @@ OC.L10N.register(
     "Create a new album." : "Criar um novo álbum.",
     "Create new album" : "Criar novo álbum",
     "New album" : "Novo álbum",
-    "_%n item_::_%n photos and videos_" : ["%nitem","%nfotos e vídeos","%nfotos e vídeos"],
-    "Failed to fetch collaborators list." : "Falha ao buscar a lista de colaboradores.",
+    "_%n item_::_%n photos and videos_" : ["%n item","%n fotos e vídeos","%n fotos e vídeos"],
+    "Failed to fetch collaborators list." : "Falha ao obter a lista de colaboradores.",
     "Failed to update album." : "Falha ao atualizar álbum.",
     "Add people or groups who can edit your album" : "Adicione pessoas ou grupos que podem editar seu álbum",
     "Search people or groups" : "Pesquisar pessoas ou grupos",
-    "No recommendations. Start typing." : "Sem recomendações. Começe a digitar.",
+    "No recommendations. Start typing." : "Sem recomendações. Comece a digitar.",
     "Group" : "Grupo",
-    "Remove {collaboratorLabel} from the collaborators list" : "Remova {collaboratorLabel} da lista de colaboradores",
+    "Remove {collaboratorLabel} from the collaborators list" : "Remover {collaboratorLabel} da lista de colaboradores",
     "Copy the public link" : "Copiar link público",
     "Public link copied!" : "Link público copiado!",
     "Copy public link" : "Copiar link público",
-    "Delete the public link" : "Remover link público",
+    "Delete the public link" : "Excluir link público",
     "Create public link share" : "Criar compartilhamento de link público",
     "Share via public link" : "Compartilhar via link público",
     "This collection does not exist" : "Esta coleção não existe",
     "An error occurred" : "Ocorreu um erro",
     "No picture for this day" : "Nenhuma foto para este dia",
-    "Picture taken on this day will show up here." : "A foto tirada neste dia aparecerá aqui.",
+    "Picture taken on this day will show up here." : "Uma foto tirada neste dia aparecerá aqui.",
     "More photos from this day" : "Mais fotos deste dia",
-    "_%n unassigned photo_::_%n unassigned photos_" : ["%nfoto não identificada","%nfotos não identificadas","%nfotos não identificadas"],
+    "_%n unassigned photo_::_%n unassigned photos_" : ["%n foto não atribuída","%n fotos não atribuídas","%n fotos não atribuídas"],
     "Favorite" : "Favorito",
-    "Favorite image, open the full size \"{name}\" image" : "Imagem favorita, abra a imagem \"{name}\" em tamanho real",
-    "Open the full size \"{name}\" image" : "Abrir a imagem \"{name}\" no tamanho normal",
+    "Favorite image, open the full size \"{name}\" image" : "Imagem favorita, abrir a imagem \"{name}\" em tamanho real",
+    "Open the full size \"{name}\" image" : "Abrir a imagem \"{name}\" no tamanho real",
     "Select image {imageName}" : "Selecionar imagem {imageName}",
-    "Open the \"{name}\" folder" : "Abra a pasta \"{nome}\"",
+    "Open the \"{name}\" folder" : "Abrir pasta \"{name}\"",
     "Back to {folder}" : "Voltar para {folder}",
     "Go back" : "Voltar",
     "Share this folder" : "Compartilhar esta pasta",
     "Dates" : "Datas",
     "Jump to specific date in list" : "Ir para uma data específica na lista",
-    "Jump to {date}" : "Ir para {data}",
+    "Jump to {date}" : "Ir para {date}",
     "Add to {destination}" : "Adicionar a {destination}",
     "The destination folder is owned by {owner}" : "A pasta de destino pertence a {owner}",
     "There are no photos or videos yet!" : "Ainda não há fotos ou vídeos!",
-    "_{years} year ago_::_{years} years ago_" : ["{anos} ano atrás","{anos} anos atrás","{anos} anos atrás"],
+    "_{years} year ago_::_{years} years ago_" : ["há {years} ano","há {years} anos","há {years} anos"],
     "Enable squared photos view" : "Ativar exibição de fotos quadradas",
     "Delete source directory" : "Excluir diretório de origem",
+    "Pick folder" : "Selecionar pasta",
     "Select a source folder for your media" : "Selecione uma pasta de origem para sua mídia",
     "All folders" : "Todas as pastas",
-    "Add a Photos source for the timelines" : "Adicione uma fonte de fotos para os cronogramas",
+    "Add a Photos source for the timelines" : "Adicione uma fonte de Fotos para as linhas do tempo",
     "Add folder" : "Adicionar pasta",
     "Select the default upload location for your media" : "Selecione o local de upload padrão para sua mídia",
     "Home" : "Início",
-    "Choose default Photos upload and Albums location" : "Escolha o upload padrão de fotos e o local dos álbuns",
+    "Choose default Photos upload and Albums location" : "Escolha o local padrão para upload de Fotos e Álbuns",
     "Choose a different folder" : "Escolha uma pasta diferente",
     "View" : "Exibição",
     "Media folders" : "Pastas de mídia",
-    "Choose the folders from where photos and videos are shown." : "Escolha as pastas onde as fotos e vídeos serão mostrados.",
-    "Upload folder" : "Carregar pasta",
-    "Choose the folder where photos and albums are uploaded to." : "Escolha a pasta para onde as fotos e os álbuns serão carregados.",
+    "Choose the folders from where photos and videos are shown." : "Escolha as pastas de onde as fotos e os vídeos são exibidos.",
+    "Upload folder" : "Pasta para uploads",
+    "Choose the folder where photos and albums are uploaded to." : "Escolha a pasta na qual as fotos e os álbuns serão carregados.",
     "_%n photo_::_%n photos_" : ["%n foto","%n fotos","%n fotos"],
-    "Unselect all" : "Desmarque todos",
+    "Unselect all" : "Desmarcar todos",
     "Add photos to this album" : "Adicionar fotos a este álbum",
     "Manage collaborators for this album" : "Gerenciar colaboradores para este álbum",
     "Open actions menu" : "Abrir menu de ações",
-    "Edit album details" : "Modificar detalhes do álbu",
+    "Edit album details" : "Modificar detalhes do álbum",
     "Download all files in album" : "Baixar todos os arquivos do álbum",
-    "Delete album" : "Remover álbum",
+    "Delete album" : "Excluir álbum",
     "Download selected files" : "Baixar arquivos selecionados",
     "Remove selection from album" : "Remover seleção do álbum",
-    "This album does not have any photos or videos yet!" : "Este álbum ainda não possui fotos ou vídeos!",
-    "Add photos to {albumName}" : "Add photos to {albumName}",
+    "This album does not have any photos or videos yet!" : "Este álbum ainda não tem fotos ou vídeos!",
+    "Add photos to {albumName}" : "Adicionar fotos a {albumName}",
     "Manage collaborators" : "Gerenciar colaboradores",
-    "Save collaborators for this album." : "Salve os colaboradores deste álbum.",
+    "Save collaborators for this album." : "Salvar colaboradores deste álbum.",
     "Cover photo for album {albumName}" : "Foto da capa do álbum {albumName}",
-    "There is no album yet!" : "Ainda não há álbum!",
-    "This person could not be found" : "Essa pessoa não pôde ser encontrada",
+    "There is no album yet!" : "Ainda não existe um álbum!",
+    "This person could not be found" : "Não foi possível encontrar essa pessoa",
     "Rename person" : "Renomear pessoa",
     "Merge with different person" : "Unir com outra pessoa",
     "Download selected photos" : "Baixar fotos selecionadas",
@@ -108,51 +109,52 @@ OC.L10N.register(
     "Name of this person" : "Nome desta pessoa",
     "Save." : "Salvar.",
     "Merge person" : "Unir pessoa",
-    "Move to different person" : "Ir para uma pessoa diferente",
-    "_Move photo to a different person_::_Move photos to a different person_" : ["Mover fotos para outra pessoa","Mover fotos para outra pessoa","Mover fotos para outra pessoa"],
-    "_Remove photo from person_::_Remove photos from person_" : ["Remover fotos desta pessoa","Remover fotos desta pessoa","Remover fotos desta pessoa"],
-    "This might take some time depending on the size of your photo library." : "Isso pode levar um tempo a depender do tamanho da sua biblioteca de fotos.",
+    "Move to different person" : "Mover para uma pessoa diferente",
+    "_Move photo to a different person_::_Move photos to a different person_" : ["Mover foto para uma pessoa diferente","Mover fotos para uma pessoa diferente","Mover fotos para uma pessoa diferente"],
+    "_Remove photo from person_::_Remove photos from person_" : ["Remover foto desta pessoa","Remover fotos desta pessoa","Remover fotos desta pessoa"],
+    "This might take some time depending on the size of your photo library." : "Isso pode levar algum tempo, dependendo do tamanho de sua biblioteca de fotos.",
     "Recognized people will show up here" : "Pessoas reconhecidas aparecerão aqui",
     "This folder does not exist" : "Esta pasta não existe",
-    "Loading folders …" : "Carregando pastas…",
+    "Loading folders …" : "Carregando pastas …",
     "No photos in here" : "Não há fotos aqui",
     "Taken on {date} at {time}" : "Tirada em {data} às {time}",
-    "This place does not have any photos or videos yet!" : "This place does not have any photos or videos yet!",
+    "This place does not have any photos or videos yet!" : "Este espaço ainda não tem fotos ou vídeos!",
     "Add photos to this place" : "Adicionar fotos a este espaço",
-    "Cover photo for place {placeName}" : "Foto da capa do lespaço {placeName}",
+    "Cover photo for place {placeName}" : "Foto da capa do espaço {placeName}",
     "There is no place yet!" : "Ainda não há espaço!",
-    "Cover photo for shared album {albumName}." : "Foto da capa do álbum compartilhado {albumName}.",
+    "Cover photo for shared album {albumName}" : "Foto da capa do álbum compartilhado {albumName}",
     "Back to tags overview" : "Voltar para a visão geral das etiquetas",
     "No photos with this tag yet" : "Ainda não há fotos com esta etiqueta",
-    "No tags yet" : "Ainda não há marcações",
-    "Photos with tags will show up here" : "Fotos com marcações serão mostradas aqui",
+    "No tags yet" : "Ainda não há etiquetas",
+    "Photos with tags will show up here" : "Fotos com etiquetas serão mostradas aqui",
     "Popular tags" : "Etiquetas populares",
     "All tags" : "Todas as etiquetas",
-    "One of the source folders does not exist" : "Um dos arquivos da fonte não existe",
+    "One of the source folders does not exist" : "Uma das pastas de origem não existe",
     "Add to album" : "Adicionar a álbum",
     "Delete selection" : "Excluir seleção",
     "No photos or videos in here" : "Não há fotos ou vídeos aqui",
-    "Unassigned faces" : "Rostos não identificados",
-    "_%n photos_::_%n photos_" : ["%nfoto","%nfotos","%nfotos"],
-    "Failed to fetch collection." : "Failed to fetch collection.",
-    "Failed to fetch collections list." : "Failed to fetch collections list.",
-    "Failed to fetch faces list." : "Falha ao buscar lista de rostos.",
+    "Unassigned faces" : "Rostos não atribuídos",
+    "_%n photos_::_%n photos_" : ["%n foto","%n fotos","%n fotos"],
+    "Failed to fetch collection." : "Falha ao obter a coleção.",
+    "Failed to fetch collections list." : "Falha ao obter a lista de coleções.",
+    "Failed to fetch faces list." : "Falha ao obter a lista de rostos.",
+    "Error fetching files" : "Erro ao buscar arquivos",
     "All your media" : "Todas as suas mídias",
-    "Album {title}" : "Álbum {título}",
+    "Album {title}" : "Álbum {title}",
     "Shared Albums" : "Álbuns Compartilhados",
     "Shared album {title}" : "Álbum compartilhado {title}",
     "Public album {title}" : "Álbum público {title}",
-    "Tagged photos" : "Fotos marcadas",
-    "Tagged photo {title}" : "Foto marcada {title}",
-    "{title}'s face" : "rosto de {title}",
-    "{startDate} to {endDate}" : "{startDate} até {endDate}",
+    "Tagged photos" : "Fotos com etiqueta",
+    "Tagged photo {title}" : "Foto com etiqueta {title}",
+    "{title}'s face" : "Rosto de {title}",
+    "{startDate} to {endDate}" : "{startDate} a {endDate}",
     "Details" : "Detalhes",
-    "Failed to rename {oldName} to {faceName}." : "Falha ao renomear {oldName} para {faceName}.",
-    "Failed to delete {faceName}." : "Falha ao remover {faceName}.",
-    "Failed to delete {fileId}." : "Falha ao excluir {fileId}.",
-    "Failed to delete {fileName}." : "Falha ao excluir {fileName}.",
-    "Failed to set favorite state for {fileId}." : "Falha ao definir o estado de favorito para {fileId}.",
-    "Failed to set favorite state for {fileName}." : "Falha ao definir o estado de favorito para {fileName}.",
+    "Failed to rename {oldName} to {faceName}" : "Falha ao renomear {oldName} para {faceName}",
+    "Failed to delete {faceName}" : "Falha ao excluir {faceName}",
+    "Failed to delete {fileId}" : "Falha ao excluir {fileId}",
+    "Failed to delete {fileName}" : "Falha ao excluir {fileName}",
+    "Failed to set favorite state for {fileId}" : "Falha ao definir o estado de favorito para {fileId}",
+    "Failed to set favorite state for {fileName}" : "Falha ao definir o estado de favorito para {fileName}",
     "Could not load photos folder" : "Não foi possível carregar a pasta de fotos",
     "One of the source folders does not exists" : "Uma das pastas de origem não existe",
     "Add" : "Adicionar"
