@@ -120,7 +120,6 @@ OC.L10N.register(
     "Add photos to this place" : "Связать фотографии с этим местом",
     "Cover photo for place {placeName}" : "Заглавное изображение для места «{placeName}»",
     "There is no place yet!" : "Пока нет ни одного места.",
-    "Cover photo for shared album {albumName}." : "Заглавное изображение опубликованного альбома «{albumName}».",
     "Back to tags overview" : "Вернуться к просмотру меток",
     "No photos with this tag yet" : "Нет ни одной фотографии с этой меткой",
     "No tags yet" : "Нет ни одной метки",
@@ -145,12 +144,6 @@ OC.L10N.register(
     "{title}'s face" : "Лицо {title}",
     "{startDate} to {endDate}" : "С {startDate} по {endDate}",
     "Details" : "Свойства",
-    "Failed to rename {oldName} to {faceName}." : "Не удалось переименовать метку лица «{oldName}» в «{faceName}».",
-    "Failed to delete {faceName}." : "Не удалось удалить метку лица «{faceName}».",
-    "Failed to delete {fileId}." : "Не удалось удалить «{fileId}».",
-    "Failed to delete {fileName}." : "Не удалось удалить файл «{fileName}».",
-    "Failed to set favorite state for {fileId}." : "Не удалось отметить или снять отметку избранного с «{fileId}».",
-    "Failed to set favorite state for {fileName}." : "Не удалось отметить или снять отметку избранного с «{fileId}».",
     "Could not load photos folder" : "Не удалось загрузить папку с фотографиями",
     "One of the source folders does not exists" : "Одна из исходных папок не существует",
     "Add" : "Добавить"
