@@ -122,7 +122,7 @@ OC.L10N.register(
     "Add photos to this place" : "Додај фотографије на ово место",
     "Cover photo for place {placeName}" : "Фотографија омота за место {placeName}",
     "There is no place yet!" : "Још увек нема места!",
-    "Cover photo for shared album {albumName}." : "Фотографија омота за дељени албум {albumName}.",
+    "Cover photo for shared album {albumName}" : "Фотографија омота за дељени албум {albumName}",
     "Back to tags overview" : "Назад на преглед ознака",
     "No photos with this tag yet" : "Још увек нема фотографија са овом ознаком",
     "No tags yet" : "Још нема ознака",
@@ -138,6 +138,7 @@ OC.L10N.register(
     "Failed to fetch collection." : "Није успело добављање колекције.",
     "Failed to fetch collections list." : "Није успело добављање листе колекција.",
     "Failed to fetch faces list." : "Није успело добављање листе лица.",
+    "Error fetching files" : "Грешка приликом преузимања фајлова",
     "All your media" : "Сви ваши медији",
     "Album {title}" : "Албум {title}",
     "Shared Albums" : "Дељени албуми",
@@ -148,12 +149,12 @@ OC.L10N.register(
     "{title}'s face" : "лице {title}",
     "{startDate} to {endDate}" : "{startDate} до {endDate}",
     "Details" : "Детаљи",
-    "Failed to rename {oldName} to {faceName}." : "Није успела промена имена {oldName} у {faceName}.",
-    "Failed to delete {faceName}." : "Није успело брисање {faceName}.",
-    "Failed to delete {fileId}." : "Није успело брисање {fileId}.",
-    "Failed to delete {fileName}." : "Није успело брисање {fileName}.",
-    "Failed to set favorite state for {fileId}." : "Није успело постављање стања омиљено за {fileId}.",
-    "Failed to set favorite state for {fileName}." : "Није успело постављање стања омиљено за {fileName}.",
+    "Failed to rename {oldName} to {faceName}" : "Није успела промена имена {oldName} у {faceName}",
+    "Failed to delete {faceName}" : "Није успело брисање {faceName}",
+    "Failed to delete {fileId}" : "Није успело брисање {fileId}",
+    "Failed to delete {fileName}" : "Није успело брисање {fileName}",
+    "Failed to set favorite state for {fileId}" : "Није успело постављање стања омиљено за {fileId}",
+    "Failed to set favorite state for {fileName}" : "Није успело постављање стања омиљено за {fileName}",
     "Could not load photos folder" : "Не може да се учита фолдер фотографија",
     "One of the source folders does not exists" : "Један од изворних фолдера не постоји",
     "Add" : "Додај"
