@@ -104,7 +104,6 @@ OC.L10N.register(
     "Set your password" : "Angiv din adgangskode password",
     "Go to %s" : "Gå til %s",
     "Install Client" : "Installer client",
-    "Logged in account must be a subadmin" : "På-logget konto skal være en subadmin",
     "Apps" : "Apps",
     "Personal" : "Personligt",
     "Administration" : "Administration",
@@ -203,6 +202,7 @@ OC.L10N.register(
     "Old server-side-encryption" : "Gammel server-side kryptering",
     "Disabled" : "Deaktiveret",
     "The old server-side-encryption format is enabled. We recommend disabling this." : "Det gamle serverside-krypteringsformat er aktiveret. Vi anbefaler at deaktivere dette.",
+    "Logging level" : "Log niveau",
     "Maintenance window start" : "Vedligeholdelsesvindue starter",
     "Server has no maintenance window start time configured. This means resource intensive daily background jobs will also be executed during your main usage time. We recommend to set it to a time of low usage, so users are less impacted by the load caused from these heavy tasks." : "Serveren har ikke konfigureret noget starttidspunkt for vedligeholdelsesvinduet. Dette betyder, at ressourcekrævende daglige baggrundsjobs også vil blive udført under din primære anvendelsestid. Vi anbefaler at indstille det til et tidspunkt med lavt forbrug, så brugerne bliver mindre påvirket af belastningen, forårsaget af disse tunge opgaver.",
     "Maintenance window to execute heavy background jobs is between {start}:00 UTC and {end}:00 UTC" : "Vedligeholdelsesvinduet til at udføre tunge baggrundsjob er mellem {start}:00 UTC og {end}:00 UTC",
@@ -249,8 +249,6 @@ OC.L10N.register(
     "PHP modules" : "PHP moduler",
     "increases language translation performance and fixes sorting of non-ASCII characters" : "Øger sprogoversættelsesperformance og retter sortering af ikke-ASCII karakterer",
     "for Argon2 for password hashing" : "til Argon2 for adgangskode hashing",
-    "for WebAuthn passwordless login" : "til WebAuthn adgangskodeløst login",
-    "for WebAuthn passwordless login, and SFTP storage" : "til WebAuthn adgangskodeløst login, og SFTP lagring",
     "for picture rotation in server and metadata extraction in the Photos app" : "til billedrotation på server og metadata ekstraktion i Fotos app",
     "This instance is missing some required PHP modules. It is required to install them: %s." : "Instansen mangler nogle krævede PHP moduler. Det kræves at de installeres: %s.",
     "This instance is missing some recommended PHP modules. For improved performance and better compatibility it is highly recommended to install them:\n%s" : "Denne instans mangler nogle anbefalede PHP moduler. For forbedret performance og bedre kompatibilitet anbefales det kraftigt at installere disse:\n%s",
@@ -392,9 +390,16 @@ OC.L10N.register(
     "Level" : "Niveau",
     "Actions" : "Handlinger",
     "Results from other categories" : "Resultater fra andre kategorier",
-    "No apps found for your version" : "Ingen apps fundet til din verion",
+    "No apps found for your version" : "Ingen apps fundet for din version",
     "_%n app has an update available_::_%n apps have an update available_" : ["%n app har en tilgængelig opdatering","%n apps har en tilgængelig opdatering"],
     "_Update_::_Update all_" : ["Opdatér","Opdater alle"],
+    "Failed to create group" : "Kunne ikke oprette gruppe",
+    "Creating group…" : "Opretter gruppe...",
+    "Create group" : "Opret gruppe",
+    "Group name" : "Gruppenavn",
+    "Please enter a valid group name" : "Indtast venligst et gyldigt gruppenavn",
+    "Search groups…" : "Søg grupper…",
+    "Loading groups…" : "Indlæser grupper…",
     "Could not load app discover section" : "App opdagelsessektionen kunne ikke indlæses",
     "Could not render element" : "Elementet kunne ikke gengives",
     "Nothing to show" : "Intet indhold",
@@ -635,6 +640,7 @@ OC.L10N.register(
     "Set line manager" : "Sæt linjeleder",
     "Account name will be autogenerated" : "Brugernavnet vil blive genereret automatisk",
     "Account name (required)" : "Brugernavn (påkrævet)",
+    "Failed to search groups" : "Fejl under søgning af grupper",
     "New account" : "Ny konto",
     "Display name" : "Vist navn",
     "Either password or email is required" : "Adgangskode eller e-mail er påkrævet",
@@ -651,6 +657,8 @@ OC.L10N.register(
     "Language" : "Sprog",
     "Set default language" : "Vælg standard sprog",
     "Add new account" : "Tilføj ny konto",
+    "_{userCount} account …_::_{userCount} accounts …_" : ["{userCount} konto …","{userCount} konti …"],
+    "_{userCount} account_::_{userCount} accounts_" : ["{userCount} konto","{userCount} konti"],
     "Total rows summary" : "Samlet række antal",
     "Scroll to load more rows" : "Rul for at indlæse flere rækker",
     "Password or insufficient permissions message" : "Besked om adgangskode eller manglende rettigheder",
@@ -730,12 +738,8 @@ OC.L10N.register(
     "Version {version}" : "Version {version}",
     "All accounts" : "Alle konti",
     "Admins" : "Administratorer",
-    "Failed to create group" : "Kunne ikke oprette gruppe",
+    "Account group: {group}" : "Konto gruppe: {group}",
     "Account management" : "Kontostyring",
-    "Creating group…" : "Opretter gruppe...",
-    "Create group" : "Opret gruppe",
-    "Group name" : "Gruppenavn",
-    "Please enter a valid group name" : "Indtast venligst et gyldigt gruppenavn",
     "Sending…" : "Sender...",
     "Email sent" : "E-mail afsendt",
     "For performance reasons, when you enable encryption on a Nextcloud server only new and changed files are encrypted." : "Af hensyn til performancemæssige, så er det kun nye og ændrede filer, der krypteres, når du aktiverer kryptering på en Nextcloud server.",
@@ -839,12 +843,15 @@ OC.L10N.register(
     "This community release of Nextcloud is unsupported and instant notifications are unavailable." : "Denne fællesskabsudgivelse af Nextcloud er ikke understøttet, og øjeblikkelige meddelelser er ikke tilgængelige.",
     "Use a second factor besides your password to increase security for your account." : "Brug to-faktor godkendelse for at øge sikkerheden for din konto.",
     "If you use third party applications to connect to Nextcloud, please make sure to create and configure an app password for each before enabling second factor authentication." : "Hvis du bruger tredjepartsapplikationer til at oprette forbindelse til Nextcloud, så skal du sørge for at oprette og konfigurere en app-adgangskode for hver applikation, før du aktiverer to-faktor-godkendelse.",
+    "Logged in account must be a subadmin" : "På-logget konto skal være en subadmin",
     "To allow this check to run you have to make sure that your webserver can connect to itself. Therefor it must be able to resolve and connect to at least one its `trusted_domains` or the `overwrite.cli.url`." : "For at tillade denne kontrol at køre, så skal du sørge for, at din webserver kan oprette forbindelse til sig selv. Derfor skal den være i stand til at opløse og oprette forbindelse til mindst et af sine `trusted_domains` eller `overwrite.cli.url`.",
     "The database is missing some indexes. Due to the fact that adding indexes on big tables could take some time they were not added automatically. By running \"occ db:add-missing-indices\" those missing indexes could be added manually while the instance keeps running. Once the indexes are added queries to those tables are usually much faster." : "Databasen mangler nogle indekser. Da tilføjelse af indekser kan tage noget tid, blev de ikke tilføjet automatisk. Kør \"occ db:add-missing-indices\" for manuelt at tilføje disse indekser mens forekomsten forbliver aktiv. Når indekserne er tilføjet, er forespørgsler til disse tabeller normalt meget hurtigere. ",
     "File locking" : "Fillåsning",
     "Transactional file locking is disabled, this might lead to issues with race conditions. Enable \"filelocking.enabled\" in config.php to avoid these problems." : "Transaktionel fillåsning er deaktiveret. Dette kan føre til problemer med ræskonditioner. Aktiver \"filelocking.enabled\" i config.php for at undgå disse problemer.",
     "Could not check for JavaScript support via any of your `trusted_domains` nor `overwrite.cli.url`. This may be the result of a server-side DNS mismatch or outbound firewall rule. Please check manually if your webserver serves `.mjs` files using the JavaScript MIME type." : "Kunne ikke søge efter JavaScript understøttelse via nogen af ​​dine `trusted_domains` eller `overwrite.cli.url`. Dette kan være på grund af en DNS uoverensstemmelse på serversiden eller udgående firewallregel. Tjek venligst manuelt, om din webserver leverer `.mjs` filer ved hjælp af JavaScript MIME typen.",
     "The PHP memory limit is below the recommended value of %s." : "PHP hukommelsesgræsen er under den anbefalede værdi på %s.",
+    "for WebAuthn passwordless login" : "til WebAuthn adgangskodeløst login",
+    "for WebAuthn passwordless login, and SFTP storage" : "til WebAuthn adgangskodeløst login, og SFTP lagring",
     "Set default expiration date for shares" : "Indstil standardudløbsdato for delinger",
     "Your biography" : "Din biografi",
     "You are using <strong>{usage}</strong>" : "Forbrug: <strong>{usage}</strong>",
@@ -868,6 +875,7 @@ OC.L10N.register(
     "Add user to group" : "Føj bruger til gruppe",
     "Server error while trying to add WebAuthn device" : "Serverfejl under forsøg på at tilføje WebAuthn-enhed",
     "Name your device" : "Navngiv din enhed",
+    "Active accounts" : "Aktive konti",
     "Follow us on Twitter" : "Følg os på Twitter",
     "To allow this check to run you have to make sure that your Web server can connect to itself. Therefore it must be able to resolve and connect to at least one of its `trusted_domains` or the `overwrite.cli.url`. This failure may be the result of a server-side DNS mismatch or outbound firewall rule." : "For at tillade at denne kontrol køres så skal du sikre dig at din webserver kan forbinde til sig selv. Derfor skal den kunne opløse og forbinde til mindst en af dets `trusted_domains` eller `overwrite.cli.url`. Denne fejl kan være resultatet af en server-side DNS mismatch eller udadgående firewall regel."
 },
