@@ -1,28 +1,33 @@
 OC.L10N.register(
     "text",
     {
-    "New text file" : "Nuevo archivo de texto",
     "The uploaded file exceeds the upload_max_filesize directive in php.ini" : "El archivo cargado excede el valor establecido en la directiva upload_max_filesize en el archivo php.ini",
     "The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form" : "El archivo cargado excede el valor especificado de la directiva MAX_FILE_SIZE en la forma de HTML",
     "No file was uploaded" : "No se cargó el archivo",
     "Missing a temporary folder" : "Falta una carpeta temporal",
+    "New text file" : "Nuevo archivo de texto",
+    "File not found" : "Archivo no encontrado",
     "Text" : "Texto",
+    "Translate" : "Traducir",
     "Guest" : "Invitado",
     "Offline" : "Sin conexión",
     "Saved" : "Guardado",
     "Unsaved changes" : "Cambios no guardados",
-    "Formatting help" : "Ayuda de formato",
     "Keyboard shortcuts" : "Atajos del teclado",
-    "Translate" : "Traducir",
+    "Link" : "Liga",
+    "Action" : "Acción",
+    "Undo" : "Deshacer",
+    "URL" : "URL",
+    "Formatting help" : "Ayuda de formato",
     "Select language" : "Seleccionar idioma",
     "to" : "para",
     "Replace" : "Reemplazar",
+    "Upload" : "Cargar",
+    "Edit" : "Editar",
     "Source code" : "Código fuente",
-    "Unsupported image type" : "Tipo de imagen no soportado",
-    "Undo" : "Deshacer",
+    "Details" : "Detalles",
     "Info" : "Info",
     "Success" : "Éxito",
-    "Warning" : "Advertencia",
-    "Edit" : "Editar"
+    "Warning" : "Advertencia"
 },
 "nplurals=3; plural=n == 1 ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");
