@@ -1,13 +1,18 @@
 OC.L10N.register(
     "text",
     {
+    "Translate" : "Translate",
+    "Reload" : "ផ្ទុកឡើងវិញ",
     "guest" : "ភ្ញៀវ",
     "Saved" : "បាន​រក្សាទុក",
-    "Translate" : "Translate",
+    "Cancel" : "លើកលែង",
+    "URL" : "URL",
     "to" : "ទៅ",
-    "Info" : "Info",
-    "Warning" : "បម្រាម",
+    "Upload" : "ផ្ទុក​ឡើង",
+    "Edit" : "កែប្រែ",
     "Table" : "តារាង",
-    "Edit" : "កែប្រែ"
+    "Details" : "ព័ត៌មាន​លម្អិត",
+    "Info" : "Info",
+    "Warning" : "បម្រាម"
 },
 "nplurals=1; plural=0;");
