@@ -31,8 +31,13 @@ OC.L10N.register(
     "Assistant results" : "小幫手結果",
     "Show result" : "顯示結果",
     "Delete task" : "刪除工作項目",
+    "Overwrite the file and save the current changes" : "覆寫檔案並儲存目前變更",
+    "Discard the current changes and load the latest version" : "放棄目前變更並載入最新版本",
     "Reload" : "重新載入",
+    "The file was overwritten. Your current changes cannot be auto-saved. Please choose how to proceed." : "檔案已被覆寫。無法自動儲存您目前的變更。請選擇要如何繼續。",
+    "The document could not be loaded. Please check your internet connection." : "無法載入文件。請檢查您的網際網路連線。",
     "Reconnect" : "重新連接",
+    "You've been disconnected from the server." : "您已與伺服器斷線。",
     "This file is opened read-only as it is currently locked by {user}." : "此檔案以唯讀模式開啟，因為其目前被 {user} 鎖定。",
     "Close outline view" : "關閉大綱檢視",
     "Outline" : "大綱",
@@ -63,7 +68,6 @@ OC.L10N.register(
     "Unsaved changes" : "未儲存變更",
     "Save document" : "儲存文件",
     "Last saved" : "最後儲存於",
-    "Connection failed." : "連線失敗。",
     "Formatting and shortcuts" : "格式化與捷徑",
     "Speed up your writing with simple shortcuts." : "使用簡單的快捷鍵加速您的寫作。",
     "Just type the Markdown syntax or use keyboard shortcuts from below." : "僅需輸入 Markdown 語法或使用下方的鍵盤快捷鍵即可。",
@@ -120,7 +124,6 @@ OC.L10N.register(
     "Upload from computer" : "從電腦上傳",
     "Insert from Files" : "從檔案插入",
     "Formatting help" : "格式化說明",
-    "Select file or folder to link to" : "選取要連結的檔案或資料夾",
     "Link to file or folder" : "連結至檔案或資料夾",
     "Link to website" : "連結至網站",
     "Update link" : "更新連結",
@@ -145,6 +148,9 @@ OC.L10N.register(
     "No command found" : "找不到指令",
     "No user found" : "找不到使用者",
     "No suggestion found" : "找不到建議",
+    "Upload" : "上傳",
+    "Insert Table" : "插入表格",
+    "Smart Picker" : "智慧型挑選器",
     "Edit" : "編輯",
     "Copy code block" : "複製程式碼區塊",
     "Copy code" : "複製程式碼",
@@ -196,6 +202,7 @@ OC.L10N.register(
     "Ctrl" : "Ctrl",
     "Option" : "選項",
     "Formatting" : "文字樣式",
+    "Select file or folder to link to" : "選取要連結的檔案或資料夾",
     "Add folder description" : "新增資料夾描述",
     "\"{name}\" already exist!" : "「{name}」已存在！",
     "Created \"{name}\"" : "已建立「{name}」",
@@ -210,6 +217,7 @@ OC.L10N.register(
     "Document idle for {timeout} minutes, click to continue editing" : "文件已閒置 {timeout} 分鐘。點選以繼續編輯",
     "Show author colors" : "顯示作者顏色",
     "Author colors are only shown until everyone has closed the document." : "僅在所有人都關閉文件前才顯示文件顏色。",
+    "Connection failed." : "連線失敗。",
     "Detect language" : "偵測語言",
     "Callouts" : "標記",
     "Info" : "資訊",
