@@ -10,7 +10,7 @@ OC.L10N.register(
     "Error saving image" : "S'ha produït un error en desar la imatge",
     "Unsaved changes" : "Hi ha canvis sense desar",
     "Drop changes" : "Suprimeix els canvis",
-    "Play the live photo" : "Reprodueix la foto en directe",
+    "Play the live photo" : "Reprodueix la fotografia en viu",
     "LIVE" : "DIRECTE",
     "Your browser does not support videos." : "El vostre navegador no és compatible amb els vídeos.",
     "This file no longer exists" : "Aquest fitxer ja no existeix",
@@ -77,7 +77,7 @@ OC.L10N.register(
     "Image" : "Imatge",
     "Importing …" : "S'està important…",
     "+ Add image" : "+ Afegeix una imatge",
-    "Upload image" : "Puja una imatge",
+    "Upload image" : "Pujada d'una imatge",
     "From gallery" : "De la galeria",
     "Line" : "Línia",
     "Pen" : "Llapis",
