@@ -127,21 +127,19 @@ OC.L10N.register(
     "Account name" : "Account name",
     "Server side authentication failed!" : "تأیید هویت از سوی سرور انجام نشد!",
     "Please contact your administrator." : "لطفا با مدیر وب‌سایت تماس بگیرید.",
-    "Temporary error" : "خطای موقتی",
-    "Please try again." : "لطفا دوباره تلاش کنید.",
     "An internal error occurred." : "یک اشتباه داخلی رخ داد.",
     "Please try again or contact your administrator." : "لطفا مجددا تلاش کنید یا با مدیر سیستم تماس بگیرید.",
     "Password" : "گذرواژه",
     "Log in with a device" : "Log in with a device",
     "Your account is not setup for passwordless login." : "Your account is not setup for passwordless login.",
-    "Browser not supported" : "Browser not supported",
-    "Passwordless authentication is not supported in your browser." : "Passwordless authentication is not supported in your browser.",
     "Your connection is not secure" : "Your connection is not secure",
     "Passwordless authentication is only available over a secure connection." : "Passwordless authentication is only available over a secure connection.",
+    "Browser not supported" : "Browser not supported",
+    "Passwordless authentication is not supported in your browser." : "Passwordless authentication is not supported in your browser.",
     "Reset password" : "تنظیم مجدد رمز عبور",
+    "Back to login" : "Back to login",
     "Couldn't send reset email. Please contact your administrator." : "ارسال ایمیل مجدد با مشکل مواجه شد . لطفا با مدیر سیستم تماس بگیرید .",
     "Password cannot be changed. Please contact your administrator." : "Password cannot be changed. Please contact your administrator.",
-    "Back to login" : "Back to login",
     "New password" : "گذرواژه جدید",
     "Your files are encrypted. There will be no way to get your data back after your password is reset. If you are not sure what to do, please contact your administrator before you continue. Do you really want to continue?" : "Your files are encrypted. There will be no way to get your data back after your password is reset. If you are not sure what to do, please contact your administrator before you continue. Do you really want to continue?",
     "I know what I'm doing" : "اطلاع از انجام این کار دارم",
@@ -184,6 +182,25 @@ OC.L10N.register(
     "Back" : "بازگشت",
     "Login form is disabled." : "Login form is disabled.",
     "More actions" : "اقدامات بیشتر",
+    "Security warning" : "اخطار امنیتی",
+    "Storage & database" : "انبارش و پایگاه داده",
+    "Data folder" : "پوشه اطلاعاتی",
+    "Install and activate additional PHP modules to choose other database types." : "جهت انتخاب انواع دیگر پایگاه‌داده‌،ماژول‌های اضافی PHP را نصب و فعال‌سازی کنید.",
+    "For more details check out the documentation." : "برای جزئیات بیشتر به مستندات مراجعه کنید.",
+    "Performance warning" : "اخطار کارایی",
+    "You chose SQLite as database." : "شما SQLite را به عنوان پایگاه داده انتخاب کردید.",
+    "SQLite should only be used for minimal and development instances. For production we recommend a different database backend." : "SQLite should only be used for minimal and development instances. For production we recommend a different database backend.",
+    "If you use clients for file syncing, the use of SQLite is highly discouraged." : "If you use clients for file syncing, the use of SQLite is highly discouraged.",
+    "Database user" : "شناسه پایگاه داده",
+    "Database password" : "پسورد پایگاه داده",
+    "Database name" : "نام پایگاه داده",
+    "Database tablespace" : "جدول پایگاه داده",
+    "Please specify the port number along with the host name (e.g., localhost:5432)." : "Please specify the port number along with the host name (e.g., localhost:5432).",
+    "Database host" : "هاست پایگاه داده",
+    "Installing …" : "Installing …",
+    "Install" : "نصب",
+    "Need help?" : "کمک لازم دارید ؟",
+    "See the documentation" : "مشاهده‌ی مستندات",
     "{name} version {version} and above" : "{name} version {version} and above",
     "This browser is not supported" : "This browser is not supported",
     "Your browser is not supported. Please upgrade to a newer version or a supported one." : "Your browser is not supported. Please upgrade to a newer version or a supported one.",
@@ -224,11 +241,6 @@ OC.L10N.register(
     "Type to search for existing projects" : "Type to search for existing projects",
     "New in" : "جدید در",
     "View changelog" : "مشاهده تغییرات",
-    "Very weak password" : "رمز عبور بسیار ضعیف",
-    "Weak password" : "رمز عبور ضعیف",
-    "So-so password" : "رمز عبور متوسط",
-    "Good password" : "رمز عبور خوب",
-    "Strong password" : "رمز عبور قوی",
     "No action available" : "هیچ عملی قابل انجام نیست",
     "Error fetching contact actions" : "خطا در دریافت فعالیتهای تماس",
     "Close \"{dialogTitle}\" dialog" : "Close \"{dialogTitle}\" dialog",
@@ -263,30 +275,6 @@ OC.L10N.register(
     "File: %s" : "فایل : %s",
     "Line: %s" : "خط: %s",
     "Trace" : "ردیابی",
-    "Security warning" : "اخطار امنیتی",
-    "Your data directory and files are probably accessible from the internet because the .htaccess file does not work." : "فایلها و فهرست های داده های شما قابل از اینترنت قابل دسترسی هستند، چونکه فایل htacces. کار نمی کند.",
-    "For information how to properly configure your server, please see the <a href=\"%s\" target=\"_blank\" rel=\"noreferrer noopener\">documentation</a>." : "For information how to properly configure your server, please see the <a href=\"%s\" target=\"_blank\" rel=\"noreferrer noopener\">documentation</a>.",
-    "Show password" : "نمایش گذرواژه",
-    "Toggle password visibility" : "Toggle password visibility",
-    "Storage & database" : "انبارش و پایگاه داده",
-    "Data folder" : "پوشه اطلاعاتی",
-    "Configure the database" : "پایگاه داده برنامه ریزی شدند",
-    "Only %s is available." : "تنها %s موجود است.",
-    "Install and activate additional PHP modules to choose other database types." : "جهت انتخاب انواع دیگر پایگاه‌داده‌،ماژول‌های اضافی PHP را نصب و فعال‌سازی کنید.",
-    "For more details check out the documentation." : "برای جزئیات بیشتر به مستندات مراجعه کنید.",
-    "Database password" : "پسورد پایگاه داده",
-    "Database name" : "نام پایگاه داده",
-    "Database tablespace" : "جدول پایگاه داده",
-    "Database host" : "هاست پایگاه داده",
-    "Please specify the port number along with the host name (e.g., localhost:5432)." : "Please specify the port number along with the host name (e.g., localhost:5432).",
-    "Performance warning" : "اخطار کارایی",
-    "You chose SQLite as database." : "شما SQLite را به عنوان پایگاه داده انتخاب کردید.",
-    "SQLite should only be used for minimal and development instances. For production we recommend a different database backend." : "SQLite should only be used for minimal and development instances. For production we recommend a different database backend.",
-    "If you use clients for file syncing, the use of SQLite is highly discouraged." : "If you use clients for file syncing, the use of SQLite is highly discouraged.",
-    "Install" : "نصب",
-    "Installing …" : "Installing …",
-    "Need help?" : "کمک لازم دارید ؟",
-    "See the documentation" : "مشاهده‌ی مستندات",
     "It looks like you are trying to reinstall your Nextcloud. However the file CAN_INSTALL is missing from your config directory. Please create the file CAN_INSTALL in your config folder to continue." : "It looks like you are trying to reinstall your Nextcloud. However the file CAN_INSTALL is missing from your config directory. Please create the file CAN_INSTALL in your config folder to continue.",
     "Could not remove CAN_INSTALL from the config folder. Please remove this file manually." : "Could not remove CAN_INSTALL from the config folder. Please remove this file manually.",
     "This application requires JavaScript for correct operation. Please {linkstart}enable JavaScript{linkend} and reload the page." : "This application requires JavaScript for correct operation. Please {linkstart}enable JavaScript{linkend} and reload the page.",
@@ -349,7 +337,18 @@ OC.L10N.register(
     "Edit Profile" : "ویرایش نمایه",
     "The headline and about sections will show up here" : "The headline and about sections will show up here",
     "Error loading message template: {error}" : "خطا در بارگذاری قالب پیام : {error}",
+    "Very weak password" : "رمز عبور بسیار ضعیف",
+    "Weak password" : "رمز عبور ضعیف",
+    "So-so password" : "رمز عبور متوسط",
+    "Good password" : "رمز عبور خوب",
+    "Strong password" : "رمز عبور قوی",
     "Profile not found" : "نمایه، یافت نشد",
-    "The profile does not exist." : "این نمایه وجود ندارد."
+    "The profile does not exist." : "این نمایه وجود ندارد.",
+    "Your data directory and files are probably accessible from the internet because the .htaccess file does not work." : "فایلها و فهرست های داده های شما قابل از اینترنت قابل دسترسی هستند، چونکه فایل htacces. کار نمی کند.",
+    "For information how to properly configure your server, please see the <a href=\"%s\" target=\"_blank\" rel=\"noreferrer noopener\">documentation</a>." : "For information how to properly configure your server, please see the <a href=\"%s\" target=\"_blank\" rel=\"noreferrer noopener\">documentation</a>.",
+    "Show password" : "نمایش گذرواژه",
+    "Toggle password visibility" : "Toggle password visibility",
+    "Configure the database" : "پایگاه داده برنامه ریزی شدند",
+    "Only %s is available." : "تنها %s موجود است."
 },
 "nplurals=2; plural=(n > 1);");
