@@ -106,6 +106,7 @@ OC.L10N.register(
     "Custom date range" : "Mukautettu päivämääräväli",
     "Pick start date" : "Valitse aloituspäivä",
     "Pick end date" : "Valitse päättymispäivä",
+    "Search in date range" : "Etsi aikaväliltä",
     "Search in current app" : "Etsi nykyisessä sovelluksessa",
     "Clear search" : "Tyhjennä haku",
     "Search everywhere" : "Etsi kaikkialta",
@@ -137,6 +138,8 @@ OC.L10N.register(
     "Account name" : "Tilin nimi",
     "Server side authentication failed!" : "Palvelimen puoleinen tunnistautuminen epäonnistui!",
     "Please contact your administrator." : "Ota yhteys ylläpitäjään.",
+    "Session error" : "Istuntovirhe",
+    "It appears your session token has expired, please refresh the page and try again." : "Vaikuttaa siltä, että istunnon poletti vanheni. Päivitä sivu ja yritä uudelleen.",
     "An internal error occurred." : "Tapahtui sisäinen virhe.",
     "Please try again or contact your administrator." : "Yritä uudestaan tai ota yhteys ylläpitäjään.",
     "Password" : "Salasana",
@@ -194,9 +197,21 @@ OC.L10N.register(
     "Login form is disabled." : "Kirjautumislomake on poistettu käytöstä.",
     "The Nextcloud login form is disabled. Use another login option if available or contact your administration." : "Nextcloudin kirjautumislomake on poistettu käytöstä. Käytä toista kirjautumistapaa tai ota yhteys ylläpitoon.",
     "More actions" : "Lisää toimintoja",
+    "Password is too weak" : "Salasana on liian heikko",
+    "Password is weak" : "Salasana on heikko",
+    "Password is average" : "Salasana on keskiverto",
+    "Password is strong" : "Salasana on vahva",
+    "Password is very strong" : "Salasana on hyvin vahva",
+    "Password is extremely strong" : "Salasana on erittäin vahva",
+    "Unknown password strength" : "Tuntematon salasanan vahvuus",
     "Security warning" : "Turvallisuusvaroitus",
+    "Create administration account" : "Luo ylläpitäjätili",
+    "Administration account name" : "Ylläpitäjätilin nimi",
+    "Administration account password" : "Ylläpitäjätilin salasana",
     "Storage & database" : "Tallennus ja tietokanta",
     "Data folder" : "Datakansio",
+    "Database configuration" : "Tietokannan kokoonpano",
+    "Only {firstAndOnlyDatabase} is available." : "Vain {firstAndOnlyDatabase} on käytettävissä.",
     "Install and activate additional PHP modules to choose other database types." : "Asenna ja aktivoi erillisiä PHP-moduuleja valitaksesi muita tietokantatyyppejä.",
     "For more details check out the documentation." : "Lue lisätiedot ohjeista.",
     "Performance warning" : "Suorituskykyvaroitus",
