@@ -101,14 +101,14 @@ OC.L10N.register(
     "Password" : "Zaporka",
     "Log in with a device" : "Prijavite se s pomoću uređaja",
     "Your account is not setup for passwordless login." : "Nije odabrana mogućnost prijave bez zaporke za vaš račun.",
-    "Browser not supported" : "Preglednik nije podržan",
-    "Passwordless authentication is not supported in your browser." : "Vaš preglednik ne podržava autentifikaciju bez zaporke.",
     "Your connection is not secure" : "Vaša veza nije sigurna",
     "Passwordless authentication is only available over a secure connection." : "Autentifikacija bez zaporke dostupna je samo ako je uspostavljena sigurna veza.",
+    "Browser not supported" : "Preglednik nije podržan",
+    "Passwordless authentication is not supported in your browser." : "Vaš preglednik ne podržava autentifikaciju bez zaporke.",
     "Reset password" : "Resetiraj zaporku",
+    "Back to login" : "Natrag na prijavu",
     "Couldn't send reset email. Please contact your administrator." : "Nije moguće poslati poruku za resetiranje. Kontaktirajte s administratorom.",
     "Password cannot be changed. Please contact your administrator." : "Zaporku nije moguće promijeniti. Obratite se svom administratoru.",
-    "Back to login" : "Natrag na prijavu",
     "New password" : "Nova zaporka",
     "Your files are encrypted. There will be no way to get your data back after your password is reset. If you are not sure what to do, please contact your administrator before you continue. Do you really want to continue?" : "Vaši podaci su šifrirani. Ako resetirate zaporku, nećete ih moći kasnije vratiti. Ako ne znate što učiniti, obratite se svom administratoru prije nego što nastavite. Želite li nastaviti?",
     "I know what I'm doing" : "Znam što radim",
@@ -144,6 +144,24 @@ OC.L10N.register(
     "Back" : "Natrag",
     "Login form is disabled." : "Obrazac za prijavu je onemogućen.",
     "More actions" : "Dodatne radnje",
+    "Security warning" : "Sigurnosno upozorenje",
+    "Storage & database" : "Pohrana i baza podataka",
+    "Data folder" : "Mapa za podatke",
+    "Install and activate additional PHP modules to choose other database types." : "Instalirajte i aktivirajte dodatne module PHP-a kako biste odabrali druge vrste baza podataka.",
+    "For more details check out the documentation." : "Za više informacija pogledajte dokumentaciju.",
+    "Performance warning" : "Upozorenje o performansama",
+    "You chose SQLite as database." : "Odabrali ste SQLite kao bazu podataka.",
+    "SQLite should only be used for minimal and development instances. For production we recommend a different database backend." : "SQLite bi se trebao upotrebljavati samo za minimalne i razvojne instance. Za produkcijske instance preporučujemo korištenje neke druge pozadinske baze podataka.",
+    "If you use clients for file syncing, the use of SQLite is highly discouraged." : "Ako upotrebljavate klijente za sinkronizaciju datoteka, preporučujemo izbjegavanje baze podataka SQLite.",
+    "Database user" : "Korisnik baze podataka",
+    "Database password" : "Zaporka baze podataka",
+    "Database name" : "Naziv baze podataka",
+    "Database tablespace" : "Tablični prostor baze podataka",
+    "Please specify the port number along with the host name (e.g., localhost:5432)." : "Navedite broj porta zajedno s nazivom računala (npr. localhost: 5432).",
+    "Database host" : "Glavno računalo baze podataka",
+    "Install" : "Instaliraj",
+    "Need help?" : "Treba li vam pomoć?",
+    "See the documentation" : "Pogledajte dokumentaciju",
     "Search {types} …" : "Traži {types}…",
     "Choose" : "Odaberite",
     "Copy" : "Kopiraj",
@@ -176,11 +194,6 @@ OC.L10N.register(
     "Type to search for existing projects" : "Upišite za pretraživanje postojećih projekata",
     "New in" : "Novo u",
     "View changelog" : "Prikaži zapis promjena",
-    "Very weak password" : "Zaporka vrlo slaba",
-    "Weak password" : "Zaporka Slaba",
-    "So-so password" : "Zaporka prosječne jačine",
-    "Good password" : "Zaporka dobra",
-    "Strong password" : "Zaporka jaka",
     "No action available" : "Nikakve radnje trenutno nisu dostupne",
     "Error fetching contact actions" : "Pogreška pri dohvaćanju radnji kontakata",
     "Non-existing tag #{tag}" : "Nepostojeća oznaka #{tag}",
@@ -213,29 +226,6 @@ OC.L10N.register(
     "File: %s" : "Datoteka: %s",
     "Line: %s" : "Red: %s",
     "Trace" : "Prati",
-    "Security warning" : "Sigurnosno upozorenje",
-    "Your data directory and files are probably accessible from the internet because the .htaccess file does not work." : "Vašem podatkovnom direktoriju i datotekama vjerojatno se može pristupiti putem interneta jer .htaccess datoteka ne radi.",
-    "For information how to properly configure your server, please see the <a href=\"%s\" target=\"_blank\" rel=\"noreferrer noopener\">documentation</a>." : "Informacije o ispravnom konfiguriranju poslužitelja potražite u <a href=\"%s\" target=\"_blank\" rel=\"noreferrer noopener\">dokumentaciji</a>.",
-    "Show password" : "Pokaži zaporku",
-    "Toggle password visibility" : "Uključivanje/isključivanje vidljivosti zaporke",
-    "Storage & database" : "Pohrana i baza podataka",
-    "Data folder" : "Mapa za podatke",
-    "Configure the database" : "Konfiguriraj bazu podataka",
-    "Only %s is available." : "Jedino je %s dostupan.",
-    "Install and activate additional PHP modules to choose other database types." : "Instalirajte i aktivirajte dodatne module PHP-a kako biste odabrali druge vrste baza podataka.",
-    "For more details check out the documentation." : "Za više informacija pogledajte dokumentaciju.",
-    "Database password" : "Zaporka baze podataka",
-    "Database name" : "Naziv baze podataka",
-    "Database tablespace" : "Tablični prostor baze podataka",
-    "Database host" : "Glavno računalo baze podataka",
-    "Please specify the port number along with the host name (e.g., localhost:5432)." : "Navedite broj porta zajedno s nazivom računala (npr. localhost: 5432).",
-    "Performance warning" : "Upozorenje o performansama",
-    "You chose SQLite as database." : "Odabrali ste SQLite kao bazu podataka.",
-    "SQLite should only be used for minimal and development instances. For production we recommend a different database backend." : "SQLite bi se trebao upotrebljavati samo za minimalne i razvojne instance. Za produkcijske instance preporučujemo korištenje neke druge pozadinske baze podataka.",
-    "If you use clients for file syncing, the use of SQLite is highly discouraged." : "Ako upotrebljavate klijente za sinkronizaciju datoteka, preporučujemo izbjegavanje baze podataka SQLite.",
-    "Install" : "Instaliraj",
-    "Need help?" : "Treba li vam pomoć?",
-    "See the documentation" : "Pogledajte dokumentaciju",
     "It looks like you are trying to reinstall your Nextcloud. However the file CAN_INSTALL is missing from your config directory. Please create the file CAN_INSTALL in your config folder to continue." : "Primijetili smo da pokušavate ponovno instalirati Nextcloud. Međutim, datoteka CAN_INSTALL nedostaje iz vašeg direktorija. Stvorite datoteku CAN_INSTALL u konfiguracijskoj mapi prije nego što nastavite.",
     "Could not remove CAN_INSTALL from the config folder. Please remove this file manually." : "CAN_INSTALL nije moguće ukloniti iz konfiguracijske mape. Ručno uklonite ovu datoteku.",
     "This application requires JavaScript for correct operation. Please {linkstart}enable JavaScript{linkend} and reload the page." : "Ova aplikacija zahtijeva JavaScript za ispravan rad. {linkstart}Omogućite JavaScript{linkend} i ponovno učitajte stranicu.",
@@ -287,6 +277,17 @@ OC.L10N.register(
     "This page will refresh itself when the instance is available again." : "Ova će se stranica osvježiti kada je instanca ponovno dostupna.",
     "Contact your system administrator if this message persists or appeared unexpectedly." : "Obratite se administratoru sustava ako se ova poruka ponavlja ili se pojavila neočekivano.",
     "Chatting, video calls, screensharing, online meetings and web conferencing – in your browser and with mobile apps." : "Razmjenjivanje poruka, video pozivi, dijeljenje zaslona, sastanci na mreži i web-konferencije – putem preglednika i mobilnih aplikacija.",
-    "Error loading message template: {error}" : "Pogrešno učitavanje predloška za poruke: {error}"
+    "Error loading message template: {error}" : "Pogrešno učitavanje predloška za poruke: {error}",
+    "Very weak password" : "Zaporka vrlo slaba",
+    "Weak password" : "Zaporka Slaba",
+    "So-so password" : "Zaporka prosječne jačine",
+    "Good password" : "Zaporka dobra",
+    "Strong password" : "Zaporka jaka",
+    "Your data directory and files are probably accessible from the internet because the .htaccess file does not work." : "Vašem podatkovnom direktoriju i datotekama vjerojatno se može pristupiti putem interneta jer .htaccess datoteka ne radi.",
+    "For information how to properly configure your server, please see the <a href=\"%s\" target=\"_blank\" rel=\"noreferrer noopener\">documentation</a>." : "Informacije o ispravnom konfiguriranju poslužitelja potražite u <a href=\"%s\" target=\"_blank\" rel=\"noreferrer noopener\">dokumentaciji</a>.",
+    "Show password" : "Pokaži zaporku",
+    "Toggle password visibility" : "Uključivanje/isključivanje vidljivosti zaporke",
+    "Configure the database" : "Konfiguriraj bazu podataka",
+    "Only %s is available." : "Jedino je %s dostupan."
 },
 "nplurals=3; plural=n%10==1 && n%100!=11 ? 0 : n%10>=2 && n%10<=4 && (n%100<10 || n%100>=20) ? 1 : 2;");
