@@ -146,23 +146,21 @@ OC.L10N.register(
     "Account name" : "Heiti notandaaðgangs",
     "Server side authentication failed!" : "Auðkenning af hálfu þjóns tókst ekki!",
     "Please contact your administrator." : "Hafðu samband við kerfisstjóra.",
-    "Temporary error" : "Tímabundin villa",
-    "Please try again." : "Endilega reyndu aftur.",
     "An internal error occurred." : "Innri villa kom upp.",
     "Please try again or contact your administrator." : "Reyndu aftur eða hafðu samband við kerfisstjóra.",
     "Password" : "Lykilorð",
     "Log in with a device" : "Skrá inn með tæki",
     "Login or email" : "Notandanafn eða lykilorð",
     "Your account is not setup for passwordless login." : "Aðgangur þinn er ekki uppsettur með lykilorðalausri innskráningu.",
-    "Browser not supported" : "Það er ekki stuðningur við vafrann",
-    "Passwordless authentication is not supported in your browser." : "Lykilorðalaus auðkenning er ekki studd í vafranum þínum.",
     "Your connection is not secure" : "Tengingin þín er ekki örugg",
     "Passwordless authentication is only available over a secure connection." : "Lykilorðalaus auðkenning er aðeins tiltæk í gegnum örugga tengingu.",
+    "Browser not supported" : "Það er ekki stuðningur við vafrann",
+    "Passwordless authentication is not supported in your browser." : "Lykilorðalaus auðkenning er ekki studd í vafranum þínum.",
     "Reset password" : "Endursetja lykilorð",
+    "Back to login" : "Til baka í innskráningu",
     "If this account exists, a password reset message has been sent to its email address. If you do not receive it, verify your email address and/or Login, check your spam/junk folders or ask your local administration for help." : "Ef þessi aðgangur fyrirfinnst, þá hafa skilaboð um endurstillingu lykilorðs verið send á tölvupóstfang aðgangsins. Ef þú hefur ekki fengið slík skilaboð, skaltu athuga tölvupóstfangið þitt og/eða notandanafnið, skoða vel í möppur fyrir ruslpóst/rusl eða beðið kerfisstjórnendur þína um aðstoð.",
     "Couldn't send reset email. Please contact your administrator." : "Gat ekki sent endurstillingu í tölvupósti. Hafðu samband við kerfisstjóra.",
     "Password cannot be changed. Please contact your administrator." : "Ekki er hægt að breyta lykilorði. Hafðu samband við kerfisstjóra.",
-    "Back to login" : "Til baka í innskráningu",
     "New password" : "Nýtt lykilorð",
     "Your files are encrypted. There will be no way to get your data back after your password is reset. If you are not sure what to do, please contact your administrator before you continue. Do you really want to continue?" : "Skrárnar þínar eru dulritaðar. Það er engin leið til að fá gögnin þín til baka eftir lykilorðið þitt er endurstillt. Ef þú ert ekki viss hvað eigi að gera, skaltu hafa samband við kerfisstjórann áður en þú heldur áfram. Viltu halda áfram?",
     "I know what I'm doing" : "Ég veit hvað ég er að gera",
@@ -207,6 +205,25 @@ OC.L10N.register(
     "Login form is disabled." : "Innskráningarform er óvirkt.",
     "The Nextcloud login form is disabled. Use another login option if available or contact your administration." : "Innskráningarform Nextcloud er óvirkt. Notaðu aðra aðferð til innskráningar ef slíkt er í boði eða hafðu samband við kerfisstjórnanda.",
     "More actions" : "Fleiri aðgerðir",
+    "Security warning" : "Öryggisviðvörun",
+    "Storage & database" : "Geymsla & gagnagrunnur",
+    "Data folder" : "Gagnamappa",
+    "Install and activate additional PHP modules to choose other database types." : "Setja upp og virkja viðbótar PHP-einingar til að geta valið aðrar tegundir gagnagrunna.",
+    "For more details check out the documentation." : "Frekari upplýsingar eru í hjálparskjölum.",
+    "Performance warning" : "Afkastaviðvörun",
+    "You chose SQLite as database." : "Þú valdir SQLite sem gagnagrunn.",
+    "SQLite should only be used for minimal and development instances. For production we recommend a different database backend." : "SQLite ætti aðeins að nota fyrir lágmarksuppsetningar og til prófana. Fyrir stærri uppsetningar mælum við með að velja annan gagnagrunnsbakenda.",
+    "If you use clients for file syncing, the use of SQLite is highly discouraged." : "Ef verið er að nota biðlaraforrit til að samstilla skrár, þá er ekki mælt með notkun SQLite.",
+    "Database user" : "Notandi gagnagrunns",
+    "Database password" : "Lykilorð gagnagrunns",
+    "Database name" : "Heiti gagnagrunns",
+    "Database tablespace" : "Töflusvæði gagnagrunns",
+    "Please specify the port number along with the host name (e.g., localhost:5432)." : "Taktu fram númer gáttar ásamt nafni hýsilvélar (t.d., localhost:5432).",
+    "Database host" : "Netþjónn gagnagrunns",
+    "Installing …" : "Set upp…",
+    "Install" : "Setja upp",
+    "Need help?" : "Þarftu hjálp?",
+    "See the documentation" : "Sjá hjálparskjölin",
     "{name} version {version} and above" : "{name} útgáfa {version} og hærri",
     "This browser is not supported" : "Það er ekki stuðningur við þennan vafra",
     "Your browser is not supported. Please upgrade to a newer version or a supported one." : "Það er ekki stuðningur við vafrann þinn. Endilega uppfærðu í nýrri útgáfu eða vafra sem er studdur.",
@@ -247,11 +264,6 @@ OC.L10N.register(
     "Type to search for existing projects" : "Skrifaðu hér til að leita að fyrirliggjandi verkefnum",
     "New in" : "Nýtt í",
     "View changelog" : "Skoða breytingaannál",
-    "Very weak password" : "Mjög veikt lykilorð",
-    "Weak password" : "Veikt lykilorð",
-    "So-so password" : "Miðlungs lykilorð",
-    "Good password" : "Gott lykilorð",
-    "Strong password" : "Sterkt lykilorð",
     "No action available" : "Engin aðgerð tiltæk",
     "Error fetching contact actions" : "Villa við að sækja aðgerðir tengiliða",
     "Close \"{dialogTitle}\" dialog" : "Loka \"{dialogTitle}\"-glugga",
@@ -289,34 +301,6 @@ OC.L10N.register(
     "File: %s" : "Skrá: %s",
     "Line: %s" : "Lína: %s",
     "Trace" : "Rekja",
-    "Security warning" : "Öryggisviðvörun",
-    "Your data directory and files are probably accessible from the internet because the .htaccess file does not work." : "Gagnamappan og skrárnar eru líklega aðgengilegar af internetinu vegna þess að .htaccess skrá er ekki virk.",
-    "For information how to properly configure your server, please see the <a href=\"%s\" target=\"_blank\" rel=\"noreferrer noopener\">documentation</a>." : "Til að fá upplýsingar hvernig á að stilla miðlarann almennilega, skaltu skoða <a href=\"%s\" target=\"_blank\" rel=\"noreferrer noopener\">hjálparskjölin</a>.",
-    "<strong>Create an admin account</strong>" : "<strong>Útbúa kerfisstjóraaðgang</strong>",
-    "New admin account name" : "Nýtt heiti kerfisstjóraaðgangs",
-    "New admin password" : "Nýtt lykilorð kerfisstjóra",
-    "Show password" : "Sýna lykilorð",
-    "Toggle password visibility" : "Breyta sýnileika lykilorðs",
-    "Storage & database" : "Geymsla & gagnagrunnur",
-    "Data folder" : "Gagnamappa",
-    "Configure the database" : "Stilla gagnagrunninn",
-    "Only %s is available." : "Aðeins %s eru laus.",
-    "Install and activate additional PHP modules to choose other database types." : "Setja upp og virkja viðbótar PHP-einingar til að geta valið aðrar tegundir gagnagrunna.",
-    "For more details check out the documentation." : "Frekari upplýsingar eru í hjálparskjölum.",
-    "Database account" : "Gagnagrunnsaðgangur",
-    "Database password" : "Lykilorð gagnagrunns",
-    "Database name" : "Heiti gagnagrunns",
-    "Database tablespace" : "Töflusvæði gagnagrunns",
-    "Database host" : "Netþjónn gagnagrunns",
-    "Please specify the port number along with the host name (e.g., localhost:5432)." : "Taktu fram númer gáttar ásamt nafni hýsilvélar (t.d., localhost:5432).",
-    "Performance warning" : "Afkastaviðvörun",
-    "You chose SQLite as database." : "Þú valdir SQLite sem gagnagrunn.",
-    "SQLite should only be used for minimal and development instances. For production we recommend a different database backend." : "SQLite ætti aðeins að nota fyrir lágmarksuppsetningar og til prófana. Fyrir stærri uppsetningar mælum við með að velja annan gagnagrunnsbakenda.",
-    "If you use clients for file syncing, the use of SQLite is highly discouraged." : "Ef verið er að nota biðlaraforrit til að samstilla skrár, þá er ekki mælt með notkun SQLite.",
-    "Install" : "Setja upp",
-    "Installing …" : "Set upp…",
-    "Need help?" : "Þarftu hjálp?",
-    "See the documentation" : "Sjá hjálparskjölin",
     "It looks like you are trying to reinstall your Nextcloud. However the file CAN_INSTALL is missing from your config directory. Please create the file CAN_INSTALL in your config folder to continue." : "Það lítur út fyrir að þú sért að reyna að setja Nextcloud upp aftur. Hinsvegar vantar skrána CAN_INSTALL í grunnstillingamöppuna þína (config directory). Búðu til skrána CAN_INSTALL í grunnstillingamöppunni til að halda áfram.",
     "Could not remove CAN_INSTALL from the config folder. Please remove this file manually." : "Gat ekki fjarlægt CAN_INSTALL úr stillingamöppunni. Fjarlægðu þessa skrá handvirkt.",
     "This application requires JavaScript for correct operation. Please {linkstart}enable JavaScript{linkend} and reload the page." : "Þetta forrit krefst JavaScript fyrir rétta virkni. {linkstart} virkjaðu JavaScript {linkend} og endurlestu síðan síðuna.",
@@ -385,7 +369,22 @@ OC.L10N.register(
     "Edit Profile" : "Breyta sniði",
     "The headline and about sections will show up here" : "Fyrirsögnin og hlutar um hugbúnaðinn munu birtast hér",
     "Error loading message template: {error}" : "Villa við að hlaða inn sniðmáti fyrir skilaboð: {error}",
+    "Very weak password" : "Mjög veikt lykilorð",
+    "Weak password" : "Veikt lykilorð",
+    "So-so password" : "Miðlungs lykilorð",
+    "Good password" : "Gott lykilorð",
+    "Strong password" : "Sterkt lykilorð",
     "Profile not found" : "Sniðið finnst ekki",
-    "The profile does not exist." : "Sniðið er ekki til."
+    "The profile does not exist." : "Sniðið er ekki til.",
+    "Your data directory and files are probably accessible from the internet because the .htaccess file does not work." : "Gagnamappan og skrárnar eru líklega aðgengilegar af internetinu vegna þess að .htaccess skrá er ekki virk.",
+    "For information how to properly configure your server, please see the <a href=\"%s\" target=\"_blank\" rel=\"noreferrer noopener\">documentation</a>." : "Til að fá upplýsingar hvernig á að stilla miðlarann almennilega, skaltu skoða <a href=\"%s\" target=\"_blank\" rel=\"noreferrer noopener\">hjálparskjölin</a>.",
+    "<strong>Create an admin account</strong>" : "<strong>Útbúa kerfisstjóraaðgang</strong>",
+    "New admin account name" : "Nýtt heiti kerfisstjóraaðgangs",
+    "New admin password" : "Nýtt lykilorð kerfisstjóra",
+    "Show password" : "Sýna lykilorð",
+    "Toggle password visibility" : "Breyta sýnileika lykilorðs",
+    "Configure the database" : "Stilla gagnagrunninn",
+    "Only %s is available." : "Aðeins %s eru laus.",
+    "Database account" : "Gagnagrunnsaðgangur"
 },
 "nplurals=2; plural=(n % 10 != 1 || n % 100 == 11);");
