@@ -146,8 +146,6 @@ OC.L10N.register(
     "Account name" : "Nome account",
     "Server side authentication failed!" : "Autenticazione lato server non riuscita!",
     "Please contact your administrator." : "Contatta il tuo amministratore di sistema.",
-    "Temporary error" : "Errore temporaneo",
-    "Please try again." : "Riprova.",
     "An internal error occurred." : "Si è verificato un errore interno.",
     "Please try again or contact your administrator." : "Prova ancora o contatta il tuo amministratore.",
     "Password" : "Password",
