@@ -146,8 +146,8 @@ OC.L10N.register(
     "Account name" : "계정 아이디",
     "Server side authentication failed!" : "서버 인증 실패!",
     "Please contact your administrator." : "관리자에게 문의하십시오.",
-    "Temporary error" : "임시 오류",
-    "Please try again." : "다시 시도해 보세요.",
+    "Session error" : "세션 오류",
+    "It appears your session token has expired, please refresh the page and try again." : "세션 토큰이 만료된 것으로 보입니다. 페이지 새로고침을 하고 다시 시도하세요.",
     "An internal error occurred." : "내부 오류가 발생했습니다.",
     "Please try again or contact your administrator." : "다시 시도하거나 관리자에게 연락하십시오.",
     "Password" : "암호",
@@ -207,9 +207,25 @@ OC.L10N.register(
     "Login form is disabled." : "로그인 양식이 비활성화 되었습니다.",
     "The Nextcloud login form is disabled. Use another login option if available or contact your administration." : "Nextcloud 로그인 양식이 비활성화 되었습니다. 이용 가능한 다른 방법으로 로그인 하거나, 관리자에게 문의하십시오.",
     "More actions" : "더 많은 동작",
+    "Password is too weak" : "너무 약한 암호",
+    "Password is weak" : "약한 암호",
+    "Password is average" : "보통 암호",
+    "Password is strong" : "강한 암호",
+    "Password is very strong" : "매우 강한 암호",
+    "Password is extremely strong" : "극도로 강한 암호",
+    "Unknown password strength" : "알 수 없는 암호 강도",
+    "Your data directory and files are probably accessible from the internet because the <code>.htaccess</code> file does not work." : "<code>.htaccess</code>파일이 작동하지 않아 당신의 데이터 디렉토리와 파일이 인터넷에 노출될 수도 있습니다.",
+    "For information how to properly configure your server, please {linkStart}see the documentation{linkEnd}" : "서버를 적절히 구성하기 위한 정보는  {linkStart}문서를 참조하세요{linkEnd}",
+    "Autoconfig file detected" : "자동구성 파일 감지됨",
+    "The setup form below is pre-filled with the values from the config file." : "아래 설정 입력란은 설정파일의 값으로 미리 입력됩니다.",
     "Security warning" : "보안 경고",
+    "Create administration account" : "관리자 계정 생성",
+    "Administration account name" : "관리자 계정 이름",
+    "Administration account password" : "관리자 계정 암호",
     "Storage & database" : "저장소 및 데이터베이스",
     "Data folder" : "데이터 폴더",
+    "Database configuration" : "데이터베이스 구성",
+    "Only {firstAndOnlyDatabase} is available." : "오직 {firstAndOnlyDatabase}만 가능합니다.",
     "Install and activate additional PHP modules to choose other database types." : "다른 데이터베이스 종류를 사용하려면 추가 PHP 모듈을 설치 및 활성화하십시오.",
     "For more details check out the documentation." : "자세한 정보를 보려면 문서를 참고하십시오.",
     "Performance warning" : "성능 경고",
@@ -222,6 +238,7 @@ OC.L10N.register(
     "Database tablespace" : "데이터베이스 테이블 공간",
     "Please specify the port number along with the host name (e.g., localhost:5432)." : "호스트 이름과 함께 포트 번호를 지정하십시오(예: localhost:5432)",
     "Database host" : "데이터베이스 호스트",
+    "localhost" : "로컬호스트",
     "Installing …" : "설치중…",
     "Install" : "설치",
     "Need help?" : "도움이 필요한가요?",
