@@ -5,11 +5,11 @@ OC.L10N.register(
     "File is too big" : "O arquivo é muito grande",
     "The selected file is not an image." : "O arquivo selecionado não é uma imagem",
     "The selected file cannot be read." : "O arquivo selecionado não pôde ser lido",
-    "The file was uploaded" : "O arquivo foi enviado",
-    "The uploaded file exceeds the upload_max_filesize directive in php.ini" : "O arquivo enviado excede a diretiva upload_max_filesize em php.ini",
-    "The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form" : "O arquivo enviado excede a diretiva MAX_FILE_SIZE que foi especificada no formulário HTML",
+    "The file was uploaded" : "O arquivo foi carregado",
+    "The uploaded file exceeds the upload_max_filesize directive in php.ini" : "O arquivo carregado excede a diretiva upload_max_filesize em php.ini",
+    "The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form" : "O arquivo carregado excede a diretiva MAX_FILE_SIZE que foi especificada no formulário HTML",
     "The file was only partially uploaded" : "O arquivo foi carregado apenas parcialmente",
-    "No file was uploaded" : "Nenhum arquivo foi enviado",
+    "No file was uploaded" : "Nenhum arquivo foi carregado",
     "Missing a temporary folder" : "Falta uma pasta temporária",
     "Could not write file to disk" : "Não foi possível gravar o arquivo no disco",
     "A PHP extension stopped the file upload" : "Uma extensão PHP interrompeu o upload do arquivo",
@@ -25,27 +25,27 @@ OC.L10N.register(
     "State token does not match" : "O estado do token não coincide",
     "Invalid app password" : "Senha do aplicativo inválida",
     "Could not complete login" : "Não foi possível concluir o login",
-    "State token missing" : "State token missing",
+    "State token missing" : "Falta o token de estado",
     "Your login token is invalid or has expired" : "Seu token de login é inválido ou expirou",
     "This community release of Nextcloud is unsupported and push notifications are limited." : "Esta versão da comunidade do Nextcloud não é compatível e as notificações por push são limitadas.",
-    "Login" : "Entrar",
+    "Login" : "Login",
     "Unsupported email length (>255)" : "Comprimento de e-mail não suportado (>255)",
     "Password reset is disabled" : "A redefinição de senha está desabilitada",
     "Could not reset password because the token is expired" : "Não foi possível redefinir a senha porque o token expirou",
     "Could not reset password because the token is invalid" : "Não foi possível redefinir a senha porque o token é inválido",
     "Password is too long. Maximum allowed length is 469 characters." : "A senha é muito longa. O comprimento máximo permitido é de 469 caracteres.",
-    "%s password reset" : "%s redefinir senha",
-    "Password reset" : "Redefinir a senha",
+    "%s password reset" : "%s redefinição da senha",
+    "Password reset" : "Redefinição da senha",
     "Click the following button to reset your password. If you have not requested the password reset, then ignore this email." : "Clique no botão abaixo para redefinir sua senha. Se você não solicitou isso, ignore este e-mail.",
     "Click the following link to reset your password. If you have not requested the password reset, then ignore this email." : "Clique no link abaixo para redefinir sua senha. Se você não solicitou isso, ignore este e-mail.",
-    "Reset your password" : "Redefinir sua senha",
+    "Reset your password" : "Redefina sua senha",
     "The given provider is not available" : "O provedor fornecido não está disponível",
     "Task not found" : "Tarefa não encontrada",
     "Internal error" : "Erro interno",
     "Not found" : "Não encontrado",
-    "Bad request" : "Pedido ruim",
-    "Requested task type does not exist" : "O tipo de tarefa solicitada não existe",
-    "Necessary language model provider is not available" : "O provedor de modelo de idioma necessário não está disponível",
+    "Bad request" : "Requisição inválida",
+    "Requested task type does not exist" : "O tipo de tarefa solicitado não existe",
+    "Necessary language model provider is not available" : "O provedor de modelo de linguagem necessário não está disponível",
     "No text to image provider is available" : "Nenhum provedor de texto para imagem está disponível",
     "Image not found" : "Imagem não encontrada",
     "No translation provider available" : "Nenhum provedor de tradução disponível",
@@ -55,7 +55,7 @@ OC.L10N.register(
     "Some of your link shares have been removed" : "Alguns dos seus compartilhamentos por link foram removidos",
     "Due to a security bug we had to remove some of your link shares. Please see the link for more information." : "Devido a um bug de segurança, tivemos que remover alguns dos seus compartilhamentos por link. Por favor, veja o link para mais informações.",
     "The account limit of this instance is reached." : "O limite de contas desta instância foi atingido.",
-    "Enter your subscription key in the support app in order to increase the account limit. This does also grant you all additional benefits that Nextcloud Enterprise offers and is highly recommended for the operation in companies." : "Digite sua chave de assinatura no aplicativo de suporte para aumentar o limite da conta. Isso também concede a você todos os benefícios adicionais que o Nextcloud Enterprise oferece e é altamente recomendado para operações em empresas.",
+    "Enter your subscription key in the support app in order to increase the account limit. This does also grant you all additional benefits that Nextcloud Enterprise offers and is highly recommended for the operation in companies." : "Digite sua chave de assinatura no aplicativo de suporte para aumentar o limite de contas. Isso também concede a você todos os benefícios adicionais que o Nextcloud Empresarial oferece e é altamente recomendado para operações em empresas.",
     "Learn more ↗" : "Saiba mais ↗",
     "Preparing update" : "Preparando a atualização",
     "[%d / %d]: %s" : "[%d / %d]: %s",
@@ -63,13 +63,13 @@ OC.L10N.register(
     "Repair info:" : "Informação do reparo:",
     "Repair warning:" : "Aviso do reparo:",
     "Repair error:" : "Erro do reparo:",
-    "Please use the command line updater because updating via browser is disabled in your config.php." : "Please use the command line updater because updating via browser is disabled in your config.php.",
+    "Please use the command line updater because updating via browser is disabled in your config.php." : "Por favor, use o atualizador de linha de comando porque a atualização via navegador está desativada em seu config.php.",
     "Turned on maintenance mode" : "Ativar o modo de manutenção",
     "Turned off maintenance mode" : "Desativar o modo de manutenção",
     "Maintenance mode is kept active" : "O modo de manutenção está sendo mantido como ativo",
     "Updating database schema" : "Atualizando o schema do banco de dados",
     "Updated database" : "Atualizar o banco de dados",
-    "Update app \"%s\" from App Store" : "Atualizar aplicativo \"%s\" da App Store",
+    "Update app \"%s\" from App Store" : "Atualizar aplicativo \"%s\" da Loja de Aplicativos",
     "Checking whether the database schema for %s can be updated (this can take a long time depending on the database size)" : "Verificando se o schema do banco de dados para %s pode ser atualizado (isso pode levar muito tempo, dependendo do tamanho do banco de dados)",
     "Updated \"%1$s\" to %2$s" : "Atualizou \"%1$s\" para %2$s",
     "Set log level to debug" : "Definir o nível de log para debug",
@@ -105,20 +105,20 @@ OC.L10N.register(
     "Yes" : "Sim",
     "The remote URL must include the user." : "A URL remota deve incluir o usuário.",
     "Invalid remote URL." : "URL remota inválida.",
-    "Failed to add the public link to your Nextcloud" : "Ocorreu uma falha ao adicionar o link público ao seu Nextcloud",
+    "Failed to add the public link to your Nextcloud" : "Falha ao adicionar o link público ao seu Nextcloud",
     "Federated user" : "Usuário federado",
     "user@your-nextcloud.org" : "user@your-nextcloud.org",
     "Create share" : "Criar compartilhamento",
     "Direct link copied to clipboard" : "Link direto copiado para a área de transferência",
     "Please copy the link manually:" : "Copie o link manualmente:",
-    "Custom date range" : "Data personalizada",
+    "Custom date range" : "Intervalo personalizado",
     "Pick start date" : "Escolha uma data de início",
     "Pick end date" : "Escolha uma data de fim",
-    "Search in date range" : "Pesquise em um intervalo de data",
+    "Search in date range" : "Pesquisar neste intervalo",
     "Search in current app" : "Pesquisar no aplicativo atual",
     "Clear search" : "Limpar pesquisa",
-    "Search everywhere" : "Pesquise em qualquer lugar",
-    "Searching …" : "Pesquisando...",
+    "Search everywhere" : "Pesquisar em qualquer lugar",
+    "Searching …" : "Pesquisando …",
     "Start typing to search" : "Comece a digitar para pesquisar",
     "No matching results" : "Nenhum resultado encontrado",
     "Today" : "Hoje",
@@ -127,27 +127,27 @@ OC.L10N.register(
     "This year" : "Este ano",
     "Last year" : "Último ano",
     "Unified search" : "Pesquisa unificada",
-    "Search apps, files, tags, messages" : "Procure por apps, arquivos, etiquetas, mensagens",
+    "Search apps, files, tags, messages" : "Pesquise aplicativos, arquivos, etiquetas, mensagens",
     "Places" : "Lugares",
     "Date" : "Data",
-    "Search people" : "Procure pessoas",
+    "Search people" : "Pesquise pessoas",
     "People" : "Pessoas",
     "Filter in current view" : "Filtrar na visualização atual",
     "Results" : "Resultados",
     "Load more results" : "Carregar mais resultados",
-    "Search in" : "Procurar em",
+    "Search in" : "Pesquisar em",
     "Log in" : "Entrar",
-    "Logging in …" : "Entrando...",
+    "Logging in …" : "Entrando …",
     "Log in to {productName}" : "Faça login em {productName}",
     "Wrong login or password." : "Login ou senha incorretos.",
-    "This account is disabled" : "Essa conta está desativada",
+    "This account is disabled" : "Esta conta está desativada",
     "We have detected multiple invalid login attempts from your IP. Therefore your next login is throttled up to 30 seconds." : "Detectamos várias tentativas de login inválidas de seu IP. Portanto, seu próximo login será desacelerado em até 30 segundos.",
     "Account name or email" : "Nome da conta ou e-mail",
     "Account name" : "Nome da conta",
     "Server side authentication failed!" : "Autenticação do servidor falhou!",
     "Please contact your administrator." : "Por favor, entre em contato com o administrador.",
-    "Temporary error" : "Erro temporário",
-    "Please try again." : "Por favor, tente novamente.",
+    "Session error" : "Erro de sessão",
+    "It appears your session token has expired, please refresh the page and try again." : "Parece que seu token de sessão expirou. Atualize a página e tente novamente.",
     "An internal error occurred." : "Ocorreu um erro interno.",
     "Please try again or contact your administrator." : "Tente novamente ou entre em contato com o administrador.",
     "Password" : "Senha",
@@ -160,9 +160,9 @@ OC.L10N.register(
     "Passwordless authentication is not supported in your browser." : "A autenticação sem senha não é suportada no seu navegador.",
     "Reset password" : "Redefinir senha",
     "Back to login" : "Voltar ao login",
-    "If this account exists, a password reset message has been sent to its email address. If you do not receive it, verify your email address and/or Login, check your spam/junk folders or ask your local administration for help." : "Se essa conta existir, uma mensagem de redefinição de senha foi enviada para o endereço de e-mail associado a ela. Se você não receber, verifique seu endereço de e-mail e/ou faça login, confira suas pastas de spam/lixeira ou peça ajuda à administração local.",
+    "If this account exists, a password reset message has been sent to its email address. If you do not receive it, verify your email address and/or Login, check your spam/junk folders or ask your local administration for help." : "Se essa conta existir, uma mensagem de redefinição da senha foi enviada para o endereço de e-mail associado a ela. Se você não a receber, verifique seu endereço de e-mail e/ou login, confira suas pastas de spam/lixo de e-mail ou peça ajuda à administração local.",
     "Couldn't send reset email. Please contact your administrator." : "Não foi possível enviar o e-mail de redefinição. Por favor, contate o administrador.",
-    "Password cannot be changed. Please contact your administrator." : "A senha não pôde ser alterada. Por favor contate seu administrador.",
+    "Password cannot be changed. Please contact your administrator." : "A senha não pôde ser alterada. Por favor, contate seu administrador.",
     "New password" : "Nova senha",
     "Your files are encrypted. There will be no way to get your data back after your password is reset. If you are not sure what to do, please contact your administrator before you continue. Do you really want to continue?" : "Seus arquivos são criptografados. Não há como recuperar os dados depois que a senha for redefinida. Se não tiver certeza do que fazer, entre em contato com o administrador. Quer realmente continuar?",
     "I know what I'm doing" : "Eu sei o que estou fazendo",
@@ -170,16 +170,16 @@ OC.L10N.register(
     "Schedule work & meetings, synced with all your devices." : "Programe trabalhos e reuniões, sincronizados com seus dispositivos.",
     "Keep your colleagues and friends in one place without leaking their private info." : "Mantenha seus colegas e amigos em um só lugar sem vazar informações particulares.",
     "Simple email app nicely integrated with Files, Contacts and Calendar." : "Aplicativo de e-mail simples e bem integrado com Arquivos, Contatos e Calendário.",
-    "Chatting, video calls, screen sharing, online meetings and web conferencing – in your browser and with mobile apps." : "Bate-papo, vídeo chamadas, compartilhamento de tela, reuniões online e conferência na web - no seu navegador e com aplicativos móveis.",
-    "Collaborative documents, spreadsheets and presentations, built on Collabora Online." : "Documentos colaborativos, planilhas e apresentações, construídos no Collabora Online.",
-    "Distraction free note taking app." : "Distraction free note taking app.",
+    "Chatting, video calls, screen sharing, online meetings and web conferencing – in your browser and with mobile apps." : "Bate-papo, vídeo chamadas, compartilhamento de tela, reuniões on-line e webconferências - no seu navegador e com aplicativos móveis.",
+    "Collaborative documents, spreadsheets and presentations, built on Collabora Online." : "Documentos, planilhas e apresentações colaborativos, criados no Collabora Online.",
+    "Distraction free note taking app." : "Aplicativo de notas sem distrações.",
     "Recommended apps" : "Aplicativos recomendados",
     "Loading apps …" : "Carregando aplicativos...",
-    "Could not fetch list of apps from the App Store." : "Não foi possível buscar a lista de aplicativos na App Store.",
+    "Could not fetch list of apps from the App Store." : "Não foi possível buscar a lista de aplicativos da Loje de Aplicativos.",
     "App download or installation failed" : "O download ou a instalação do aplicativo falhou",
     "Cannot install this app because it is not compatible" : "Não foi possível instalar este aplicativo pois não é compatível.",
     "Cannot install this app" : "Não foi possível instalar este aplicativo.",
-    "Skip" : "Ignorar",
+    "Skip" : "Pular",
     "Installing apps …" : "Instalando aplicativos...",
     "Install recommended apps" : "Instalar aplicativos recomendados",
     "Avatar of {displayName}" : "Avatar de {displayName}",
@@ -188,7 +188,7 @@ OC.L10N.register(
     "Looking for {term} …" : "Procurando por {term}…",
     "Search contacts" : "Pesquisar contatos",
     "Reset search" : "Redefinir pesquisa",
-    "Search contacts …" : "Procurar contatos...",
+    "Search contacts …" : "Pesquisar contatos …",
     "Could not load your contacts" : "Não foi possível carregar seus contatos",
     "No contacts found" : "Nenhum contato encontrado",
     "Show all contacts" : "Mostrar todos os contatos",
@@ -198,7 +198,7 @@ OC.L10N.register(
     "Press Enter to start searching" : "Pressione Enter para iniciar a pesquisa",
     "_Please enter {minSearchLength} character or more to search_::_Please enter {minSearchLength} characters or more to search_" : ["Digite {minSearchLength} caractere ou mais para pesquisar","Digite {minSearchLength} caracteres ou mais para pesquisar","Digite {minSearchLength} caracteres ou mais para pesquisar"],
     "An error occurred while searching for {type}" : "Ocorreu um erro ao pesquisar por {type}",
-    "Search starts once you start typing and results may be reached with the arrow keys" : "A pesquisa iniciará assim que você começar a digitar e os resultados você pode navegar com as setas do teclado",
+    "Search starts once you start typing and results may be reached with the arrow keys" : "A pesquisa iniciará assim que você começar a digitar e você pode navegar nos resultados com as teclas de seta",
     "Search for {name} only" : "Pesquisar somente por {name}",
     "Loading more results …" : "Carregando mais resultados…",
     "Forgot password?" : "Esqueceu a senha?",
@@ -207,9 +207,25 @@ OC.L10N.register(
     "Login form is disabled." : "O formulário de login está desativado.",
     "The Nextcloud login form is disabled. Use another login option if available or contact your administration." : "O formulário de login do Nextcloud está desabilitado. Use outra opção de login, se disponível, ou entre em contato com sua administração.",
     "More actions" : "Mais ações",
+    "Password is too weak" : "A senha é muito fraca",
+    "Password is weak" : "A senha é fraca",
+    "Password is average" : "A senha é média",
+    "Password is strong" : "A senha é forte",
+    "Password is very strong" : "A senha é muito forte",
+    "Password is extremely strong" : "A senha é extremamente forte",
+    "Unknown password strength" : "Força da senha é desconhecida",
+    "Your data directory and files are probably accessible from the internet because the <code>.htaccess</code> file does not work." : "Seu diretório de dados e arquivos provavelmente podem ser acessados pela Internet porque o arquivo <code>.htaccess</code> não funciona.",
+    "For information how to properly configure your server, please {linkStart}see the documentation{linkEnd}" : "Para obter informações sobre como configurar corretamente seu servidor, {linkStart}consulte a documentação{linkEnd}",
+    "Autoconfig file detected" : "Arquivo de configuração automática detectado",
+    "The setup form below is pre-filled with the values from the config file." : "O formulário de configuração abaixo é preenchido previamente com os valores do arquivo de configuração.",
     "Security warning" : "Alerta de segurança",
+    "Create administration account" : "Criar conta de administração",
+    "Administration account name" : "Nome da conta de administração",
+    "Administration account password" : "Senha da conta de administração",
     "Storage & database" : "Armazenamento & banco de dados",
     "Data folder" : "Pasta de dados",
+    "Database configuration" : "Configuração do banco de dados",
+    "Only {firstAndOnlyDatabase} is available." : "Somente {firstAndOnlyDatabase} está disponível.",
     "Install and activate additional PHP modules to choose other database types." : "Instale e ative os módulos adicionais do PHP para escolher outros tipos de banco de dados.",
     "For more details check out the documentation." : "Para mais informações consulte a documentação.",
     "Performance warning" : "Alerta de performance",
@@ -220,15 +236,16 @@ OC.L10N.register(
     "Database password" : "Senha do banco de dados",
     "Database name" : "Nome do banco de dados",
     "Database tablespace" : "Espaço de tabela do banco de dados",
-    "Please specify the port number along with the host name (e.g., localhost:5432)." : "Por favor especifique o nome do host e porta (ex., localhost:5432).",
+    "Please specify the port number along with the host name (e.g., localhost:5432)." : "Por favor, especifique o nome do host e a porta (p. ex., localhost:5432).",
     "Database host" : "Host do banco de dados",
-    "Installing …" : "Instalando ...",
+    "localhost" : "localhost",
+    "Installing …" : "Instalando …",
     "Install" : "Instalar",
     "Need help?" : "Precisa de ajuda?",
     "See the documentation" : "Veja a documentação",
     "{name} version {version} and above" : "{name} versão {version} e superior",
     "This browser is not supported" : "Este navegador não é compatível",
-    "Your browser is not supported. Please upgrade to a newer version or a supported one." : "Seu navegador não é suportado. Atualize para uma versão mais recente ou compatível.",
+    "Your browser is not supported. Please upgrade to a newer version or a supported one." : "Seu navegador não é compatível. Por favor, atualize para uma versão mais recente ou compatível.",
     "Continue with this unsupported browser" : "Continuar com este navegador não compatível",
     "Supported versions" : "Versões compatíveis",
     "Search {types} …" : "Pesquisar {types}…",
@@ -268,7 +285,7 @@ OC.L10N.register(
     "View changelog" : "Ver alterações",
     "No action available" : "Nenhuma ação disponível",
     "Error fetching contact actions" : "Erro ao obter as ações de contato",
-    "Close \"{dialogTitle}\" dialog" : "Close \"{dialogTitle}\" dialog",
+    "Close \"{dialogTitle}\" dialog" : "Fechar a caixa de diálogo \"{dialogTitle}\"",
     "Email length is at max (255)" : "O comprimento do e-mail é no máximo (255)",
     "Non-existing tag #{tag}" : "Etiqueta inexistente #{tag}",
     "Restricted" : "Restrita",
@@ -277,10 +294,10 @@ OC.L10N.register(
     "Rename" : "Renomear",
     "Collaborative tags" : "Etiquetas colaborativas",
     "No tags found" : "Nenhuma etiqueta encontrada",
-    "Clipboard not available, please copy manually" : "Área de transferência não disponível, copie manualmente",
+    "Clipboard not available, please copy manually" : "A área de transferência não está disponível, por favor, copie manualmente",
     "Personal" : "Pessoal",
     "Accounts" : "Contas",
-    "Admin" : "Administrar",
+    "Admin" : "Administração",
     "Help" : "Ajuda",
     "Access forbidden" : "Acesso proibido",
     "Page not found" : "Página não encontrada",
@@ -306,14 +323,14 @@ OC.L10N.register(
     "It looks like you are trying to reinstall your Nextcloud. However the file CAN_INSTALL is missing from your config directory. Please create the file CAN_INSTALL in your config folder to continue." : "Parece que você está tentando reinstalar o Nextcloud. No entanto, o arquivo CAN_INSTALL está faltando no diretório de configuração. Crie o arquivo CAN_INSTALL na pasta de configuração para continuar.",
     "Could not remove CAN_INSTALL from the config folder. Please remove this file manually." : "Não foi possível remover CAN_INSTALL da pasta de configuração. Remova este arquivo manualmente.",
     "This application requires JavaScript for correct operation. Please {linkstart}enable JavaScript{linkend} and reload the page." : "Este aplicativo requer JavaScript para sua correta operação. Por favor {linkstart}habilite o JavaScript{linkend} e recarregue a página.",
-    "Skip to main content" : "Ir ao conteúdo principal",
-    "Skip to navigation of app" : "Ir à navegação do aplicativo",
-    "Go to %s" : "Ir para %s",
+    "Skip to main content" : "Pular para o conteúdo principal",
+    "Skip to navigation of app" : "Pular para a navegação do aplicativo",
+    "Go to %s" : "Vá para %s",
     "Get your own free account" : "Obtenha uma conta grátis",
     "Connect to your account" : "Conectar à sua conta",
     "Please log in before granting %1$s access to your %2$s account." : "Logue-se antes de conceder acesso %1$s à sua conta %2$s.",
     "If you are not trying to set up a new device or app, someone is trying to trick you into granting them access to your data. In this case do not proceed and instead contact your system administrator." : "Se você não está tentando configurar um novo dispositivo ou aplicativo, alguém está tentando induzi-lo a conceder acesso a seus dados. Nesse caso, não prossiga e entre em contato com o administrador do sistema.",
-    "App password" : "Senha do aplicativo",
+    "App password" : "Senha de aplicativo",
     "Grant access" : "Conceder acesso",
     "Alternative log in using app password" : "Login alternativo usando senha do aplicativo",
     "Account access" : "Acesso à conta",
@@ -362,14 +379,14 @@ OC.L10N.register(
     "This page will refresh itself when the instance is available again." : "Esta página será atualizada quando o Nextcloud estiver disponível novamente.",
     "Contact your system administrator if this message persists or appeared unexpectedly." : "Entre em contato com o administrador do sistema se esta mensagem persistir ou aparecer inesperadamente.",
     "Currently open" : "Atualmente aberto",
-    "Login with username or email" : "Login com nome de usuário ou e-mail",
-    "Login with username" : "Login com nome de usuário",
+    "Login with username or email" : "Fazer login com o nome de usuário ou e-mail",
+    "Login with username" : "Fazer login com o nome de usuário",
     "Chatting, video calls, screensharing, online meetings and web conferencing – in your browser and with mobile apps." : "Bate-papo, vídeo chamadas, compartilhamento de tela, reuniões online e conferência na web - no seu navegador e com aplicativos móveis.",
     "You have not added any info yet" : "Você ainda não adicionou nenhuma informação",
     "{user} has not added any info yet" : "{user} ainda não adicionou nenhuma informação",
-    "Error opening the user status modal, try hard refreshing the page" : "Erro ao abrir o modal de status do usuário, tente atualizar a página",
+    "Error opening the user status modal, try hard refreshing the page" : "Erro ao abrir o modal de status do usuário, tente forçar uma atualização da página sem cache",
     "Edit Profile" : "Editar Perfil ",
-    "The headline and about sections will show up here" : "O título e as seções sobre serão exibidos aqui",
+    "The headline and about sections will show up here" : "As seções de título e sobre serão exibidas aqui",
     "Error loading message template: {error}" : "Erro carregando o modelo de mensagem: {error}",
     "Very weak password" : "Senha muito fraca",
     "Weak password" : "Senha fraca",
@@ -381,8 +398,8 @@ OC.L10N.register(
     "Your data directory and files are probably accessible from the internet because the .htaccess file does not work." : "Seu diretório de dados e arquivos provavelmente estão acessíveis pela internet, porque o .htaccess não funciona.",
     "For information how to properly configure your server, please see the <a href=\"%s\" target=\"_blank\" rel=\"noreferrer noopener\">documentation</a>." : "Para mais informações de como configurar apropriadamente seu servidor, consulte nossa <a href=\"%s\" target=\"_blank\" rel=\"noreferrer noopener\">documentação</a>.",
     "<strong>Create an admin account</strong>" : "<strong>Criar uma conta de administrador</strong>",
-    "New admin account name" : "Nome de conta do novo Administrador",
-    "New admin password" : "Senha do novo Administrador",
+    "New admin account name" : "Nome de conta do novo administrador",
+    "New admin password" : "Senha do novo administrador",
     "Show password" : "Mostrar senha",
     "Toggle password visibility" : "Alternar visibilidade da senha",
     "Configure the database" : "Configurar o banco de dados",
