@@ -121,14 +121,14 @@ OC.L10N.register(
     "Please try again or contact your administrator." : "Por favor, tente novamente ou contacte o seu administrador.",
     "Password" : "Palavra-passe",
     "Your account is not setup for passwordless login." : "A sua conta não está configurada para autenticação sem palavra-passe.",
-    "Browser not supported" : "Navegador não suportado",
-    "Passwordless authentication is not supported in your browser." : "O seu navegador não suporta autenticação sem palavra-passe.",
     "Your connection is not secure" : "A sua ligação não é segura",
     "Passwordless authentication is only available over a secure connection." : "A autenticação sem palavra-passe só está disponível através de uma ligação segura.",
+    "Browser not supported" : "Navegador não suportado",
+    "Passwordless authentication is not supported in your browser." : "O seu navegador não suporta autenticação sem palavra-passe.",
     "Reset password" : "Repor palavra-passe",
+    "Back to login" : "Voltar à autenticação",
     "Couldn't send reset email. Please contact your administrator." : "Não foi possível enviar a mensagem de reposição. Por favor, contacte o seu administrador.",
     "Password cannot be changed. Please contact your administrator." : "A palavra-passe não pode ser alterada. Por favor, contacte o seu administrador.",
-    "Back to login" : "Voltar à autenticação",
     "New password" : "Nova palavra-passe",
     "Your files are encrypted. There will be no way to get your data back after your password is reset. If you are not sure what to do, please contact your administrator before you continue. Do you really want to continue?" : "Os seus ficheiros estão cifrados. Não será possível aceder aos seus dados após a palavra-passe ser alterada. Se não tiver a certeza do que fazer, contacte o administrador do sistema antes de continuar. Tem a certeza que quer continuar?",
     "I know what I'm doing" : "Eu sei o que eu estou a fazer",
@@ -159,12 +159,31 @@ OC.L10N.register(
     "Forgot password?" : "Senha esquecida?",
     "Back" : "Anterior",
     "More actions" : "Mais ações",
+    "Security warning" : "Aviso de segurança",
+    "Storage & database" : "Armazenamento e base de dados",
+    "Data folder" : "Pasta de dados",
+    "Install and activate additional PHP modules to choose other database types." : "Instale e ative os módulos PHP adicionais para escolher outros tipos de base de dados.",
+    "For more details check out the documentation." : "Para mais detalhes consulte a documentação.",
+    "Performance warning" : "Aviso de desempenho",
+    "You chose SQLite as database." : "Escolheu SQLite como base de dados",
+    "If you use clients for file syncing, the use of SQLite is highly discouraged." : "Se utiliza clientes para a sincronização de ficheiros, a utilização de SQLite é altamente desencorajada.",
+    "Database user" : "Utilizador da base de dados",
+    "Database password" : "Palavra-passe da base de dados",
+    "Database name" : "Nome da base de dados",
+    "Database tablespace" : "Tablespace da base de dados",
+    "Please specify the port number along with the host name (e.g., localhost:5432)." : "Por favor, especifique o número da porta com o nome do anfitrião (por exemplo, localhost:5432).",
+    "Database host" : "Anfitrião da base de dados",
+    "Installing …" : "A instalar...",
+    "Install" : "Instalar",
+    "Need help?" : "Precisa de ajuda?",
+    "See the documentation" : "Consulte a documentação",
     "{name} version {version} and above" : "{name} versão {version} e superior",
     "This browser is not supported" : "Este navegador não é suportado",
     "Your browser is not supported. Please upgrade to a newer version or a supported one." : "O seu navegador não é suportado. Por favor, atualize para uma versão mais recente ou para um suportado.",
     "Continue with this unsupported browser" : "Continuar com este navegador não suportado",
     "Supported versions" : "Versões suportadas",
     "Search {types} …" : "Pesquisar {types}...",
+    "Choose {file}" : "Escolher {file}",
     "Choose" : "Escolher",
     "Copy" : "Copiar",
     "Move" : "Mover",
@@ -196,11 +215,6 @@ OC.L10N.register(
     "Type to search for existing projects" : "Digite para procurar por projetos existentes",
     "New in" : "Novo em",
     "View changelog" : "Ver registo de alterações",
-    "Very weak password" : "Palavra-passe muito fraca",
-    "Weak password" : "Palavra-passe fraca",
-    "So-so password" : "Palavra-passe aceitável",
-    "Good password" : "Palavra-passe boa",
-    "Strong password" : "Palavra-passe forte",
     "No action available" : "Nenhuma ação disponível",
     "Error fetching contact actions" : "Erro ao obter ações dos contactos",
     "Non-existing tag #{tag}" : "Etiqueta não existente #{tag}",
@@ -231,29 +245,6 @@ OC.L10N.register(
     "File: %s" : "Ficheiro: %s",
     "Line: %s" : "Linha: %s",
     "Trace" : "Rastreio",
-    "Security warning" : "Aviso de segurança",
-    "Your data directory and files are probably accessible from the internet because the .htaccess file does not work." : "A pasta de dados e os respetivos ficheiros estão provavelmente acessíveis a partir da internet pois o ficheiro .htaccess não funciona.",
-    "For information how to properly configure your server, please see the <a href=\"%s\" target=\"_blank\" rel=\"noreferrer noopener\">documentation</a>." : "Para obter informações de como configurar corretamente o servidor, veja em: <a href=\"%s\" target=\"_blank\" rel=\"noreferrer\">documentação</a>.",
-    "Show password" : "Mostrar senha",
-    "Toggle password visibility" : "Altere a visibilidade da palavra-passe",
-    "Storage & database" : "Armazenamento e base de dados",
-    "Data folder" : "Pasta de dados",
-    "Configure the database" : "Configure a base de dados",
-    "Only %s is available." : "Só está disponível %s.",
-    "Install and activate additional PHP modules to choose other database types." : "Instale e ative os módulos PHP adicionais para escolher outros tipos de base de dados.",
-    "For more details check out the documentation." : "Para mais detalhes consulte a documentação.",
-    "Database password" : "Palavra-passe da base de dados",
-    "Database name" : "Nome da base de dados",
-    "Database tablespace" : "Tablespace da base de dados",
-    "Database host" : "Anfitrião da base de dados",
-    "Please specify the port number along with the host name (e.g., localhost:5432)." : "Por favor, especifique o número da porta com o nome do anfitrião (por exemplo, localhost:5432).",
-    "Performance warning" : "Aviso de desempenho",
-    "You chose SQLite as database." : "Escolheu SQLite como base de dados",
-    "If you use clients for file syncing, the use of SQLite is highly discouraged." : "Se utiliza clientes para a sincronização de ficheiros, a utilização de SQLite é altamente desencorajada.",
-    "Install" : "Instalar",
-    "Installing …" : "A instalar...",
-    "Need help?" : "Precisa de ajuda?",
-    "See the documentation" : "Consulte a documentação",
     "This application requires JavaScript for correct operation. Please {linkstart}enable JavaScript{linkend} and reload the page." : "Esta aplicação requer JavaScript para funcionar corretamente. Por favor, {linkstart}ative o JavaScript{linkend} e recarregue a página.",
     "Skip to main content" : "Saltar para conteúdo principal",
     "Skip to navigation of app" : "Saltar para navegação da aplicação",
@@ -299,7 +290,18 @@ OC.L10N.register(
     "You have not added any info yet" : "Ainda não adicionou qualquer informação ",
     "Edit Profile" : "Editar perfil",
     "Error loading message template: {error}" : "Ocorreu um erro ao carregar o modelo: {error}",
+    "Very weak password" : "Palavra-passe muito fraca",
+    "Weak password" : "Palavra-passe fraca",
+    "So-so password" : "Palavra-passe aceitável",
+    "Good password" : "Palavra-passe boa",
+    "Strong password" : "Palavra-passe forte",
     "Profile not found" : "Perfil não encontrado",
-    "The profile does not exist." : "O perfil não existe."
+    "The profile does not exist." : "O perfil não existe.",
+    "Your data directory and files are probably accessible from the internet because the .htaccess file does not work." : "A pasta de dados e os respetivos ficheiros estão provavelmente acessíveis a partir da internet pois o ficheiro .htaccess não funciona.",
+    "For information how to properly configure your server, please see the <a href=\"%s\" target=\"_blank\" rel=\"noreferrer noopener\">documentation</a>." : "Para obter informações de como configurar corretamente o servidor, veja em: <a href=\"%s\" target=\"_blank\" rel=\"noreferrer\">documentação</a>.",
+    "Show password" : "Mostrar senha",
+    "Toggle password visibility" : "Altere a visibilidade da palavra-passe",
+    "Configure the database" : "Configure a base de dados",
+    "Only %s is available." : "Só está disponível %s."
 },
 "nplurals=3; plural=(n == 0 || n == 1) ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");
