@@ -146,6 +146,8 @@ OC.L10N.register(
     "Account name" : "Kontonamn",
     "Server side authentication failed!" : "Servern misslyckades med autentisering!",
     "Please contact your administrator." : "Kontakta din administratör.",
+    "Session error" : "Sessionsfel",
+    "It appears your session token has expired, please refresh the page and try again." : "Det verkar som att din sessionstoken har gått ut, uppdatera sidan och försök igen.",
     "An internal error occurred." : "Ett internt fel uppstod.",
     "Please try again or contact your administrator." : "Försök igen eller kontakta din administratör.",
     "Password" : "Lösenord",
@@ -213,6 +215,9 @@ OC.L10N.register(
     "Password is extremely strong" : "Lösenordet är extremt starkt",
     "Unknown password strength" : "Okänd lösenordsstyrka",
     "Security warning" : "Säkerhetsvarning",
+    "Create administration account" : "Skapa administratörskonto",
+    "Administration account name" : "Namn på administratörskonto",
+    "Administration account password" : "Lösenord för administratörskonto",
     "Storage & database" : "Lagring & databas",
     "Data folder" : "Datamapp",
     "Install and activate additional PHP modules to choose other database types." : "Installera och aktivera ytterligare moduler för att kunna välja andra databas-typer.",
