@@ -108,7 +108,7 @@ OC.L10N.register(
     "Failed to add the public link to your Nextcloud" : "Не вдалося додати загальнодоступне посилання до вашого Nextcloud",
     "Federated user" : "Обʼєднаний користувач",
     "user@your-nextcloud.org" : "користувач@ваш-nextcloud.org",
-    "Create share" : "Створити спільний ресурс",
+    "Create share" : "Передати у публічний доступ",
     "Direct link copied to clipboard" : "Посилання прямого доступу скопійовано в буфер обміну",
     "Please copy the link manually:" : "Будь ласка, скопіюйте посилання вручну:",
     "Custom date range" : "Власний вибір проміжку",
@@ -146,8 +146,8 @@ OC.L10N.register(
     "Account name" : "Назва облікового запису",
     "Server side authentication failed!" : "Невдала авторизація на стороні сервера!",
     "Please contact your administrator." : "Будь ласка, зверніться до вашого Адміністратора.",
-    "Temporary error" : "Тимчасова помилка",
-    "Please try again." : "Спробуйте ще раз.",
+    "Session error" : "Помилка сеансу",
+    "It appears your session token has expired, please refresh the page and try again." : "Здається, термін дії вашого токену сеансу закінчився, будь ласка, оновіть сторінку і спробуйте ще раз.",
     "An internal error occurred." : "Виникла внутрішня помилка.",
     "Please try again or contact your administrator." : "Будь ласка, спробуйте ще раз або зверніться до адміністратора.",
     "Password" : "Пароль",
@@ -207,9 +207,25 @@ OC.L10N.register(
     "Login form is disabled." : "Форма входу вимкнена.",
     "The Nextcloud login form is disabled. Use another login option if available or contact your administration." : "Форму авторизації у хмарі Nextcloud вимкнено. Скористайтеся іншим способом входу, якщо є така можливість, або сконтактуйте з адміністратором.",
     "More actions" : "Більше дій",
+    "Password is too weak" : "Занадто простий пароль ",
+    "Password is weak" : "Простий пароль",
+    "Password is average" : "Пароль середньої складності",
+    "Password is strong" : "Надійний пароль ",
+    "Password is very strong" : "Пароль дуже надійний",
+    "Password is extremely strong" : "Надзвичайно надійний пароль",
+    "Unknown password strength" : "Невідома ефективність паролю",
+    "Your data directory and files are probably accessible from the internet because the <code>.htaccess</code> file does not work." : "Ваш каталог з даними та файли скоріш за все публічно доступні в Інтернеті, оскільки файл <code>.htaccess</code> не налаштовано відповідним чином. ",
+    "For information how to properly configure your server, please {linkStart}see the documentation{linkEnd}" : "Ознайомтеся з{linkStart}документацію{linkEnd} з налаштування сервера.",
+    "Autoconfig file detected" : "Виявлено файл автоконфігурації",
+    "The setup form below is pre-filled with the values from the config file." : "Форму для налаштування попередньо заповнено значеннями з файлу конфігурації.",
     "Security warning" : "Попередження безпеки",
+    "Create administration account" : "Створіть обліковий запис адміністратора",
+    "Administration account name" : "Ім'я облікового запису адміністратора",
+    "Administration account password" : "Пароль облікового запису адміністратора",
     "Storage & database" : "Сховище і база даних",
     "Data folder" : "Каталог з даними",
+    "Database configuration" : "Конфігурація бази даних",
+    "Only {firstAndOnlyDatabase} is available." : "Лише {firstAndOnlyDatabase} доступна для вибору.",
     "Install and activate additional PHP modules to choose other database types." : "Встановіть та активуйте додаткові модулі PHP, щоб вибрати інший тип БД.",
     "For more details check out the documentation." : "За подробицями зверніться до документації.",
     "Performance warning" : "Попередження продуктивності",
@@ -222,6 +238,7 @@ OC.L10N.register(
     "Database tablespace" : "Таблиця бази даних",
     "Please specify the port number along with the host name (e.g., localhost:5432)." : "Будь ласка, вкажіть номер порту поряд з ім'ям вузла (напр., localhost:5432).",
     "Database host" : "Вузол бази даних",
+    "localhost" : "localhost",
     "Installing …" : "Встановлення…",
     "Install" : "Встановити",
     "Need help?" : "Потрібна допомога?",
