@@ -201,6 +201,7 @@ OC.L10N.register(
     "Path is already shared with this group" : "Umístění už je této skupině nasdíleno",
     "Link sharing is not allowed" : "Sdílení odkazů není povoleno",
     "Public upload is not allowed" : "Veřejné nahrávání není povoleno",
+    "You cannot share a folder that contains other shares" : "Není možné nasdílet složku, která obsahuje další sdílení",
     "Sharing is disabled" : "Sdílení je vypnuto",
     "Sharing is disabled for you" : "Máte zakázáno sdílet",
     "Cannot share with the share owner" : "Nelze sdílet zpět vlastníkovi sdílení",
@@ -328,7 +329,6 @@ OC.L10N.register(
     "The audio to transcribe" : "Nahrávka k přepisu",
     "Transcription" : "Přepis do textu",
     "The transcribed text" : "Přepsaný text",
-    "ContextAgent" : "ContextAgent",
     "Chat with an agent" : "Chatovat s agentem",
     "Chat message" : "Zpráva v chatu",
     "A chat message to send to the agent." : "Zpráva chatu, kterou poslat agentovi.",
@@ -456,7 +456,6 @@ OC.L10N.register(
     "Click the button below to open it." : "Pro otevření klikněte na tlačítko níže.",
     "File is currently busy, please try again later" : "Soubor je nyní používán, zkuste to později",
     "Cannot download file" : "Soubor se nedaří stáhnout",
-    "Ensure there is a file called \".ocdata\" in the root of the data directory." : "Ověřte, že v kořeni datového adresáře je soubor s názvem „.ocdata“.",
-    "Path contains files shared with you" : "Popis umístění obsahuje soubory, které vám byly nasdíleny"
+    "Ensure there is a file called \".ocdata\" in the root of the data directory." : "Ověřte, že v kořeni datového adresáře je soubor s názvem „.ocdata“."
 },
 "nplurals=4; plural=(n == 1 && n % 1 == 0) ? 0 : (n >= 2 && n <= 4 && n % 1 == 0) ? 1: (n % 1 != 0 ) ? 2 : 3;");
