@@ -38,6 +38,7 @@ OC.L10N.register(
     "Server version %s or higher is required." : "Du skal have server version %s eller nyere.",
     "Server version %s or lower is required." : "Du skal have server version %s eller ældre.",
     "Logged in account must be an admin, a sub admin or gotten special right to access this setting" : "En konto, der er logget på, skal være administrator, underadministrator eller have en særlig rettighed for at få adgang til denne indstilling",
+    "Your current IP address doesn't allow you to perform admin actions" : "Din nuværende IP-adresse tillader dig ikke at udføre administratorhandlinger",
     "Logged in account must be an admin or sub admin" : "Kontoen, der er logget på, skal være en administrator eller underadministrator",
     "Logged in account must be an admin" : "Kontoen, der er logget på, skal være en admin",
     "Wiping of device %s has started" : "Komplet sletning af enhed %s er påbegyndt",
@@ -155,6 +156,7 @@ OC.L10N.register(
     "Oracle connection could not be established" : "Oracle forbindelsen kunne ikke etableres",
     "Oracle Login and/or password not valid" : "Oracle login og / eller adgangskode ikke gyldig",
     "PostgreSQL Login and/or password not valid" : "PostgreSQL login og / eller adgangskode ikke gyldig",
+    "Mac OS X is not supported and %s will not work properly on this platform. Use it at your own risk!" : "Mac OS X understøttes ikke, og %s vil ikke fungere korrekt på denne platform. Brug det på eget ansvar!",
     "For the best results, please consider using a GNU/Linux server instead." : "For de bedste resultater, overvej venligst at bruge en GNU/Linux-server i stedet.",
     "It seems that this %s instance is running on a 32-bit PHP environment and the open_basedir has been configured in php.ini. This will lead to problems with files over 4 GB and is highly discouraged." : "Det ser ud til, at denne %s-instans kører på et 32-bit PHP-miljø, samt at open_basedir er blevet konfigureret gennem php.ini. Dette vil føre til problemer med filer som er større end 4GB, og frarådes kraftigt.",
     "Please remove the open_basedir setting within your php.ini or switch to 64-bit PHP." : "Fjern venligst indstillingen for open_basedir inde i din php.ini eller skift til 64-bit PHP.",
@@ -199,7 +201,7 @@ OC.L10N.register(
     "Path is already shared with this group" : "Sti deles allerede med denne gruppe",
     "Link sharing is not allowed" : "Link deling er ikke tilladt",
     "Public upload is not allowed" : "Offentlig upload er ikke tilladt",
-    "Path contains files shared with you" : "Sti indeholder filer delt med dig",
+    "You cannot share a folder that contains other shares" : "Du kan ikke dele en mappe, der indeholder andre delinger",
     "Sharing is disabled" : "Deling er deaktiveret",
     "Sharing is disabled for you" : "Deling er deaktiveret for dig",
     "Cannot share with the share owner" : "Kan ikke dele med delingsejeren",
@@ -327,7 +329,6 @@ OC.L10N.register(
     "The audio to transcribe" : "Lyden der skal transskriberes",
     "Transcription" : "Transskription",
     "The transcribed text" : "Den transskriberede tekst",
-    "ContextAgent" : "ContextAgent",
     "Chat with an agent" : "Chat med en agent",
     "Chat message" : "Chatbeskeder",
     "A chat message to send to the agent." : "En chatbesked til agenten.",
