@@ -37,9 +37,9 @@ OC.L10N.register(
     "The following platforms are supported: %s" : "Die folgenden Plattformen werden unterstützt: %s",
     "Server version %s or higher is required." : "Server Version %s oder höher wird benötigt.",
     "Server version %s or lower is required." : "Server Version %s oder niedriger wird benötigt.",
-    "Logged in account must be an admin, a sub admin or gotten special right to access this setting" : "Das angemeldete Konto muss ein Administrator, ein Teil-Administrator sein oder ein Sonderrecht haben, um auf diese Einstellung zuzugreifen",
+    "Logged in account must be an admin, a sub admin or gotten special right to access this setting" : "Das angemeldete Konto muss ein Administrator, ein Unteradministrator sein oder ein Sonderrecht haben, um auf diese Einstellung zuzugreifen",
     "Your current IP address doesn't allow you to perform admin actions" : "Unter deiner aktuellen IP-Adresse sind keine Administrationsaktionen erlaubt",
-    "Logged in account must be an admin or sub admin" : "Das angemeldete Konto muss ein (Sub-)Administrator sein",
+    "Logged in account must be an admin or sub admin" : "Das angemeldete Konto muss ein (Unter-)Administrator sein",
     "Logged in account must be an admin" : "Das angemeldete Konto muss ein Administrator sein",
     "Wiping of device %s has started" : "Löschen von Gerät %s wurde gestartet",
     "Wiping of device »%s« has started" : "Löschen von Gerät »%s« wurde gestartet",
@@ -201,7 +201,7 @@ OC.L10N.register(
     "Path is already shared with this group" : "Der Pfad ist bereits mit dieser Gruppe geteilt",
     "Link sharing is not allowed" : "Freigabe via Link ist nicht erlaubt",
     "Public upload is not allowed" : "Öffentliches Hochladen ist nicht erlaubt",
-    "Path contains files shared with you" : "Der Pfad enthält für dich freigegebene Dateien",
+    "You cannot share a folder that contains other shares" : "Ein Ordner, der andere Freigaben enthält, kann nicht geteilt werden",
     "Sharing is disabled" : "Teilen ist deaktiviert",
     "Sharing is disabled for you" : "Teilen ist für dich deaktiviert",
     "Cannot share with the share owner" : "Teilen mit dem Freigabeeigentümer nicht möglich",
@@ -329,7 +329,6 @@ OC.L10N.register(
     "The audio to transcribe" : "Die Audio-Datei zum Transkribieren",
     "Transcription" : "Transkription",
     "The transcribed text" : "Der transkribierte Text",
-    "ContextAgent" : "ContextAgent",
     "Chat with an agent" : "Mit einem Agenten chatten",
     "Chat message" : "Chatnachricht",
     "A chat message to send to the agent." : "Eine Chatnachricht, die an den Agenten gesendet wird.",
