@@ -201,6 +201,7 @@ OC.L10N.register(
     "Path is already shared with this group" : "La ruta ya se encuentra compartida con este grupo",
     "Link sharing is not allowed" : "La compartición de enlaces no está permitida",
     "Public upload is not allowed" : "No está permitida la subida de archivos pública",
+    "You cannot share a folder that contains other shares" : "No puede compartir una carpeta que contiene otros recursos compartidos",
     "Sharing is disabled" : "Compartir está deshabilitado",
     "Sharing is disabled for you" : "Compartir está deshabilitado para Ud.",
     "Cannot share with the share owner" : "No se puede compartir con el propietario del recurso compartido",
@@ -328,7 +329,6 @@ OC.L10N.register(
     "The audio to transcribe" : "El audio a transcribir",
     "Transcription" : "Transcripción",
     "The transcribed text" : "El texto transcrito",
-    "ContextAgent" : "ContextAgent",
     "Chat with an agent" : "Chatea con un agente",
     "Chat message" : "Mensaje de chat",
     "A chat message to send to the agent." : "Un mensaje de chat a escribir al agente",
@@ -456,7 +456,6 @@ OC.L10N.register(
     "Click the button below to open it." : "Haz clic en el botón de abajo para abrirlo.",
     "File is currently busy, please try again later" : "El archivo se encuentra actualmente ocupado, por favor inténtelo de nuevo más tarde",
     "Cannot download file" : "No se puede descargar el archivo",
-    "Ensure there is a file called \".ocdata\" in the root of the data directory." : "Asegúrate de que existe un archivo llamado \".ocdata\" en la raíz del directorio de datos.",
-    "Path contains files shared with you" : "La ruta contiene archivos compartidos con Ud."
+    "Ensure there is a file called \".ocdata\" in the root of the data directory." : "Asegúrate de que existe un archivo llamado \".ocdata\" en la raíz del directorio de datos."
 },
 "nplurals=3; plural=n == 1 ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");
