@@ -4,7 +4,6 @@ OC.L10N.register(
     "Cannot write into \"config\" directory!" : "Pisanje u direktorij „config” nije moguće!",
     "But, if you prefer to keep config.php file read only, set the option \"config_is_read_only\" to true in it." : "Međutim, ako želite da datoteka config.php ostane samo za čitanje, postavite opciju „config_is_read_only” na „true”.",
     "See %s" : "Pogledajte %s",
-    "The files of the app %1$s were not replaced correctly. Make sure it is a version compatible with the server." : "Datoteke aplikacije %1$s nisu ispravno zamijenjene. Provjerite je li inačica kompatibilna s poslužiteljem.",
     "Sample configuration detected" : "Pronađena ogledna konfiguracija",
     "It has been detected that the sample configuration has been copied. This can break your installation and is unsupported. Please read the documentation before performing changes on config.php" : "Otkriveno je kopiranje ogledne konfiguracije. To može dovesti do poteškoća u radu vaše instalacije i nije podržano. Pročitajte dokumentaciju prije nego što izvršite promjene u config.php",
     "%s email verification" : "Provjeru e-pošte %s",
@@ -17,7 +16,6 @@ OC.L10N.register(
     "%1$s, %2$s and %3$s" : "%1$s, %2$s i %3$s",
     "%1$s, %2$s, %3$s and %4$s" : "%1$s, %2$s, %3$s i %4$s",
     "%1$s, %2$s, %3$s, %4$s and %5$s" : "%1$s, %2$s, %3$s, %4$s i %5$s",
-    "Education Edition" : "Obrazovno izdanje",
     "Enterprise bundle" : "Enterprise paket",
     "Groupware bundle" : "Paket grupnog softvera",
     "Hub bundle" : "Paket alata",
@@ -34,9 +32,6 @@ OC.L10N.register(
     "The following platforms are supported: %s" : "Podržane su sljedeće platforme: %s",
     "Server version %s or higher is required." : "Inačica poslužitelja treba biti %s ili viša.",
     "Server version %s or lower is required." : "Potrebna je inačica poslužitelja %s ili niža.",
-    "Logged in user must be an admin, a sub admin or gotten special right to access this setting" : "Prijavljeni korisnik mora biti administrator, podadministrator ili imati posebna prava za pristupanje ovoj postavci",
-    "Logged in user must be an admin or sub admin" : "Prijavljeni korisnik mora biti administrator ili podadministrator",
-    "Logged in user must be an admin" : "Korisnik koji je prijavljen mora biti administrator",
     "Wiping of device %s has started" : "Počelo je brisanje sadržaja s uređaja %s",
     "Wiping of device »%s« has started" : "Počelo je brisanje sadržaja s uređaja »%s«",
     "»%s« started remote wipe" : "»%s« je počeo daljinsko brisanje",
@@ -53,7 +48,9 @@ OC.L10N.register(
     "Unknown filetype" : "Vrsta datoteke nepoznata",
     "Invalid image" : "Slika neispravna",
     "Avatar image is not square" : "Slika avatara nije kvadratna",
+    "Files" : "Datoteke",
     "View profile" : "Prikaži profil",
+    "_%nh_::_%nh_" : ["%nh","%nh","%nh"],
     "today" : "danas",
     "tomorrow" : "sutra",
     "yesterday" : "jučer",
@@ -75,24 +72,21 @@ OC.L10N.register(
     "seconds ago" : "prije nekoliko sekundi",
     "Empty file" : "Prazna datoteka",
     "Module with ID: %s does not exist. Please enable it in your apps settings or contact your administrator." : "Modul s ID-om: %s ne postoji. Omogućite ga u postavkama svojih aplikacija ili se obratite administratoru.",
+    "Dot files are not allowed" : "Datoteke s točkama nisu dopuštene",
     "File already exists" : "Datoteka već postoji",
     "Invalid path" : "Nevažeći put",
     "Failed to create file from template" : "Stvaranje datoteke iz predloška nije uspjelo",
     "Templates" : "Predlošci",
-    "File name is a reserved word" : "Naziv datoteke je rezervirana riječ",
-    "File name contains at least one invalid character" : "Naziv datoteke sadrži barem jedan nevažeći znak",
-    "File name is too long" : "Naziv datoteke je predugačak",
-    "Dot files are not allowed" : "Datoteke s točkama nisu dopuštene",
+    "Filename contains at least one invalid character" : "Naziv datoteke sadrži barem jedan nevažeći znak",
     "Empty filename is not allowed" : "Datoteke bez naziva nisu dopuštene",
     "App \"%s\" cannot be installed because appinfo file cannot be read." : "Aplikaciju „%s” nije moguće instalirati jer se ne može pročitati datoteka s podacima o aplikaciji.",
     "App \"%s\" cannot be installed because it is not compatible with this version of the server." : "Aplikaciju „%s” nije moguće instalirati jer nije kompatibilna s ovom inačicom poslužitelja.",
     "__language_name__" : "Hrvatski",
     "This is an automatically sent email, please do not reply." : "Ovo je automatski poslana poruka e-pošte, nemojte odgovarati.",
-    "Help" : "Pomoć",
     "Apps" : "Aplikacije",
     "Settings" : "Postavke",
     "Log out" : "Odjava",
-    "Users" : "Korisnici",
+    "Accounts" : "Korisnićki računi",
     "Email" : "E-pošta",
     "Mail %s" : "Pošta %s",
     "Phone" : "Telefon",
@@ -104,32 +98,22 @@ OC.L10N.register(
     "Address" : "Adresa",
     "Profile picture" : "Profilna slika",
     "About" : "Informacije",
-    "Full name" : "Puno ime",
     "Headline" : "Naslov",
     "Organisation" : "Organizacija",
     "Role" : "Uloga",
-    "Unknown user" : "Nepoznat korisnik",
     "Additional settings" : "Dodatne postavke",
-    "MySQL username and/or password not valid" : "Neispravno korisničko ime i/ili zaporka baze podataka MySQL",
     "You need to enter details of an existing account." : "Trebate unijeti informacije o postojećem računu.",
     "Oracle connection could not be established" : "Nije moguće uspostaviti vezu s bazom podataka Oracle",
-    "Oracle username and/or password not valid" : "Neispravno korisničko ime i/ili zaporka baze podataka Oracle",
-    "PostgreSQL username and/or password not valid" : "Neispravno korisničko ime i/ili zaporka baze podataka PostgreSQL",
-    "Mac OS X is not supported and %s will not work properly on this platform. Use it at your own risk! " : "Mac OS X nije podržan i %s na ovoj platformi neće raditi kako treba. Koristite na vlastiti rizik!",
     "For the best results, please consider using a GNU/Linux server instead." : "Za najbolje rezultate razmotrite mogućnost korištenja poslužitelja GNU/Linux.",
     "It seems that this %s instance is running on a 32-bit PHP environment and the open_basedir has been configured in php.ini. This will lead to problems with files over 4 GB and is highly discouraged." : "Čini se da se ova %s instanca izvodi u 32-bitnom PHP okruženju, a open_basedir je konfiguriran u php.ini. To će dovesti do problema s datotekama većim od 4 GB i stoga se ne preporučuje.",
     "Please remove the open_basedir setting within your php.ini or switch to 64-bit PHP." : "Uklonite postavku open_basedir iz datoteke php.ini ili se prebacite na 64-bitni PHP.",
-    "Set an admin username." : "Postavite korisničko ime administratora.",
     "Set an admin password." : "Postavite zaporku administratora.",
     "Cannot create or write into the data directory %s" : "Nije moguće stvoriti ili pisati u direktorij s podacima %s",
     "Sharing backend %s must implement the interface OCP\\Share_Backend" : "Pozadina za dijeljenje %s mora implementirati sučelje OCP\\Share_Backend",
     "Sharing backend %s not found" : "Pozadina za dijeljenje %s nije pronađena",
     "Sharing backend for %s not found" : "Pozadina za dijeljenje za %s nije pronađena",
-    "%1$s shared »%2$s« with you and wants to add:" : "%1$s dijeli »%2$s« s vama i želi dodati:",
-    "%1$s shared »%2$s« with you and wants to add" : "%1$s dijeli »%2$s« s vama i želi dodati",
-    "»%s« added a note to a file shared with you" : "»%s« je dodao bilješku datoteci koju dijeli s vama",
-    "Open »%s«" : "Otvori »%s«",
     "%1$s via %2$s" : "%1$s putem %2$s",
+    "Unknown share type" : "Nepoznata vrsta dijeljenja",
     "You are not allowed to share %s" : "Nije vam dopušteno dijeliti %s",
     "Cannot increase permissions of %s" : "Nije moguće povećati dopuštenja za %s",
     "Files cannot be shared with delete permissions" : "Datoteke se ne mogu dijeliti s dopuštenjima za brisanje",
@@ -137,10 +121,6 @@ OC.L10N.register(
     "Expiration date is in the past" : "Datum isteka je u prošlosti",
     "_Cannot set expiration date more than %n day in the future_::_Cannot set expiration date more than %n days in the future_" : ["Ne može se postaviti datum isteka više od %n dan u budućnosti","Ne može se postaviti datum isteka više od %n dana u budućnosti","Ne može se postaviti datum isteka više od %n dana u budućnosti"],
     "Sharing is only allowed with group members" : "Dijeljenje je dopušteno samo članovima grupe",
-    "Sharing %s failed, because this item is already shared with user %s" : "Dijeljenje %s nije uspjelo jer je ova stavka već podijeljena s korisnikom %s",
-    "%1$s shared »%2$s« with you" : "%1$s dijeli »%2$s« s vama",
-    "%1$s shared »%2$s« with you." : "%1$s dijeli »%2$s« s vama.",
-    "Click the button below to open it." : "Kliknite gumb u nastavku za otvaranje.",
     "The requested share does not exist anymore" : "Zatraženo dijeljenje više ne postoji",
     "Could not find category \"%s\"" : "Kategorija „%s” nije pronađena",
     "Sunday" : "Nedjelja",
@@ -188,20 +168,10 @@ OC.L10N.register(
     "Oct." : "Lis.",
     "Nov." : "Stu.",
     "Dec." : "Pro.",
-    "The user limit has been reached and the user was not created." : "Dostignuto je ograničenje broja korisnika pa korisnik nije stvoren.",
-    "Only the following characters are allowed in a username: \"a-z\", \"A-Z\", \"0-9\", and \"_.@-'\"" : "U korisničkom imenu dopušteni su samo sljedeći znakovi: „a – z”, „A – Z”, „0 – 9” i „_.@-'”",
-    "A valid username must be provided" : "Nužno je navesti ispravno korisničko ime",
-    "Username contains whitespace at the beginning or at the end" : "Korisničko ime sadrži bijeli prostor na početku ili na kraju",
-    "Username must not consist of dots only" : "Korisničko ime ne smije se sastojati samo od točkica",
-    "Username is invalid because files already exist for this user" : "Korisničko ime je nevažeće jer već postoje datoteke za ovog korisnika",
     "A valid password must be provided" : "Nužno je navesti ispravnu zaporku",
-    "The username is already being used" : "Korisničko ime se već koristi",
-    "Could not create user" : "Nije moguće stvoriti korisnika",
-    "User disabled" : "Korisnik je onemogućen",
     "Login canceled by app" : "Prijava je otkazana putem aplikacije",
     "App \"%1$s\" cannot be installed because the following dependencies are not fulfilled: %2$s" : "Aplikaciju „%1$s” nije moguće instalirati jer nisu ispunjene sljedeće ovisnosti: %2$s",
     "a safe home for all your data" : "siguran dom za sve vaše podatke",
-    "File is currently busy, please try again later" : "Datoteka je trenutno zauzeta, pokušajte ponovo kasnije",
     "Application is not enabled" : "Aplikacija nije omogućena",
     "Authentication error" : "Pogrešna autentifikacija",
     "Token expired. Please reload page." : "Token je istekao. Ponovno učitajte stranicu.",
@@ -211,14 +181,10 @@ OC.L10N.register(
     "Please ask your server administrator to install the module." : "Zamolite svog administratora poslužitelja da instalira modul.",
     "PHP setting \"%s\" is not set to \"%s\"." : "PHP postavka „%s” nije postavljena na „%s”.",
     "Adjusting this setting in php.ini will make Nextcloud run again" : "Podešavanjem ove postavke u php.ini možete ponovno pokrenuti Nextcloud",
-    "libxml2 2.7.0 is at least required. Currently %s is installed." : "Potreban je barem Libxml2 2.7.0. Trenutno je instalirana inačica %s.",
-    "To fix this issue update your libxml2 version and restart your web server." : "Kako biste riješili ovaj problem, ažurirajte svoju inačicu libxml2 i ponovno pokrenite web poslužitelj.",
     "PHP is apparently set up to strip inline doc blocks. This will make several core apps inaccessible." : "PHP je očigledno postavljen za uklanjanje inline doc blokova. Zbog toga će nekoliko osnovnih aplikacija biti nedostupne.",
     "This is probably caused by a cache/accelerator such as Zend OPcache or eAccelerator." : "Uzrok tome je vjerojatno neki ubrzivač predmemoriranja kao što je Zend OPcache ili eAccelerator.",
     "PHP modules have been installed, but they are still listed as missing?" : "PHP moduli su instalirani, ali još uvijek su na popisu onih koji nedostaju?",
     "Please ask your server administrator to restart the web server." : "Molimo zamolite svog administratora poslužitelja da ponovno pokrene web poslužitelj.",
-    "Please change the permissions to 0770 so that the directory cannot be listed by other users." : "Promijenite dozvole na 0770 tako da se tim direktorijem ne mogu služiti drugi korisnici.",
-    "Ensure there is a file called \".ocdata\" in the root of the data directory." : "Provjerite postoji li datoteka pod nazivom „.ocdata” u korijenu podatkovnog direktorija.",
     "Action \"%s\" not supported or implemented." : "Radnja „%s” nije podržana ili provedena.",
     "Authentication failed, wrong token or provider ID given" : "Autentifikacija nije uspjela, dan je pogrešan token ili ID davatelja usluge",
     "Parameters missing in order to complete the request. Missing Parameters: \"%s\"" : "Nedostaju parametri za ispunjavanje zahtjeva. Nedostaju parametri: „%s”",
@@ -230,28 +196,23 @@ OC.L10N.register(
     "Storage connection error. %s" : "Pogreška veze pohrane. %s",
     "Storage is temporarily not available" : "Pohrana privremeno nije dostupna",
     "Storage connection timeout. %s" : "Istek veze pohrane. %s",
-    "This can usually be fixed by giving the webserver write access to the config directory." : "Ovo se obično može ispraviti tako da se web-poslužitelju dopusti pristup za pisanje u direktoriju config.",
-    "%s enter the database username and name." : "%s unesite korisničko ime i naziv baze podataka.",
-    "%s enter the database username." : "%s unesite korisničko ime baze podataka.",
-    "%s enter the database name." : "%s unesite naziv baze podataka.",
-    "%s you may not use dots in the database name" : "%s ne smijete koristiti točke u nazivu baze podataka",
-    "Cannot read file" : "Datoteku nije moguće pročitati",
-    "Cannot write into \"config\" directory" : "Pisanje u direktorij „config” nije moguće",
-    "This can usually be fixed by giving the webserver write access to the config directory. See %s" : "Ovo se obično može popraviti tako da se web poslužitelju dopusti pristup za pisanje u konfiguracijski direktorij. Pogledajte %s",
-    "Cannot write into \"apps\" directory" : "Nije moguće pisati u direktorij „apps”",
-    "This can usually be fixed by giving the webserver write access to the apps directory or disabling the App Store in the config file." : "Ovo se obično može popraviti tako da se web-poslužitelju dopusti pristup za pisanje u aplikacijski direktorij ili onemogućivanjem trgovine aplikacijama App Store u konfiguracijskoj datoteci.",
-    "Cannot create \"data\" directory" : "Nije moguće stvoriti direktorij „data”",
-    "This can usually be fixed by giving the webserver write access to the root directory. See %s" : "Ovo se obično može popraviti tako da se web poslužitelju dopusti pristup za pisanje u korijenski direktorij. Pogledajte %s",
-    "Permissions can usually be fixed by giving the webserver write access to the root directory. See %s." : "Dopuštenja se obično mogu popraviti tako da se web poslužitelju dopusti pristup za pisanje u korijenski direktorij. Pogledajte %s.",
-    "Setting locale to %s failed" : "Neuspješno postavljanje regionalne sheme na %s",
-    "Please install one of these locales on your system and restart your webserver." : "Instalirajte jednu od ovih regionalnih shema u svoj sustav i ponovno pokrenite svoj web poslužitelj.",
-    "mbstring.func_overload is set to \"%s\" instead of the expected value \"0\"" : "mbstring.func_overload je postavljen na „%s” umjesto očekivane vrijednosti „0”",
-    "To fix this issue set <code>mbstring.func_overload</code> to <code>0</code> in your php.ini" : "Kako biste riješili ovaj problem, postavite <code>mbstring.func_overload</code> na <code>0</code> u datoteci php.ini",
-    "PostgreSQL >= 9 required" : "Potreban je PostgreSQL >= 9",
-    "Please upgrade your database version" : "Ažurirajte svoju inačicu baze podataka",
-    "Your data directory is readable by other users" : "Vaš podatkovni direktorij mogu čitati drugi korisnici",
-    "Your data directory must be an absolute path" : "Vaš podatkovni direktorij mora imati apsolutni put",
-    "Check the value of \"datadirectory\" in your configuration" : "Provjerite vrijednost „datadirectory” u svojoj konfiguraciji",
-    "Your data directory is invalid" : "Vaš je podatkovni direktorij nevažeći"
+    "Text" : "Tekst",
+    "Summary" : "Sažetak",
+    "Translate" : "Prevedi",
+    "Result" : "Rezultat",
+    "Education Edition" : "Obrazovno izdanje",
+    "File name is a reserved word" : "Naziv datoteke je rezervirana riječ",
+    "File name contains at least one invalid character" : "Naziv datoteke sadrži barem jedan nevažeći znak",
+    "File name is too long" : "Naziv datoteke je predugačak",
+    "Users" : "Korisnici",
+    "%1$s shared »%2$s« with you and wants to add:" : "%1$s dijeli »%2$s« s vama i želi dodati:",
+    "%1$s shared »%2$s« with you and wants to add" : "%1$s dijeli »%2$s« s vama i želi dodati",
+    "»%s« added a note to a file shared with you" : "»%s« je dodao bilješku datoteci koju dijeli s vama",
+    "Open »%s«" : "Otvori »%s«",
+    "%1$s shared »%2$s« with you" : "%1$s dijeli »%2$s« s vama",
+    "%1$s shared »%2$s« with you." : "%1$s dijeli »%2$s« s vama.",
+    "Click the button below to open it." : "Kliknite gumb u nastavku za otvaranje.",
+    "File is currently busy, please try again later" : "Datoteka je trenutno zauzeta, pokušajte ponovo kasnije",
+    "Ensure there is a file called \".ocdata\" in the root of the data directory." : "Provjerite postoji li datoteka pod nazivom „.ocdata” u korijenu podatkovnog direktorija."
 },
 "nplurals=3; plural=n%10==1 && n%100!=11 ? 0 : n%10>=2 && n%10<=4 && (n%100<10 || n%100>=20) ? 1 : 2;");
