@@ -201,7 +201,7 @@ OC.L10N.register(
     "Path is already shared with this group" : "パスはすでにこのグループで共有されています",
     "Link sharing is not allowed" : "リンクの共有は許可されていません",
     "Public upload is not allowed" : "公開アップロードは許可されていません",
-    "Path contains files shared with you" : "パスにはあなたと共有するファイルが含まれています",
+    "You cannot share a folder that contains other shares" : "他の共有を含むフォルダーを共有することはできません",
     "Sharing is disabled" : "共有は無効になっています",
     "Sharing is disabled for you" : "共有は無効になっています",
     "Cannot share with the share owner" : "共有所有者と共有できません",
@@ -329,7 +329,6 @@ OC.L10N.register(
     "The audio to transcribe" : "文字起こしする音声",
     "Transcription" : "書き起こし",
     "The transcribed text" : "書き起こされたテキスト",
-    "ContextAgent" : "ContextAgent",
     "Chat with an agent" : "エージェントとチャット",
     "Chat message" : "チャットメッセージ",
     "A chat message to send to the agent." : "エージェントに送信するチャットメッセージ。",
