@@ -64,6 +64,7 @@ OC.L10N.register(
     "Additional settings" : "Papildu iestatījumi",
     "Oracle connection could not be established" : "Nevar izveidot savienojumu ar Oracle",
     "Set an admin password." : "Iestatīt pārvaldītāja paroli.",
+    "Open %s" : "Atvērt %s",
     "Unknown share type" : "Nezināms kopīgošanas veids",
     "You are not allowed to share %s" : "Tev nav ļauts dalīties ar %s",
     "Could not find category \"%s\"" : "Nevarēja atrast kategoriju “%s”",
@@ -116,7 +117,7 @@ OC.L10N.register(
     "Login canceled by app" : "Pieteikšanos atcelā lietotne",
     "a safe home for all your data" : "droša vieta visiem Taviem datiem",
     "Application is not enabled" : "Lietotne nav iespējota",
-    "Authentication error" : "Autentifikācijas kļūda",
+    "Authentication error" : "Autentificēšanās kļūda",
     "Token expired. Please reload page." : "Pilnvarai ir beidzies derīgums. Lūgums pārlādēt lapu.",
     "PHP module %s not installed." : "PHP modulis %s nav instalēts.",
     "Please ask your server administrator to install the module." : "Lūgums vaicāt savam servera pārvaldītāja, lai uzstāda moduli.",
