@@ -2,11 +2,12 @@ OC.L10N.register(
     "lib",
     {
     "Cannot write into \"config\" directory!" : "Не може да зе запишува во \"config\" директориумот!",
+    "This can usually be fixed by giving the web server write access to the config directory." : "Ова најчесто се поправа со давање на дозвола веб серверот за запишување во config папката.",
     "But, if you prefer to keep config.php file read only, set the option \"config_is_read_only\" to true in it." : "Но, доколку претпочитувате config.php да биде само за читање, поставете параметар \"config_is_read_only\" во него.",
     "See %s" : "Види %s",
-    "The files of the app %1$s were not replaced correctly. Make sure it is a version compatible with the server." : "Датотеките од аоликацијата %1$s не се преклопени коректно. Проверете дали верзијата е компатибилна со серверот.",
     "Sample configuration detected" : "Детектирана е едноставна конфигурација",
     "It has been detected that the sample configuration has been copied. This can break your installation and is unsupported. Please read the documentation before performing changes on config.php" : "Детектирано е дека едноставната конфигурација е копирана. Ова може да и наштети на вашата инсталација и не е поддржано. Прочитајте ја документацијата пред да правите промени во config.php",
+    "The page could not be found on the server." : "Страницата не е пронајдена на серверот.",
     "%s email verification" : "%s е-пошта верификација",
     "Email verification" : "Е-пошта верификација",
     "Click the following button to confirm your email." : "Кликнете на следното копче за да ја потврдите вашата е-пошта адреса.",
@@ -17,7 +18,6 @@ OC.L10N.register(
     "%1$s, %2$s and %3$s" : "%1$s, %2$s и %3$s",
     "%1$s, %2$s, %3$s and %4$s" : "%1$s, %2$s, %3$s и %4$s",
     "%1$s, %2$s, %3$s, %4$s and %5$s" : "%1$s, %2$s, %3$s, %4$s и %5$s",
-    "Education Edition" : "Едукативно издание",
     "Enterprise bundle" : "Професионален пакет",
     "Groupware bundle" : "Пакет со групни производи",
     "Hub bundle" : "Централизиран пакет",
@@ -34,9 +34,6 @@ OC.L10N.register(
     "The following platforms are supported: %s" : "Следниве платформи се поддржани: %s",
     "Server version %s or higher is required." : "Потребна е верзија %s или поголема на серверот.",
     "Server version %s or lower is required." : "Потербна е верзија %s или помала на серверот.",
-    "Logged in user must be an admin, a sub admin or gotten special right to access this setting" : "Најавените корисници мора да бидат администратори, ко-администратори или да имаат специјални дозволи за да пристапат до овие поставки",
-    "Logged in user must be an admin or sub admin" : "Најавениот корисник мора да биде администратор или заменик администратор",
-    "Logged in user must be an admin" : "Најавениот корисник мора да биде администратор",
     "Wiping of device %s has started" : "Започна бришење на уредот %s",
     "Wiping of device »%s« has started" : "Започна бришење на уредот »%s«",
     "»%s« started remote wipe" : "Запошна далечинско бришење на уредот »%s«",
@@ -53,7 +50,9 @@ OC.L10N.register(
     "Unknown filetype" : "Непознат тип на датотека",
     "Invalid image" : "Невалидна фотографија",
     "Avatar image is not square" : "Сликата за Аватар не е квадратна",
+    "Files" : "Датотеки",
     "View profile" : "Прегледај профил",
+    "Local time: %s" : "Локално време: %s",
     "today" : "денес",
     "tomorrow" : "утре",
     "yesterday" : "вчера",
@@ -61,8 +60,8 @@ OC.L10N.register(
     "_%n day ago_::_%n days ago_" : ["пред 1 ден","пред %n дена"],
     "next month" : "следниот месец",
     "last month" : "предходниот месец",
-    "_in %n month_::_in %n months_" : ["за 1 месец","за %n месеца"],
-    "_%n month ago_::_%n months ago_" : ["пред 1 месец","пред %n месеци"],
+    "_in %n month_::_in %n months_" : ["за %n месец","за %n месеца"],
+    "_%n month ago_::_%n months ago_" : ["пред %n месец","пред %n месеци"],
     "next year" : "следниот месец",
     "last year" : "предходната година",
     "_in %n year_::_in %n years_" : ["за 1 година","за %n години"],
@@ -75,26 +74,28 @@ OC.L10N.register(
     "seconds ago" : "пред неколку секунди",
     "Empty file" : "Празна датотека",
     "Module with ID: %s does not exist. Please enable it in your apps settings or contact your administrator." : "Модул со ИД: %s не постои. Овозможете го во параметрите на апликациите или контактирајте администратор.",
+    "Dot files are not allowed" : "Датотеки само со точки не се дозволени",
     "File already exists" : "Датотека веќе постои",
     "Invalid path" : "Невалидна патека",
     "Failed to create file from template" : "Неуспешно креирање на датотека од шаблон",
     "Templates" : "Шаблони",
-    "File name is a reserved word" : "Името на датотеката е резервиран збор",
-    "File name contains at least one invalid character" : "Името на датотеката соджи невалиден карактер",
-    "File name is too long" : "Името на датотеката е премногу долго",
-    "Dot files are not allowed" : "Датотеки само со точки не се дозволени",
+    "Filename contains at least one invalid character" : "Името на датотеката соджи невалиден карактер",
     "Empty filename is not allowed" : "Датотеки без име не се дозволени",
     "App \"%s\" cannot be installed because appinfo file cannot be read." : "Апликацијата \"%s\" неможе да се инсталира бидејќи датотеката appinfo неможе да се прочита.",
     "App \"%s\" cannot be installed because it is not compatible with this version of the server." : "Апликацијата \"%s\" неможе да се инсталира бидејќи не е компатибилна со верзијата на серверот.",
     "__language_name__" : "Македонски",
     "This is an automatically sent email, please do not reply." : "Ова е автоматски испратена порака, не одговарајте на истата.",
-    "Help" : "Помош",
+    "Appearance and accessibility" : "Изглед и пристапност",
     "Apps" : "Аппликации",
+    "Personal settings" : "Лични параметри",
+    "Administration settings" : "Административни параметри",
     "Settings" : "Параметри",
     "Log out" : "Одјава",
-    "Users" : "Корисници",
+    "Accounts" : "Сметки",
     "Email" : "Е-пошта",
     "Mail %s" : "Пошта %s",
+    "Fediverse" : "Федиверс",
+    "View %s on the fediverse" : "Погледни %s на федиверс",
     "Phone" : "Телефон",
     "Call %s" : "Повикај %s",
     "Twitter" : "Twitter",
@@ -102,34 +103,27 @@ OC.L10N.register(
     "Website" : "Веб страна",
     "Visit %s" : "Посети %s",
     "Address" : "Адреса",
-    "Profile picture" : "Фотографија за профил",
+    "Profile picture" : "Фотографија",
     "About" : "За",
-    "Full name" : "Цело име",
+    "Display name" : "Име и презиме",
     "Headline" : "Наслов",
     "Organisation" : "Организација",
     "Role" : "Улога",
-    "Unknown user" : "Непознат корисник",
     "Additional settings" : "Дополнителни параметри",
-    "MySQL username and/or password not valid" : "Погрешно MySQL корисничко име и/или лозинка",
+    "Enter the database name for %s" : "Внесете го името на базата за %s",
+    "You cannot use dots in the database name %s" : "Не можеш да користиш точки во името на базата %s",
     "You need to enter details of an existing account." : "Потребно е да внесете детали од постоечката сметка.",
     "Oracle connection could not be established" : "Oracle врската неможе да се воспостави",
-    "Oracle username and/or password not valid" : "Oracle корисничкото име и/или лозинката не се валидни",
-    "PostgreSQL username and/or password not valid" : "PostgreSQL корисничкото име и/или лозинка не се валидни",
-    "Mac OS X is not supported and %s will not work properly on this platform. Use it at your own risk! " : "Mac OS X не е поддржана и %s нема да работи соодветно на оваа платформа. Користењето е на ваш ризик! ",
     "For the best results, please consider using a GNU/Linux server instead." : "За најдобри резултати, размислете за користење на сервер со GNU/Linux.",
     "It seems that this %s instance is running on a 32-bit PHP environment and the open_basedir has been configured in php.ini. This will lead to problems with files over 4 GB and is highly discouraged." : "Највероватно оваа истанца %s е стартувана на 32-битна PHP средина и open_basedir е конфигурано во php.ini. Ова ќе прави проблеми со датотеки поголеми од 4 GB.",
     "Please remove the open_basedir setting within your php.ini or switch to 64-bit PHP." : "Отстранете го параметарот open_basedir од php.ini или преминете на 64-битна PHP средина.",
-    "Set an admin username." : "Постави администраторско корисничко име",
     "Set an admin password." : "Постави администраторска лозинка.",
     "Cannot create or write into the data directory %s" : "Неможете да креирате или да запишувате во папката за податоци %s",
     "Sharing backend %s must implement the interface OCP\\Share_Backend" : "За позадинското споделување %s мора се имплементира интерфејсот OCP\\Share_Backend",
     "Sharing backend %s not found" : "Не е пронајдено позадинско споделување %s",
     "Sharing backend for %s not found" : "Не е пронајдено позадинско споделување за %s.",
-    "%1$s shared »%2$s« with you and wants to add:" : "%1$s ја сподели папката »%2$s« и додаде:",
-    "%1$s shared »%2$s« with you and wants to add" : "%1$s ја сподели папката »%2$s« и додаде",
-    "»%s« added a note to a file shared with you" : "»%s« додаде белешка до датотеката што ја сподели со вас",
-    "Open »%s«" : "Отвори »%s«",
     "%1$s via %2$s" : "%1$s преку %2$s",
+    "Unknown share type" : "Непознат вид на споделување",
     "You are not allowed to share %s" : "Не сте овластени да ја споделите %s",
     "Cannot increase permissions of %s" : "Неможат да се зголемат дозволите на %s",
     "Files cannot be shared with delete permissions" : "Датотеки неможат да бидат споделени со дозвола за бришење",
@@ -137,11 +131,8 @@ OC.L10N.register(
     "Expiration date is in the past" : "Рокот на траење е во минато време",
     "_Cannot set expiration date more than %n day in the future_::_Cannot set expiration date more than %n days in the future_" : ["Неможе да се постави рок на траење повеќе од 1 ден","Неможе да се постави рок на траење повеќе од %s дена"],
     "Sharing is only allowed with group members" : "Споделувањето е овозможено само со членови на групата",
-    "Sharing %s failed, because this item is already shared with user %s" : "Споделувањето на %s е неуспешно, бидејќи истото веќе е споделено со корисникот %s",
-    "%1$s shared »%2$s« with you" : "%1$s сподели »%2$s« со вас",
-    "%1$s shared »%2$s« with you." : "%1$s сподели »%2$s« со вас.",
-    "Click the button below to open it." : "Кликнете на копчето подолу за да ја отворите.",
     "The requested share does not exist anymore" : "Споделувањето не постои повеќе",
+    "The user was not created because the user limit has been reached. Check your notifications to learn more." : "Корисникот не е креиран затоа што максималниот број на корисници е достигнат. Проверете ги вашите известувања за да дознаете повеќе.",
     "Could not find category \"%s\"" : "Не можам да најдам категорија „%s“",
     "Sunday" : "Недела",
     "Monday" : "Понеделник",
@@ -188,37 +179,40 @@ OC.L10N.register(
     "Oct." : "Окт.",
     "Nov." : "Ное.",
     "Dec." : "Дек.",
-    "The user limit has been reached and the user was not created." : "Оганичувањето на корисниците е достигнато и корисникот не е креиран.",
-    "Only the following characters are allowed in a username: \"a-z\", \"A-Z\", \"0-9\", and \"_.@-'\"" : "Само следниве карактери се дозволени во корисничкото име:: \"a-z\", \"A-Z\", \"0-9\", и \"_.@-'\"",
-    "A valid username must be provided" : "Мора да се внесе валидно корисничко име ",
-    "Username contains whitespace at the beginning or at the end" : "Корисничкото име содржи празно место на почетокот или на крајот",
-    "Username must not consist of dots only" : "Корисничкото име не смее да се состои само од точки",
-    "Username is invalid because files already exist for this user" : "Невалидно корисничкото име бидејќи веќе постојат датотеки за овој корисник",
     "A valid password must be provided" : "Мора да се обезбеди валидна лозинка",
-    "The username is already being used" : "Корисничкото име е веќе во употреба",
-    "Could not create user" : "Неможе да се креира корисник",
-    "User disabled" : "Оневозможен корисник",
     "Login canceled by app" : "Најавата е одкажана од апликација",
     "App \"%1$s\" cannot be installed because the following dependencies are not fulfilled: %2$s" : "Апликацијата \"%1$s\" не може да се инсталира затоа што следниве зависности не се исполнети: %2$s",
     "a safe home for all your data" : "безбеден дом за сите ваши податоци",
-    "File is currently busy, please try again later" : "Датотеката моментално е зафатена, обидете се повторно",
     "Application is not enabled" : "Апликацијата не е овозможена",
     "Authentication error" : "Грешка во автентикација",
     "Token expired. Please reload page." : "Жетонот е истечен. Ве молам превчитајте ја страницата.",
     "No database drivers (sqlite, mysql, or postgresql) installed." : "Нема инсталирано додаток за (sqlite, mysql, или postgresql) база на податоци.",
+    "Cannot write into \"config\" directory." : "Не може да зе запишува во \"config\" директориумот",
+    "This can usually be fixed by giving the web server write access to the config directory. See %s" : "Ова најчесто се поправа со давање дозвола на веб серверот за запишување во config папката. Видете %s",
     "Or, if you prefer to keep config.php file read only, set the option \"config_is_read_only\" to true in it. See %s" : "Или, доколку претпочитувате config.php да биде само за читање, поставете параметар \"config_is_read_only\" во него. Видете %s",
+    "Cannot write into \"apps\" directory." : "Не може да зе запишува во \"apps\" директориумот",
+    "This can usually be fixed by giving the web server write access to the apps directory or disabling the App Store in the config file." : "Ова најчесто се поправа со давање дозвола на веб серверот за запишување во папката со апликации или оневозможување на продавницата за апликации во кофигурациската датотека.",
+    "Cannot create \"data\" directory." : "Неможе да се креира директориум \"data\"",
+    "This can usually be fixed by giving the web server write access to the root directory. See %s" : "Ова најчесто се поправа со давање дозвола на веб серверот за запишување во главната папка. Видете %s",
+    "Permissions can usually be fixed by giving the web server write access to the root directory. See %s." : "Дозволите најчесто се поправаат со давање дозвола на веб серверот за запишување во главната папка. Видете %s",
+    "Your data directory is not writable." : "Во Вашата папка со податоци неможе да се запишува.",
+    "Setting locale to %s failed." : "Неуспешно поставување на локацијата %s ",
+    "Please install one of these locales on your system and restart your web server." : "Инсталирајте една од овие локациски податоци во вашиот систем и рестартирајте го веб серверот.",
     "PHP module %s not installed." : "PHP модулот %s не е инсталиран.",
     "Please ask your server administrator to install the module." : "Замолете го сервер администраторот да го инсталира додатокот.",
     "PHP setting \"%s\" is not set to \"%s\"." : "PHP поставката \"%s\" не е поставена до \"%s\".",
     "Adjusting this setting in php.ini will make Nextcloud run again" : "Прилагодувањето на оваа поставка во php.ini ќе направи повторно да работи ",
-    "libxml2 2.7.0 is at least required. Currently %s is installed." : "Потербна минимална верзија на libxml2 е 2.7.0. Моментална верзија е %s.",
-    "To fix this issue update your libxml2 version and restart your web server." : "За да го поправите овој проблем, ажурирајте ја верзијата на libxml2 и рестартирајте го вашиот веб сервер.",
+    "<code>mbstring.func_overload</code> is set to <code>%s</code> instead of the expected value <code>0</code>." : "<code>mbstring.func_overload</code> е поставено на <code>%s</code> очекувана вредност е <code>0</code>.",
+    "To fix this issue set <code>mbstring.func_overload</code> to <code>0</code> in your php.ini." : "За да го поправите ова, поставете вредност за <code>mbstring.func_overload</code> = <code>0</code> во вашата php.ini датотека.",
     "PHP is apparently set up to strip inline doc blocks. This will make several core apps inaccessible." : "PHP поставено да ги поставува во линија внатрешните блокови на документите. Ова ќе ги направи неколку основни апликации недостапни.",
     "This is probably caused by a cache/accelerator such as Zend OPcache or eAccelerator." : "Ова е веројатно предизвикано од кеш-меморија/забрзување како што се Zend OPcache или eAccelerator.",
     "PHP modules have been installed, but they are still listed as missing?" : "PHP модулот е инсталиран, но сеуште се прикажува како да недостасува?",
     "Please ask your server administrator to restart the web server." : "Замолете го сервер администраторот да го рестартира веб серверот.",
-    "Please change the permissions to 0770 so that the directory cannot be listed by other users." : "Поставете дозвола на папката 0770, за да неможе да се чита од други корисници.",
-    "Ensure there is a file called \".ocdata\" in the root of the data directory." : "Осигурете се дека има датотека наречена \".ocdata\" во главната папка со податоци.",
+    "The required %s config variable is not configured in the config.php file." : "Потребната променлива %s не е конфигурирана config.php датотеката.",
+    "Please ask your server administrator to check the Nextcloud configuration." : "Замолете го сервер администраторот да ја провери конфигурацијата.",
+    "Your data directory must be an absolute path." : "Вашата папка со податоци мора да биде апсолутна патека.",
+    "Check the value of \"datadirectory\" in your configuration." : "Проверете ја вредноста на \"datadirectory\" во вашата конфигурација.",
+    "Your data directory is invalid." : "Вашата папка со податоци не е валидна.",
     "Action \"%s\" not supported or implemented." : "Акцијата \"%s\" не е поддржана или не е имплементирана.",
     "Authentication failed, wrong token or provider ID given" : "Неуспешна автентификација, погрешен токен или зададен погрешен ИД",
     "Parameters missing in order to complete the request. Missing Parameters: \"%s\"" : "Некој параметри недостасуваат за да се комплетира барањето.Параметри шо недостасуваат: \"%s\"",
@@ -230,28 +224,24 @@ OC.L10N.register(
     "Storage connection error. %s" : "Грешка во конекција до складиштето. %s",
     "Storage is temporarily not available" : "Складиштето моментално не е достапно",
     "Storage connection timeout. %s" : "Поврзувањето со складиштето не успеа. %s",
-    "This can usually be fixed by giving the webserver write access to the config directory." : "Ова најчесто се поправа со давање на дозвола веб серверот за запишување во config папката.",
-    "%s enter the database username and name." : "%s внесете го корисничкото име и името на базата.",
-    "%s enter the database username." : "%s внеси го корисничкото име за базата.",
-    "%s enter the database name." : "%s внеси го името на базата.",
-    "%s you may not use dots in the database name" : "%s не можеш да користиш точки во името на базата",
-    "Cannot read file" : "Неможе да се прочита датотеката",
-    "Cannot write into \"config\" directory" : "Не може да зе запишува во \"config\" директориумот",
-    "This can usually be fixed by giving the webserver write access to the config directory. See %s" : "Ова најчесто се поправа со давање дозвола на веб серверот за запишување во config папката. Видете %s",
-    "Cannot write into \"apps\" directory" : "Не може да зе запишува во \"apps\" директориумот",
-    "This can usually be fixed by giving the webserver write access to the apps directory or disabling the App Store in the config file." : "Ова најчесто се поправа со давање дозвола на веб серверот за запишување во папката со апликации или оневозможување на продавницата за апликации во кофигурациската датотека.",
-    "Cannot create \"data\" directory" : "Неможе да се креира директориум \"data\"",
-    "This can usually be fixed by giving the webserver write access to the root directory. See %s" : "Ова најчесто се поправа со давање дозвола на веб серверот за запишување во главната папка. Видете %s",
-    "Permissions can usually be fixed by giving the webserver write access to the root directory. See %s." : "Дозволите најчесто се поправаат со давање дозвола на веб серверот за запишување во главната папка. Видете %s",
-    "Setting locale to %s failed" : "Неуспешно поставување на локацијата %s ",
-    "Please install one of these locales on your system and restart your webserver." : "Инсталирајте една од овие локациски податоци во вашиот систем и рестартирајте го веб серверот.",
-    "mbstring.func_overload is set to \"%s\" instead of the expected value \"0\"" : "mbstring.func_overload е поставено на \"%s\", очекувана вредност е \"0\"",
-    "To fix this issue set <code>mbstring.func_overload</code> to <code>0</code> in your php.ini" : "За да го поправите ова, поставете вредност за <code>mbstring.func_overload</code> = <code>0</code> во вашата php.ini датотека",
-    "PostgreSQL >= 9 required" : "Потребно е PostgreSQL >= 9 ",
-    "Please upgrade your database version" : "Ве молиме надградете ја верзијата на базата со податоци",
-    "Your data directory is readable by other users" : "Вашата папка со податоци може да се чита и од други корисници",
-    "Your data directory must be an absolute path" : "Вашата папка со податоци мора да биде потполна патека",
-    "Check the value of \"datadirectory\" in your configuration" : "Проверете ја вредноста на \"datadirectory\" во вашата конфигурација",
-    "Your data directory is invalid" : "Вашата папка со податоци не е валидна"
+    "Text" : "Текст",
+    "Summary" : "Резиме",
+    "Translate" : "Преведи",
+    "Generate headline" : "Генерирај заглавие",
+    "Education Edition" : "Едукативно издание",
+    "File name is a reserved word" : "Името на датотеката е резервиран збор",
+    "File name contains at least one invalid character" : "Името на датотеката соджи невалиден карактер",
+    "File name is too long" : "Името на датотеката е премногу долго",
+    "Users" : "Корисници",
+    "%1$s shared »%2$s« with you and wants to add:" : "%1$s ја сподели папката »%2$s« и додаде:",
+    "%1$s shared »%2$s« with you and wants to add" : "%1$s ја сподели папката »%2$s« и додаде",
+    "»%s« added a note to a file shared with you" : "»%s« додаде белешка до датотеката што ја сподели со вас",
+    "Open »%s«" : "Отвори »%s«",
+    "%1$s shared »%2$s« with you" : "%1$s сподели »%2$s« со вас",
+    "%1$s shared »%2$s« with you." : "%1$s сподели »%2$s« со вас.",
+    "Click the button below to open it." : "Кликнете на копчето подолу за да ја отворите.",
+    "File is currently busy, please try again later" : "Датотеката моментално е зафатена, обидете се повторно",
+    "Cannot download file" : "Не може да се преземе датотеката",
+    "Ensure there is a file called \".ocdata\" in the root of the data directory." : "Осигурете се дека има датотека наречена \".ocdata\" во главната папка со податоци."
 },
 "nplurals=2; plural=(n % 10 == 1 && n % 100 != 11) ? 0 : 1;");
