@@ -2,29 +2,29 @@ OC.L10N.register(
     "lib",
     {
     "Cannot write into \"config\" directory!" : "Não é possível gravar no diretório \"config\"!",
-    "This can usually be fixed by giving the web server write access to the config directory." : "Isso geralmente pode ser corrigido dando ao servidor web acesso de gravação ao diretório de configuração.",
+    "This can usually be fixed by giving the web server write access to the config directory." : "Geralmente, isso pode ser corrigido dando ao servidor web acesso de gravação ao diretório de configuração.",
     "But, if you prefer to keep config.php file read only, set the option \"config_is_read_only\" to true in it." : "Mas, se você preferir manter o arquivo config.php somente para leitura, defina a opção \"config_is_read_only\" como true nele. ",
     "See %s" : "Ver %s",
-    "Application %1$s is not present or has a non-compatible version with this server. Please check the apps directory." : "Aplicação %1$s não está presente ou possui uma versão não compatível com este servidor. Verifique o diretório de aplicativos.",
+    "Application %1$s is not present or has a non-compatible version with this server. Please check the apps directory." : "O aplicativo %1$s não está presente ou tem uma versão não compatível com este servidor. Verifique o diretório de aplicativos.",
     "Sample configuration detected" : "Configuração de exemplo detectada",
     "It has been detected that the sample configuration has been copied. This can break your installation and is unsupported. Please read the documentation before performing changes on config.php" : "Foi detectado que a configuração de exemplo foi copiada. Isso pode terminar sua instalação e não é suportado. Por favor leia a documentação antes de realizar mudanças no config.php",
     "The page could not be found on the server." : "A página não pôde ser encontrada no servidor.",
-    "%s email verification" : "%s e-mail de verificação",
-    "Email verification" : "E-mail de verificação",
-    "Click the following button to confirm your email." : "Clique no botão a seguir para confirmar seu e-mail.",
-    "Click the following link to confirm your email." : "Clique no link a seguir para confirmar seu e-mail.",
-    "Confirm your email" : "Confirme seu e-mail",
+    "%s email verification" : "Verificação de e-mail de %s",
+    "Email verification" : "Verificação do endereço de e-mail",
+    "Click the following button to confirm your email." : "Clique no botão a seguir para confirmar seu endereço de e-mail.",
+    "Click the following link to confirm your email." : "Clique no link a seguir para confirmar seu endereço de e-mail.",
+    "Confirm your email" : "Confirmar seu e-mail",
     "Other activities" : "Outras atividades",
     "%1$s and %2$s" : "%1$s e %2$s",
     "%1$s, %2$s and %3$s" : "%1$s, %2$s e %3$s",
     "%1$s, %2$s, %3$s and %4$s" : "%1$s, %2$s, %3$s e %4$s",
     "%1$s, %2$s, %3$s, %4$s and %5$s" : "%1$s, %2$s, %3$s, %4$s e %5$s",
-    "Education bundle" : "Pacote educacional",
-    "Enterprise bundle" : "Pacote Enterprise",
+    "Education bundle" : "Pacote Educação",
+    "Enterprise bundle" : "Pacote Empresarial",
     "Groupware bundle" : "Pacote Groupware",
-    "Hub bundle" : "Pacote de hub",
-    "Public sector bundle" : "Pacote do setor público",
-    "Social sharing bundle" : "Pacote de compartilhamento social",
+    "Hub bundle" : "Pacote Hub",
+    "Public sector bundle" : "Pacote Setor Público",
+    "Social sharing bundle" : "Pacote Compartilhamento Social",
     "PHP %s or higher is required." : "PHP %s ou superior é necessário.",
     "PHP with a version lower than %s is required." : "É necessária uma versão PHP mais antiga que a %s.",
     "%sbit or higher PHP required." : "%sbit ou PHP maior é requerido.",
@@ -37,10 +37,10 @@ OC.L10N.register(
     "The following platforms are supported: %s" : "As seguintes plataformas são suportadas: %s",
     "Server version %s or higher is required." : "É requerido um servidor da versão %s ou superior.",
     "Server version %s or lower is required." : "É requerido um servidor da versão %s ou abaixo.",
-    "Logged in account must be an admin, a sub admin or gotten special right to access this setting" : "A conta conectada deve ser um administrador, um subadministrador ou ter direito especial para acessar esta configuração",
+    "Logged in account must be an admin, a sub admin or gotten special right to access this setting" : "A conta logada deve ser um administrador, um subadministrador ou ter direito especial para acessar esta configuração",
     "Your current IP address doesn't allow you to perform admin actions" : "Seu endereço IP atual não permite que você execute ações administrativas",
-    "Logged in account must be an admin or sub admin" : "A conta conectada deve ser de um administrador ou subadministrador",
-    "Logged in account must be an admin" : "A conta logada deve ser de um administrador",
+    "Logged in account must be an admin or sub admin" : "A conta logada deve ser um administrador ou subadministrador",
+    "Logged in account must be an admin" : "A conta logada deve ser um administrador",
     "Wiping of device %s has started" : "Limpeza do dispositivo %s iniciou",
     "Wiping of device »%s« has started" : "A limpeza do dispositivo »%s« terminou",
     "»%s« started remote wipe" : "»%s« iniciou a limpeza remota",
@@ -59,12 +59,12 @@ OC.L10N.register(
     "Avatar image is not square" : "A imagem do avatar não é quadrada",
     "Files" : "Arquivos",
     "View profile" : "Visualizar perfil",
-    "same time" : "mesmo tempo",
+    "same time" : "mesmo horário",
     "_%nh_::_%nh_" : ["%nh","%nh","%nh"],
     "_%nm_::_%nm_" : ["%nm","%nm","%nm"],
     "%s ahead" : "%s à frente",
     "%s behind" : "%s atrás",
-    "Local time: %s" : "Hora local: %s",
+    "Local time: %s" : "Horário local: %s",
     "today" : "hoje",
     "tomorrow" : "amanhã",
     "yesterday" : "ontem",
@@ -74,7 +74,7 @@ OC.L10N.register(
     "last month" : "último mês",
     "_in %n month_::_in %n months_" : ["em %n mês","em %n meses","em %n meses"],
     "_%n month ago_::_%n months ago_" : ["há %n mês atrás","há %n meses","há %n meses"],
-    "next year" : "ano que vem",
+    "next year" : "próximo ano",
     "last year" : "último ano",
     "_in %n year_::_in %n years_" : ["em %n ano","em %n anos","em %n anos"],
     "_%n year ago_::_%n years ago_" : ["%n ano atrás","%n anos atrás","%n anos atrás"],
@@ -86,7 +86,9 @@ OC.L10N.register(
     "seconds ago" : "segundos atrás",
     "Empty file" : "Arquivo vazio",
     "Module with ID: %s does not exist. Please enable it in your apps settings or contact your administrator." : "O módulo com a ID: %s não existe. Por favor, habilite-o nas configurações de seu aplicativo ou contacte o administrador.",
+    "No file conversion providers available" : "Não há provedores de conversão de arquivos disponíveis",
     "File is too large to convert" : "O arquivo é muito grande para converter",
+    "Destination does not match conversion extension" : "O destino não corresponde à extensão de conversão",
     "Could not convert file" : "Não foi possível converter o arquivo",
     "Destination does not exist" : "Destino não existe",
     "Destination is not creatable" : "Destino não pode ser criado",
@@ -96,14 +98,17 @@ OC.L10N.register(
     "\"%1$s\" is not allowed inside a file or folder name." : "\"%1$s\" não é permitido dentro de um nome de arquivo ou pasta.",
     "\"%1$s\" is a forbidden file type." : "\"%1$s\" é um tipo de arquivo proibido.",
     "Filenames must not end with \"%1$s\"." : "Os nomes dos arquivos não devem terminar com \"%1$s\".",
-    "Invalid parent path" : "Caminho mãe inválido",
+    "Invalid parent path" : "Caminho pai inválido",
     "File already exists" : "O arquivo já existe",
-    "Invalid path" : "Diretório inválido",
-    "Failed to create file from template" : "Falha ao criar arquivo do modelo ",
+    "Invalid path" : "Caminho inválido",
+    "Failed to create file from template" : "Falha ao criar arquivo a partir do modelo",
     "Templates" : "Modelos ",
+    "Storage %s cannot be moved" : "O armazenamento %s não pode ser movido",
+    "Moving a share (%s) into a shared folder is not allowed" : "Não é permitido mover um compartilhamento (%s) para uma pasta compartilhada",
+    "Moving a storage (%s) into a shared folder is not allowed" : "Não é permitido mover um armazenamento (%s) para uma pasta compartilhada",
     "Moving a share (%s) into another share (%s) is not allowed" : "Não é permitido mover um compartilhamento (%s) para outro compartilhamento (%s)",
     "Moving a share (%s) into another storage (%s) is not allowed" : "Não é permitido mover um compartilhamento (%s) para outro armazenamento (%s)",
-    "Moving a storage (%s) into a share (%s) is not allowed" : "Não é permitido mover um armazenamento (%s) para compartilhamento (%s)",
+    "Moving a storage (%s) into a share (%s) is not allowed" : "Não é permitido mover um armazenamento (%s) para um compartilhamento (%s)",
     "Moving a storage (%s) into another storage (%s) is not allowed" : "Não é permitido mover um armazenamento (%s) para outro armazenamento (%s)",
     "Path contains invalid segments" : "O caminho contém segmentos inválidos",
     "Filename is a reserved word" : "Nome do arquivo é uma palavra reservada",
@@ -123,14 +128,14 @@ OC.L10N.register(
     "Log out" : "Sair",
     "Accounts" : "Contas",
     "Email" : "E-mail",
-    "Mail %s" : "E-Mail %s",
-    "Fediverse" : "Fediverse",
-    "View %s on the fediverse" : "Ver %s no fediverse",
+    "Mail %s" : "Enviar e-mail para %s",
+    "Fediverse" : "Fediverso",
+    "View %s on the fediverse" : "Ver %s no fediverso",
     "Phone" : "Fone",
-    "Call %s" : "Chamar %s",
+    "Call %s" : "Ligar para %s",
     "Twitter" : "Twitter",
-    "View %s on Twitter" : "Visualizar %s no Twitter",
-    "Website" : "Website",
+    "View %s on Twitter" : "Ver %s no Twitter",
+    "Website" : "Site",
     "Visit %s" : "Visitar %s",
     "Address" : "Endereço",
     "Profile picture" : "Foto do perfil",
@@ -144,12 +149,12 @@ OC.L10N.register(
     "Additional settings" : "Configurações adicionais",
     "Enter the database Login and name for %s" : "Insira o login e o nome do banco de dados para %s",
     "Enter the database Login for %s" : "Insira o login do banco de dados para %s",
-    "Enter the database name for %s" : "Digite o nome do banco de dados para %s",
+    "Enter the database name for %s" : "Insira o nome do banco de dados para %s",
     "You cannot use dots in the database name %s" : "Você não pode usar pontos no nome do banco de dados %s",
     "MySQL Login and/or password not valid" : "Login e/ou senha do MySQL inválidos",
     "You need to enter details of an existing account." : "Você necessita entrar detalhes de uma conta existente.",
     "Oracle connection could not be established" : "Conexão Oracle não pôde ser estabelecida",
-    "Oracle Login and/or password not valid" : "Login e/ou senha Oracle inválidos",
+    "Oracle Login and/or password not valid" : "Login e/ou senha do Oracle inválidos",
     "PostgreSQL Login and/or password not valid" : "Login e/ou senha do PostgreSQL inválidos",
     "Mac OS X is not supported and %s will not work properly on this platform. Use it at your own risk!" : "O Mac OS X não é compatível e %s não funcionará corretamente nessa plataforma. Use-o por sua própria conta e risco!",
     "For the best results, please consider using a GNU/Linux server instead." : "Para obter melhores resultados, por favor considere o uso de um servidor GNU/Linux em seu lugar.",
@@ -167,17 +172,17 @@ OC.L10N.register(
     "%1$s shared %2$s with you and wants to add:" : "%1$s compartilhou %2$s com você e deseja adicionar:",
     "%1$s shared %2$s with you and wants to add" : "%1$s compartilhou %2$s com você e deseja adicionar",
     "%s added a note to a file shared with you" : "%s adicionou uma nota a um arquivo compartilhado com você",
-    "Passwords are enforced for link and mail shares" : "As senhas são aplicadas para compartilhamentos de links e e-mails",
+    "Passwords are enforced for link and mail shares" : "As senhas são obrigatórias para compartilhamentos de links e e-mails",
     "Share recipient is not a valid user" : "O destinatário do compartilhamento não é um usuário válido",
     "Share recipient is not a valid group" : "O destinatário do compartilhamento não é um grupo válido",
-    "Share recipient should be empty" : "O destinatário do compartilhamento pode estar vazio",
-    "Share recipient should not be empty" : "O destinatário do compartilhamento não pode estar vazio",
+    "Share recipient should be empty" : "O destinatário do compartilhamento deve estar vazio",
+    "Share recipient should not be empty" : "O destinatário do compartilhamento não deve estar vazio",
     "Share recipient is not a valid circle" : "O destinatário do compartilhamento não é um círculo válido",
     "Unknown share type" : "Tipo de compartilhamento desconhecido",
     "Share initiator must be set" : "O iniciador de compartilhamento deve estar definido",
     "Cannot share with yourself" : "Não é possível compartilhar consigo mesmo",
     "Shared path must be set" : "O caminho do compartilhamento deve estar definido",
-    "Shared path must be either a file or a folder" : "O caminho do compartilhamento deve ser um arquivo ou uma pasta",
+    "Shared path must be either a file or a folder" : "O caminho do compartilhamento deve ser ou um arquivo ou uma pasta",
     "You cannot share your root folder" : "Você não pode compartilhar sua pasta raiz",
     "You are not allowed to share %s" : "Você não tem permissão para compartilhar %s",
     "Valid permissions are required for sharing" : "Permissões válidas são necessárias para compartilhamento",
@@ -188,15 +193,15 @@ OC.L10N.register(
     "Files cannot be shared with create permissions" : "Arquivos não podem ser compartilhados com permissões de criação",
     "Expiration date is in the past" : "Data de expiração está no passado",
     "Expiration date is enforced" : "A data de expiração é aplicada",
-    "_Cannot set expiration date more than %n day in the future_::_Cannot set expiration date more than %n days in the future_" : ["Não foi possível definir a data de expiração superior que %n dias no futuro","Não foi possível definir a data de expiração superior que %n dias no futuro","Não foi possível definir a data de expiração superior que %n dias no futuro"],
+    "_Cannot set expiration date more than %n day in the future_::_Cannot set expiration date more than %n days in the future_" : ["Não é possível definir a data de expiração para mais de %n dia no futuro","Não é possível definir a data de expiração para mais de %n dias no futuro","Não é possível definir a data de expiração para mais de %n dias no futuro"],
     "Sharing is only allowed with group members" : "O compartilhamento só é permitido com membros do grupo ",
-    "Sharing %s failed, because this item is already shared with the account %s" : "Falha no compartilhamento %s porque este item já está compartilhado com a conta %s",
+    "Sharing %s failed, because this item is already shared with the account %s" : "O compartilhamento do %s falhou, porque esse item já está compartilhado com a conta %s",
     "Group sharing is now allowed" : "O compartilhamento em grupo é permitido agora",
     "Sharing is only allowed within your own groups" : "O compartilhamento só é permitido dentro de seus próprios grupos",
     "Path is already shared with this group" : "O caminho já está compartilhado com este grupo",
-    "Link sharing is not allowed" : "O compartilhamento de link não é permitido",
+    "Link sharing is not allowed" : "O compartilhamento de links não é permitido",
     "Public upload is not allowed" : "O upload público não é permitido",
-    "Path contains files shared with you" : "O caminho contém arquivos compartilhados com você",
+    "You cannot share a folder that contains other shares" : "Você não pode compartilhar uma pasta que contém outros compartilhamentos",
     "Sharing is disabled" : "O compartilhamento está desativado",
     "Sharing is disabled for you" : "O compartilhamento está desativado para você",
     "Cannot share with the share owner" : "Não é possível compartilhar com o proprietário do compartilhamento",
@@ -214,7 +219,7 @@ OC.L10N.register(
     "The requested share comes from a disabled user" : "O compartilhamento solicitado vem de um usuário desabilitado",
     "The user was not created because the user limit has been reached. Check your notifications to learn more." : "O usuário não foi criado porque o limite de usuários foi atingido. Confira suas notificações para saber mais.",
     "Could not find category \"%s\"" : "Impossível localizar a categoria \"%s\"",
-    "Input text" : "Entrada de texto",
+    "Input text" : "Texto de entrada",
     "The input text" : "O texto de entrada",
     "Sunday" : "Domingo",
     "Monday" : "Segunda-feira",
@@ -265,9 +270,9 @@ OC.L10N.register(
     "The Login is already being used" : "O Login já está sendo usado",
     "Could not create account" : "Não foi possível criar a conta",
     "Only the following characters are allowed in an Login: \"a-z\", \"A-Z\", \"0-9\", spaces and \"_.@-'\"" : "Somente os seguintes caracteres são permitidos em um Login: \"a-z\", \"A-Z\", \"0-9\", espaços e \"_.@-'\"",
-    "A valid Login must be provided" : "Um login válido deve ser fornecido",
+    "A valid Login must be provided" : "Um Login válido deve ser fornecido",
     "Login contains whitespace at the beginning or at the end" : "O login contém espaços em branco no início ou no final",
-    "Login must not consist of dots only" : "O login não deve consistir apenas em pontos",
+    "Login must not consist of dots only" : "O login não deve consistir apenas de pontos",
     "Login is invalid because files already exist for this user" : "O login é inválido porque já existem arquivos para este usuário",
     "Account disabled" : "Conta desativada",
     "Login canceled by app" : "Login cancelado pelo aplicativo",
@@ -278,16 +283,16 @@ OC.L10N.register(
     "Token expired. Please reload page." : "O token expirou. Por favor recarregue a página.",
     "No database drivers (sqlite, mysql, or postgresql) installed." : "Nenhum driver  de banco de dados (sqlite, mysql ou postgresql) instalado.",
     "Cannot write into \"config\" directory." : "Não é possível gravar no diretório \"config\".",
-    "This can usually be fixed by giving the web server write access to the config directory. See %s" : "Isso geralmente pode ser corrigido dando ao servidor web acesso de gravação ao diretório de configuração. Ver %s",
+    "This can usually be fixed by giving the web server write access to the config directory. See %s" : "Geralmente, isso pode ser corrigido dando ao servidor web acesso de gravação ao diretório de configuração. Consulte %s",
     "Or, if you prefer to keep config.php file read only, set the option \"config_is_read_only\" to true in it. See %s" : "Ou, se você preferir manter o arquivo config.php somente para leitura, defina a opção \"config_is_read_only\" como true. Veja %s",
     "Cannot write into \"apps\" directory." : "Não é possível gravar no diretório \"apps\".",
-    "This can usually be fixed by giving the web server write access to the apps directory or disabling the App Store in the config file." : "Isso geralmente pode ser corrigido dando ao servidor web acesso de gravação ao diretório de aplicativos ou desabilitando a App Store no arquivo de configuração.",
-    "Cannot create \"data\" directory." : "Não é possível criar o diretório \"dados\".",
-    "This can usually be fixed by giving the web server write access to the root directory. See %s" : "Isso geralmente pode ser corrigido dando ao servidor web acesso de gravação ao diretório raiz. Ver %s",
-    "Permissions can usually be fixed by giving the web server write access to the root directory. See %s." : "As permissões geralmente podem ser corrigidas dando ao servidor web acesso de gravação ao diretório raiz. Ver %s.",
+    "This can usually be fixed by giving the web server write access to the apps directory or disabling the App Store in the config file." : "Geralmente, isso pode ser corrigido dando ao servidor web acesso de gravação ao diretório de aplicativos ou desabilitando a Loja de Aplicativos no arquivo de configuração.",
+    "Cannot create \"data\" directory." : "Não é possível criar o diretório \"data\".",
+    "This can usually be fixed by giving the web server write access to the root directory. See %s" : "Geralmente, isso pode ser corrigido dando ao servidor web acesso de gravação ao diretório raiz. Consulte %s",
+    "Permissions can usually be fixed by giving the web server write access to the root directory. See %s." : "Geralmente, as permissões podem ser corrigidas dando ao servidor web acesso de gravação ao diretório raiz. Consulte %s.",
     "Your data directory is not writable." : "Seu diretório de dados não é gravável.",
-    "Setting locale to %s failed." : "Falha ao definir a localidade para %s .",
-    "Please install one of these locales on your system and restart your web server." : "Instale um dessas localidades em seu sistema e reinicie seu servidor web.",
+    "Setting locale to %s failed." : "Falha ao definir a localidade para %s.",
+    "Please install one of these locales on your system and restart your web server." : "Por favor, instale uma dessas localidades em seu sistema e reinicie seu servidor web.",
     "PHP module %s not installed." : "Módulo PHP %s não instalado.",
     "Please ask your server administrator to install the module." : "Por favor, peça ao seu administrador do servidor para instalar o módulo.",
     "PHP setting \"%s\" is not set to \"%s\"." : "Configuração PHP \"%s\" não está configurado para \"%s\".",
@@ -324,13 +329,19 @@ OC.L10N.register(
     "The audio to transcribe" : "O áudio a ser transcrito",
     "Transcription" : "Transcrição",
     "The transcribed text" : "O texto transcrito",
-    "ContextAgent" : "ContextAgent",
     "Chat with an agent" : "Conversar com um agente",
     "Chat message" : "Mensagem de bate-papo",
     "A chat message to send to the agent." : "Uma mensagem de bate-papo a ser enviada ao agente",
     "Confirmation" : "Confirmação",
+    "Whether to confirm previously requested actions: 0 for denial and 1 for confirmation." : "Se deve confirmar as ações solicitadas anteriormente: 0 para negação e 1 para confirmação.",
     "Conversation token" : "Token de conversação",
-    "Generated response" : "Gerar reposta",
+    "A token representing the conversation." : "Um token que representa a conversa.",
+    "Generated response" : "Resposta gerada",
+    "The response from the chat model." : "A resposta do modelo de bate-papo.",
+    "The new conversation token" : "O novo token de conversa",
+    "Send this along with the next interaction." : "Envie isso junto com a próxima interação.",
+    "Requested actions by the agent" : "Ações solicitadas pelo agente",
+    "Actions that the agent would like to carry out in JSON format." : "Ações que o agente gostaria de realizar no formato JSON.",
     "Context write" : "Gravação de contexto",
     "Writes text in a given style based on the provided source material." : "Escreve texto em um determinado estilo com base no material de origem fornecido.",
     "Writing style" : "Estilo de escrita",
@@ -346,17 +357,23 @@ OC.L10N.register(
     "The generated emoji based on the input text" : "O emoji gerado com base no texto de entrada",
     "Generate image" : "Gerar imagem",
     "Generate an image from a text prompt" : "Gere uma imagem a partir de um prompt de texto",
-    "Prompt" : "Pronto",
+    "Prompt" : "Prompt",
     "Describe the image you want to generate" : "Descreva a imagem que você deseja gerar",
     "Number of images" : "Número de imagens",
     "How many images to generate" : "Quantas imagens gerar",
     "Output images" : "Imagens de saída",
     "The generated images" : "As imagens geradas",
-    "Free text to text prompt" : "Texto livre para prompt de texto",
+    "Free text to text prompt" : "Prompt de texto livre para texto",
     "Runs an arbitrary prompt through a language model that returns a reply" : "Usa um modelo de linguagem para gerar uma resposta a partir de um prompt.",
     "Describe a task that you want the assistant to do or ask a question" : "Descreva uma tarefa que você deseja que o assistente execute ou faça uma pergunta",
     "Generated reply" : "Resposta gerada",
     "The generated text from the assistant" : "O texto gerado do assistente",
+    "Change Tone" : "Mudar o tom",
+    "Change the tone of a piece of text." : "Alterar o tom de um texto.",
+    "Write a text that you want the assistant to rewrite in another tone." : "Escreva um texto que você deseja que o assistente reescreva em outro tom.",
+    "Desired tone" : "Tom desejado",
+    "In which tone should your text be rewritten?" : "Em qual tom seu texto deve ser reescrito?",
+    "The rewritten text in the desired tone, written by the assistant:" : "O texto reescrito no tom desejado, escrito pelo assistente:",
     "Chat" : "Conversa",
     "Chat with the assistant" : "Converse com o assistente",
     "System prompt" : "Prompt do sistema",
@@ -366,11 +383,14 @@ OC.L10N.register(
     "Response message" : "Mensagem de resposta",
     "The generated response as part of the conversation" : "A resposta gerada como parte da conversa",
     "Chat with tools" : "Conversar com ferramentas",
+    "Chat with the language model with tool calling support." : "Converse com o modelo de linguagem com suporte a tool calling (\"chamadas a ferramentas\").",
     "Tool message" : "Mensagem da ferramenta",
+    "The result of tool calls in the last interaction" : "O resultado das chamadas de ferramentas na última interação",
     "Available tools" : "Ferramentas disponíveis",
     "The available tools in JSON format" : "As ferramentas disponíveis em formato JSON",
     "The response from the chat model" : "A resposta do modelo de bate-papo",
     "Tool calls" : "Chamadas de ferramentas",
+    "Tools call instructions from the model in JSON format" : "Instruções de chamada de ferramentas do modelo no formato JSON",
     "Formalize text" : "Formalizar texto",
     "Takes a text and makes it sound more formal" : "Pega um texto e faz com que ele soe mais formal",
     "Write a text that you want the assistant to formalize" : "Escreva um texto que você deseja que o assistente formalize",
@@ -382,21 +402,23 @@ OC.L10N.register(
     "The original text to generate a headline for" : "O texto original para gerar um título para",
     "The generated headline" : "O título gerado",
     "Proofread" : "Revisar",
+    "Proofreads a text and lists corrections" : "Revisa um texto e lista as correções",
     "Text" : "Texto",
     "The text to proofread" : "O texto a ser revisado",
     "Corrections" : "Correções",
+    "The corrections that should be made in your text" : "As correções que devem ser feitas em seu texto",
     "Reformulate text" : "Reformular texto",
     "Takes a text and reformulates it" : "Pega um texto e o reformula",
     "Write a text that you want the assistant to reformulate" : "Escrever um texto que você deseja que o assistente reformule",
     "Reformulated text" : "Texto reformulado",
     "The reformulated text, written by the assistant" : "O texto reformulado, escrito pela assistente",
     "Simplify text" : "Simplificar texto",
-    "Takes a text and simplifies it" : "Pegar um texto e simplificar ",
+    "Takes a text and simplifies it" : "Pega e simplifica um texto",
     "Write a text that you want the assistant to simplify" : "Escreva um texto que você deseja que o assistente simplifique",
     "Simplified text" : "Texto simplificado",
     "The simplified text" : "O texto simplificado",
     "Summarize" : "Resumir",
-    "Summarizes a text" : "Resumir um texto",
+    "Summarizes a text" : "Resume um texto",
     "The original text to summarize" : "O texto original para resumir",
     "Summary" : "Resumo",
     "The generated summary" : "O resumo gerado",
@@ -406,16 +428,16 @@ OC.L10N.register(
     "Topics" : "Tópicos",
     "The list of extracted topics" : "A lista de tópicos extraídos",
     "Translate" : "Traduzir",
-    "Translate text from one language to another" : "Traduzir o texto de um idioma para outro",
+    "Translate text from one language to another" : "Traduzir um texto de um idioma para outro",
     "Origin text" : "Texto original",
     "The text to translate" : "O texto a ser traduzido",
     "Origin language" : "Idioma original",
     "The language of the origin text" : "O idioma do texto original",
-    "Target language" : "Target language",
+    "Target language" : "Idioma de destino",
     "The desired language to translate the origin text in" : "O idioma definido para traduzir o texto original",
     "Result" : "Resultado",
     "The translated text" : "O texto traduzido",
-    "Free prompt" : "Solicitação gratuita",
+    "Free prompt" : "Prompt livre",
     "Runs an arbitrary prompt through the language model." : "Executa um prompt arbitrário por meio do modelo de idioma.",
     "Generate headline" : "Gerar título",
     "Summarizes text by reducing its length without losing key information." : "Resume o texto reduzindo seu comprimento sem perder informações importantes.",
