@@ -201,7 +201,7 @@ OC.L10N.register(
     "Path is already shared with this group" : "路径已与此群组共享",
     "Link sharing is not allowed" : "不允许共享链接",
     "Public upload is not allowed" : "不允许公开上传",
-    "Path contains files shared with you" : "路径包含与你共享的文件",
+    "You cannot share a folder that contains other shares" : "您无法共享包含其他共享的文件夹",
     "Sharing is disabled" : "共享已禁用",
     "Sharing is disabled for you" : "已为您禁用共享",
     "Cannot share with the share owner" : "无法与共享所有者共享",
@@ -329,7 +329,6 @@ OC.L10N.register(
     "The audio to transcribe" : "要转录的音频",
     "Transcription" : "转录",
     "The transcribed text" : "已转录的文本",
-    "ContextAgent" : "上下文代理",
     "Chat with an agent" : "和 agent 对话",
     "Chat message" : "聊天消息",
     "A chat message to send to the agent." : "要发送给 agent 的聊天消息。",
